(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   1423284,      26326]
NotebookOptionsPosition[   1407360,      25857]
NotebookOutlinePosition[   1407849,      25876]
CellTagsIndexPosition[   1407806,      25873]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "\n",
 StyleBox["10-K Documetric Similarity  ", "Title"],
 "\n\n\n\n\nDara O Shayda\ndara@lossofgenerality.com \n\nNov 10th 2013 \n\n\
\[Copyright] Thorek-Scout & Partners \n"
}], "Text",
 CellChangeTimes->{{3.5930526852827673`*^9, 3.5930527491259003`*^9}, {
   3.593054962038898*^9, 3.593054970969283*^9}, {3.5930550218432302`*^9, 
   3.5930550289072104`*^9}, {3.593055186039577*^9, 3.593055205951097*^9}, 
   3.593057649804163*^9}],

Cell[TextData[{
 "\n",
 StyleBox["Prelude", "Title"],
 "\n\n\nThis is an investigation into putative relationship between the 10-K \
filings for US public companies and their corresponding stock prices. \n\nWe \
show that the relationship is tangibly extant and not a conceptual nor a \
theoretical one.\n\nWe start by stablishing the Cosine Similarity between the \
Section 7 (Management Discussion) of about 1000 US companies, for 2012. We \
set the threshold at 60% for similarity between the said sub-sections of the \
filings. \n\nThen we take the corresponding stock prices for 2013 and instead \
of focusing on a small period of time and wondering about fluctuations, we go \
straight to the Trend (de-noised) curves of these stocks and compute the \
distance between the curves (Canberra Metric) to establish a measure for \
similarity. 2013 was chosen as a lag of time to allow for reaction to the \
10-K filing of 2012. \n\nNo other knowledge about the market or specific \
stock is assumed. No further assumptions.\n\nThe code below is a simple \
implementation of the above to verify the concepts and observe the \
limitations. \n\nAs we see below the relationship between the 10-K filings\
\[CloseCurlyQuote] Section 7 and Trend curves are real and small number of \
failures are observed. \n\nIn specific if the distance between two 10-K \
filings is small, then the distance between their corresponding Trend curves \
is also small in more rigorous manner:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"d", "(", 
       RowBox[{
        SubscriptBox["s", "1"], ",", " ", 
        SubscriptBox["s", "2"]}], " ", ")"}], " ", "\[LessLess]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "(", 
         RowBox[{
          SubscriptBox["s", "i"], ",", " ", "tr"}], ")"}], "  ", 
        "\[DoubleLongRightArrow]", " ", 
        RowBox[{"d", "'"}]}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"T", "(", 
          SubscriptBox["s", "1"], ")"}], ",", " ", 
         RowBox[{"T", "(", 
          SubscriptBox["s", "2"], ")"}]}], " ", ")"}]}], " ", "\[LessLess]", 
      " ", 
      RowBox[{
       RowBox[{"d", "'"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"T", "(", 
          SubscriptBox["s", "i"], ")"}], ",", " ", 
         RowBox[{"T", "(", "tr", ")"}]}], ")"}], "     ", "i"}]}], " ", "=", 
     " ", "1"}], " ", ",", "2", " "}], TraditionalForm]]],
 "\n\nWhere d is Cosine Similarity (or whatever metric used for similarity in \
10-K document space), ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "1"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "2"], TraditionalForm]]],
 " are two stocks with similarity more than 60%, tr is a an outlier much \
further away from ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "1"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "2"], TraditionalForm]]],
 " than distance between ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "1"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "2"], TraditionalForm]]],
 ", d\[CloseCurlyQuote] is the metric in Trend curve  space of the stock \
(Canberra Distance) and T is the Trend function. \[LessLess] stands for much \
less than. \n\nIf the stocks\[CloseCurlyQuote] Cosine Similarity for their \
10-K filings form a connected sub-graph, then we test for max-min:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"max", "(", 
           RowBox[{
            RowBox[{"d", "'"}], 
            RowBox[{"(", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"T", 
                RowBox[{"(", 
                 SubscriptBox["s", "i"], ")"}]}], ",", " ", 
               RowBox[{"T", 
                RowBox[{"(", 
                 SubscriptBox["s", "j"], ")"}]}]}], ")"}]}]}]}], "}"}], " ", 
         ")"}], "  ", "\[LessLess]", " ", 
        RowBox[{"min", "(", 
         RowBox[{
          RowBox[{"d", "'"}], 
          RowBox[{"(", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"T", "(", 
              SubscriptBox["s", "i"], ")"}], ",", " ", 
             RowBox[{"T", "(", "tr", ")"}]}], ")"}]}]}]}]}], "}"}], ")"}], "     ", 
     RowBox[{"\[ForAll]", "i"}]}], ",", " ", "j", " "}], TraditionalForm]]],
 "\n\n ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "i"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "j"], TraditionalForm]]],
 " are connected in the Cosine Similarity graph of the 10-K filings. This \
equation basically says: \n \n",
 StyleBox["if the similarity connected stocks in 10-K space with Cosine \
Distance form a low-radius cluster which is afar from a random-pick outlier \
(tr), then their Trend curve space for price in Canberra Distance also forms \
a low-radius cluster which is afar from the Trend curve of the random-pick! ",
  
  FontWeight->"Bold"],
 "\n \n This is indeed a very weak off-shoot definition of isometry. Let\
\[CloseCurlyQuote]s call this ",
 StyleBox["relative-isometry with preserved outlier",
  FontVariations->{"Underline"->True}],
 ". \n\n",
 StyleBox["Remark 1",
  FontWeight->"Bold"],
 ": ",
 StyleBox["The above test is not a full-proof test, but good enough to show \
that there is such a relationship as depicted above. ",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.59306406175802*^9, 3.593064382689354*^9}, {
   3.593064470137385*^9, 3.593064514684827*^9}, {3.59306482535711*^9, 
   3.593064894149085*^9}, {3.5930653641670427`*^9, 3.593065377755958*^9}, {
   3.593065458885991*^9, 3.593065484834113*^9}, {3.593066085442965*^9, 
   3.593066419421327*^9}, {3.593066482569895*^9, 3.593066507235613*^9}, {
   3.5930665750791903`*^9, 3.593066575572344*^9}, {3.593071061297594*^9, 
   3.593071168821686*^9}, {3.593071206009294*^9, 3.593071212830263*^9}, {
   3.593071244307976*^9, 3.593071287505702*^9}, {3.593071988613158*^9, 
   3.593071990118116*^9}, 3.593072129565546*^9, {3.593095530326415*^9, 
   3.5930957583649178`*^9}, {3.593095839362028*^9, 3.593095929529434*^9}, 
   3.5930960061895514`*^9, {3.593096056654839*^9, 3.5930963479207697`*^9}, {
   3.593096513781929*^9, 3.593096575495957*^9}, {3.593097248363674*^9, 
   3.593097250094122*^9}, {3.5931287433559313`*^9, 3.5931287456378736`*^9}, {
   3.593128859145756*^9, 3.593128869286654*^9}}],

Cell[TextData[{
 "\n",
 StyleBox["Remark 2",
  FontWeight->"Bold"],
 ": ",
 StyleBox["The above test fails in some occasions and indeed the statistics \
of such failures would indicate the good-ness of the said relationship.\n\n",
  FontSlant->"Italic"],
 StyleBox["Remark 3",
  FontWeight->"Bold"],
 ": ",
 StyleBox["Canberra Distance might not always be a good metric, therefore \
variations of such metric for similarity might result in much more accurate \
Documentric algorithms. ",
  FontSlant->"Italic"],
 "\n\nTo investigate further, a set of random-pick outliers were selected to \
investigate the statistical nature of the above algorithm. In above \
inequalities the term ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"d", "'"}], 
    RowBox[{"(", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"T", "(", 
        SubscriptBox["s", "i"], ")"}], ",", " ", 
       RowBox[{"T", "(", "tr", ")"}]}], ")"}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " was replaced by the mean of all such distances summing over the set of \
outliers, let\[CloseCurlyQuote]",
 StyleBox["s",
  FontSlant->"Italic"],
 " represent that by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["d", "_"], "'"}], 
    RowBox[{"(", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"T", "(", 
        SubscriptBox["s", "i"], ")"}], ",", " ", 
       RowBox[{"T", "(", "tr", ")"}]}]}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") and therefore:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"max", "(", 
            RowBox[{
             RowBox[{"d", "'"}], 
             RowBox[{"(", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"T", "(", 
                 SubscriptBox["s", "i"], ")"}], ",", " ", 
                RowBox[{"T", "(", 
                 SubscriptBox["s", "j"], ")"}]}], ")"}]}]}]}], "}"}], " ", 
          ")"}], "  ", "\[LessLess]", " ", 
         RowBox[{"min", "(", 
          RowBox[{
           RowBox[{
            OverscriptBox["d", "_"], "'"}], 
           RowBox[{"(", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"T", "(", 
               SubscriptBox["s", "i"], ")"}], ",", " ", 
              RowBox[{"T", "(", "tr", ")"}]}], ")"}]}]}]}]}], "}"}], ")"}], "     ", 
      RowBox[{"\[ForAll]", "i"}]}], ",", " ", "j"}], " ", "\n"}], 
   TraditionalForm]],
  FormatType->"TraditionalForm"],
 " \nas the desired inequality to check for Documetric Similarities mapped \
into Trend curve similarities. \n\nResults are quite similar, strong \
indication of a relationship between the 10-K filings and stock prince Trend \
curves. \n\n",
 StyleBox["\n\n",
  FontSlant->"Italic"],
 StyleBox["Disclaimer", "Subtitle"],
 "\n\n",
 StyleBox["We provide \[OpenCurlyQuote]cloud\[CloseCurlyQuote] for computing \
the machine learning algorithms and data mining for forecast, classification \
and clustering applications. By no means we provide any guarantees for the \
models to be of certain accuracy or performance. It is the responsibility of \
the user to fine-tune the algorithms to produce the desired results. For that \
matter we provide a large variation for a certain algorithm and different \
versions of the algorithm. \n\n",
  FontSlant->"Italic"],
 "\n\n",
 StyleBox["Trend & Wavelets", "Title"]
}], "Text",
 CellChangeTimes->{{3.593055210529167*^9, 3.593055222306917*^9}, {
  3.593055291474454*^9, 3.593055292586712*^9}, {3.593055611516533*^9, 
  3.593055623900772*^9}, {3.593060210263343*^9, 3.593060215910136*^9}, {
  3.5930621771023073`*^9, 3.593062193977768*^9}, {3.59306404723512*^9, 
  3.5930640544451323`*^9}, {3.593071991546501*^9, 3.5930720521074753`*^9}, {
  3.5930964496546087`*^9, 3.593096495586808*^9}, {3.593096605502026*^9, 
  3.5930966558551493`*^9}, {3.5930966899669867`*^9, 3.5930966926765757`*^9}, {
  3.593128756360753*^9, 3.593128852142228*^9}, {3.593128898774517*^9, 
  3.5931291142930613`*^9}, {3.593134826736157*^9, 3.593134827306212*^9}}],

Cell["\<\

Choose a stock and download this year\[CloseCurlyQuote]s price data:\
\>", "Text",
 CellChangeTimes->{{3.593055237259185*^9, 3.5930552615921583`*^9}, 
   3.5930665917404203`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<IBM\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.525987020690566*^9, 3.525987024717289*^9}, {
   3.5259873948022137`*^9, 3.525987398806273*^9}, {3.525989563193519*^9, 
   3.525989564022056*^9}, 3.525989880029282*^9, 3.525989918761571*^9, {
   3.593039867902714*^9, 3.593039871479488*^9}, {3.593044638968956*^9, 
   3.5930446631524467`*^9}, {3.593045969455594*^9, 3.593045984462613*^9}, {
   3.593046084093822*^9, 3.593046085959978*^9}, {3.593049231885222*^9, 
   3.593049233705824*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DateListPlot", "[", 
  RowBox[{"price", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<IBM\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{3.525987050662086*^9, 3.593064937510762*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxVlmlslFUYhScooAW0QP9QoAyrNUEoOxgJU0EpoklpFAGLVJOWTWAQjQkY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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 172.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"IBM\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {171.94, 212.58}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.8128000000000003, 
   0.8128000000000003}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.5259870534232597`*^9, 3.525987406193453*^9, 3.5259895821829853`*^9, 
   3.525989890999489*^9, 3.525989929497693*^9, 3.593039693342703*^9, 
   3.593039874855467*^9, {3.5930446443782797`*^9, 3.59304466695304*^9}, 
   3.593045988906782*^9, 3.593046089338485*^9, 3.5930462630410233`*^9, 
   3.593047160149177*^9, 3.593048957135829*^9, 3.593049236618978*^9, 
   3.593055482658493*^9, 3.593064938644009*^9, 3.593065044345079*^9, 
   3.593065100073097*^9, 3.593097748948799*^9, {3.593136104375124*^9, 
   3.593136110114006*^9}}]
}, Open  ]],

Cell["\<\

Choose a Wavelet basis to break down the price function above:\
\>", "Text",
 CellChangeTimes->{{3.5930553092709618`*^9, 3.593055326111767*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.525987069910513*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WaveletListPlot", "[", 
  RowBox[{"dwd", ",", 
   RowBox[{"PlotLayout", "\[Rule]", "\"\<CommonYAxis\>\""}], ",", 
   RowBox[{"Ticks", "\[Rule]", "Full"}]}], "]"}]], "Input",
 CellChangeTimes->{3.525987079979705*^9, 3.593041574675253*^9}],

Cell[BoxData[
 GraphicsBox[{{
    TagBox[
     TooltipBox[{{}, {{}, {}, 
        {RGBColor[0.24, 0.3531726744018182, 0.6], LineBox[CompressedData["
1:eJw9lQtQVGUUxz9xwJQkRGYIUNgQERWTUiMM+V8zRlDynYgSbCiP0GkhVIxx
5Kr5yGeihFkB1fjILFCbVJC+BRVUcJb3+7G8FpbX8khNSem7937TndnZOfOd
ved//ud3vn0jXLMmwowQEss+0vf/z4s92YubcumCGXtvrorfh6xQm4i0czaC
EieD2I4mus7IoSXZebbPrnwHEkQHL+y4A+X8J5Do0dWvOyTDLO5Hg6v1RYjj
7Sq8tvfy/F9BYpzNVm/LoyvkhCyQRUmRaRkFvN41qITFtzvfsBCmBJ7SZef9
AdLldDm1U8ffdwNi+MpmK68yaky5+uJE6C2IY3AgKqaRvz8HxG+c+67jHfTP
5tLZm0dyQUKSbhePuQ6lnhba0NOzPFOGkM+yHQPzeD9FXH8+iNvo+ZygWnrJ
e/zdA+fugKjTt5mvK6OKnrsQAquXZee305Oh9vWmrnvI2h4Wnm9NtIq+Qoif
FoVOjhjEzv0zh4K97kMMOdS1saoVit4HIDul/BIaIhd4CNK75+Tl3yjXXwTi
27z8amQVXfIoQPVmRTHIlCTrWDzk/TyCuCwh4uK/7VR6+1kXHdd7i/dXAu36
nPqwo8P0sKXUUQkE78JCC6OBKv2WQr1BsyVrwzAdmZr7Nnsn05uQU/nxIPe/
DNpFUn0D1Xj6+fZYlEOU69dxP1i8fdwvi5z1tPV9WSCIjcwDFH9Y/Owvk+Oa
fvqR/FQyf1e+4vhBD/erEv4fznM4mGarfRDVqD6yuwqC3WvlQslzPt9qVv9Q
sscOA3wSI7bRn6uhjh1eWHd0gPtZA0GTutUqi2gzj/Ul/P2QxRFhXrP1Ldzf
WpCJSR01VsWYlr6D/aIWGZ88nX7Eb4j7XQe1pscq8MYA/UZKt68HWe58xcWy
kvtfD9X6zS713w5D6va00ABBhfqUIiOUeTSArBp122u8jt1VEy/cj2qE6K5p
6y7ogjKfRhDFbwx0SYKakCHrHYAyr2aIZukxiZ59dLMyAAjPCxwvu/Xz+ekh
LtQNn8mtQo/F2vbrn+mhciiMqzn0HMo89SD9Ei86TLe2i1lh1sLn18Ln2wLy
NHTC+GNNCJPsTmmBMGlpwzFND5RyLciIjj9/In4QZ10kg1pBnObu/8Klm/Pf
CnGL5GcpymZLCtn5/NGSNYerofDQBuHVGR7rpvZClrOqDUTAW3c9DJwPFn8+
ujtzmZ5K2WvbWfyy7quJ2S+g8NIOwan58T7zbiQtlSbYDrJO8rOc88PiSKl+
HpgYm8OWHSCbdAF3nMqh8MTiyBsDmaUtkO1M74A+buWEC1EDUPjqgDhn7u/W
a2vgIRtsAAmW7yeq8GaAKN9X5VSiK6iAxXNPnp5mX0MV/jpZv5lLQrZWUxmf
YBarpftsH1V4ZHG4dB/ko3aP1EAnxMcrrvW2NlGFzy6QAI23vXslbOSBdUFU
pZ5xyDVC4ZWd+1Q7T0s2QG7X1ghtcMLXvnPaOL9GqNWmZyOxQzjI6Au5ZGR8
6pw8+is4zyyfdBa17uqjkvon73WD+Ev83uN8d7N9sDzTVzMIiYZTOnYel576
/ZdaznsPiOlgzrv7THSeDGwPhEHfjSXeJij8s/OFznuP1hVQ2Z4nLHZL1146
9YAq+9ALYYIzKfDvhQS/+kgvRNn/En5fsTigcOgH+8dUL63D1D7cjE7zoXGT
tMq+9EEVH/TOfB89lfG82gdiHrYg43YDv9/6oHa3mxVZ2UUl+j39+qEfGmpV
jRvl+9Qv7d+I8eYBHJfXn527BoUJAUa+XyaI0YX+xYmDYOawiZlgvWnmia3m
Y7XKvpmQsbG0wjB5rFb5sxsA+eel65N7afQ/0nF50A==
          "]]}}, {}},
      RowBox[{"{", "1", "}"}]],
     Annotation[#, {1}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[{{}, {{}, {}, 
        {RGBColor[0.24, 0.6, 0.33692049419863584`], LineBox[CompressedData["
1:eJw9k09IlEEYxiclsg3yLxSSZkqg4CHIQrDt+U4pEbh6MttChUQDa7FLVIcl
tENg3oQ6lBCpp/KmRjCTlQVrkFiZ9MeVMitr+fb/rqu7ve83Xw4sy/PNzDvP
+/xmDnRcaj6fJYSoox//62HidWn/2lyowgh0963cO2HCNUkfqvaoL/M5PueA
ibZopXvwXBwkxj/PmxAvZmdnTz3E1Gj+0LXiIMqaacNSUo6xbA/CX/iofnko
y2A1NRrEsGPhgeevKbl6SyAIz1rTZGldtnG5saI6XhOCQbL/+U+0WwVDEHxe
+Vfp4unpEFxFVM8t1HE+PicMxQZ9fvBsb2MYZVTeOZJAsVUgDNHdSeOV3GkZ
DsPLsivXsJZXROC5Q+PgduMH2+mOQNQvXy3q/IV33O54BH4+LysGXl0dp/nb
09HKp6bk033OKK5wvcJ8dZ+390XR5aQGS/Yqy54vijGy4wjkGdctQzEYXK98
FResAGIQd+n80xnZYgUeg2I/PUFplVshzf1fTOOINoBh3t+xLq04ekm7B6ej
iSAKrIDj8PdRoKZDaZ4JiH39a021L6XmSdpPhm6NwLI/kMAY2VuYK1SaZwIu
7t/jMJ5YPJNoO0xjIg7NM4k81vtzleaZhHhP9U6u2jyT8HL/N3Yry23NOgTz
PLNk8yTN/Eve2jzXUcb9bttl80xBsZ/6TZtnCt7HZCjyQWqeKQxnaIya0DxT
EG/o/h37JjXPDQjOp3UGmifpKgqoJ9vQPDdgnKW8Dv2ROs4N7Wdxh9I8NyGe
UeCZj9A8N+Hl/Js/QfOkeb5ftQVK80xDcV4zv6XmmUYDxT3ZWqA0zzSMBr5P
AZsnrafr454IS80zA3GT1h/9bvPMbL0/zTOz9f7sB2r8f3//ADds2Rs=
          "]]}}, {}},
      
      RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]],
     Annotation[#, {0, 1}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[{{}, {{}, {}, 
        {RGBColor[0.6, 0.5470136627990908, 0.24], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQUOM4yvSNfu1TgA4TE4KNws+f1oOSOE38Dg0HBh
R1hWvLIDmH8AqGJP3uuQyWftIdoZHR6E5O62CZKFyDswOjCkrz11c+Xl/RD9
QL5YbUp38h2I+gOMDg1LTpaGOz2A6mdyYPBviDZ3egThOzA5TOhl+rZuogDU
fiYHiy+VTEr/FCD8A0wOC1rOcp87xwCxj4HZIeJOxenFAoZQ+5kdGBb0fGLb
uRRiXgOzg8PtSUWBuWxQ9wPl659vS458DXEfA4vDAfl+luDrvyB8BxaHhhNJ
W7IU/0Ldz+LwQP9i4aMrYlD9LA4O6jyyh2R/Qd3P6nCgwOc57/avUP2sDg1d
qTlGDU+h+lkdHGqXPP2azA7VD1T/WMvnfM5nqH42hwUJd6oC1YSh7ge602et
mqb2Xah+NocPt3I8ApZIQf3P5pDznadva4Y+hM/A7pDg9c6gwYUHqp/dQeL3
/rUsvBoQfgO7w4KbvLmfBGHxx+5wwS0x5rO/LFQ/h8OGd1wVrjtEDgAAqOiU
aA==
          "]]}}, {}},
      RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]],
     Annotation[#, {0, 0, 1}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[{{}, {{}, {}, 
        {RGBColor[0.6, 0.24, 0.4428931686004542], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEcDhIx/UqyqxQP7G37JHUqm8NhQ4Ftl7WY+oFK
3qemU65zOPw4c4aH/7fyAbMp1wPinDkdNsT0L7p4UdkBpFpjPadDwnY5V3t5
tgPrF+4BmsDl8GBxQWz9b32HHA2QCJdDQ6Ft1xqVn/vB3E9cDnvcHz6bv8zp
AMj0gDhuB49qEbu8LNUDi0DaT3E7NKx3T+x9/nt/nDPIBTwODtcXG5R8FDwg
DbJuIY9Dgci656sWSTvcCACp4HVgMDY2fjbvhT3YeZW8DhYi68ozBZUdAsEG
8Dq0vA58MTfd4AAf2EI+h4q0tG8SxloHwMbt4XNgqBJZt2IGowPY+xr8DjcW
F+ytXavqALZ+Cr/DjteBNypr1Rwg4SXgwLDidSDH7Z37AaHNiQk=
          "]]}}, {}},
      RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]],
     Annotation[#, {0, 0, 0, 1}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[{{}, {{}, {}, 
        {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQECDjzXF5/vrWh3iHOu5H1qKuAgvm76s45J7Q57
2z5JncoWcHhU1dKwL7TdQfpUtsb6hQIOWjHTDzWrdziAVE+5LuDQ/Pqj4PRN
HQ43AkAmCDosLbib/aej08FsynWgiKCD50MjVa76Lgcwt1LQ4bvGmm8y1h0O
INM11gs6HP06Q0xnWadDINgBgg4eD42mNAH56xfuAbpAyKFG5N/2zPXtDnwg
6wKEHPoPzd17oajDIUcDpELI4cjXGY5SBu0OYOftEXKQbz38V52/3QEs/UnI
4cbiCUtDW9sd2sEWCjtUitjdeves1QFsXJywww8NF44rju0OYO9PEXYwNn6c
5lvY7rAIZP0pYYcLZ/5Un13Z7gAJLxGHte6Ml1e/bXMAAOFRjeM=
          "]]}}, {}},
      RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]],
     Annotation[#, {0, 0, 0, 0}, "Tooltip"]& ]}, 
   {AbsoluteThickness[0.1], 
    StyleBox[{
      StyleBox[
       StyleBox[{
         {GrayLevel[0.45], 
          LineBox[{{1., -200.}, {1., 1000.0000000000001`}}]}, {{
           {GrayLevel[0.45], 
            LineBox[{{{1., -200.}, Offset[{4., 0}, {1., -200.}]}, {{1., 0.}, 
               Offset[{4., 0}, {1., 0.}]}, {{1., 200.}, 
               Offset[{4., 0}, {1., 200.}]}, {{1., 400.}, 
               Offset[{4., 0}, {1., 400.}]}, {{1., 600.}, 
               Offset[{4., 0}, {1., 600.}]}, {{1., 800.}, 
               Offset[{4., 0}, {1., 800.}]}, {{1., 1000.0000000000001`}, 
               Offset[{4., 0}, {1., 1000.0000000000001`}]}}]}, 
           {GrayLevel[0.45], 
            LineBox[{{{1., -150.}, Offset[{2., 0}, {1., -150.}]}, {{
               1., -100.}, Offset[{2., 0}, {1., -100.}]}, {{1., -50.}, 
               Offset[{2., 0}, {1., -50.}]}, {{1., 50.}, 
               Offset[{2., 0}, {1., 50.}]}, {{1., 100.}, 
               Offset[{2., 0}, {1., 100.}]}, {{1., 150.}, 
               Offset[{2., 0}, {1., 150.}]}, {{1., 250.00000000000003`}, 
               Offset[{2., 0}, {1., 250.00000000000003`}]}, {{1., 300.}, 
               Offset[{2., 0}, {1., 300.}]}, {{1., 350.}, 
               Offset[{2., 0}, {1., 350.}]}, {{1., 450.00000000000006`}, 
               Offset[{2., 0}, {1., 450.00000000000006`}]}, {{1., 
               500.00000000000006`}, 
               Offset[{2., 0}, {1., 500.00000000000006`}]}, {{1., 550.}, 
               Offset[{2., 0}, {1., 550.}]}, {{1., 650.}, 
               Offset[{2., 0}, {1., 650.}]}, {{1., 700.}, 
               Offset[{2., 0}, {1., 700.}]}, {{1., 750.}, 
               Offset[{2., 0}, {1., 750.}]}, {{1., 850.}, 
               Offset[{2., 0}, {1., 850.}]}, {{1., 900.0000000000001}, 
               Offset[{2., 0}, {1., 900.0000000000001}]}, {{1., 
               950.0000000000001}, 
               Offset[{2., 0}, {1., 950.0000000000001}]}}]}}, 
          {GrayLevel[0.45], 
           DynamicBox[Directive[
             CurrentValue[{GraphicsBoxOptions, LabelStyle}]],
            
            ImageSizeCache->{{
             4.503599627370496*^15, -4.503599627370496*^15}, {
             4.503599627370496*^15, -4.503599627370496*^15}}], {{{}, {}, {}, \
{}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}}}, {}}}},
        Antialiasing->False], "GraphicsAxes",
       StripOnInput->False], 
      StyleBox[
       StyleBox[{
         {GrayLevel[0.45], 
          LineBox[{{2., -200.}, {2., 1000.0000000000001`}}]}, {{
           {GrayLevel[0.45], 
            LineBox[{{{2., -200.}, Offset[{4., 0}, {2., -200.}]}, {{2., 0.}, 
               Offset[{4., 0}, {2., 0.}]}, {{2., 200.}, 
               Offset[{4., 0}, {2., 200.}]}, {{2., 400.}, 
               Offset[{4., 0}, {2., 400.}]}, {{2., 600.}, 
               Offset[{4., 0}, {2., 600.}]}, {{2., 800.}, 
               Offset[{4., 0}, {2., 800.}]}, {{2., 1000.0000000000001`}, 
               Offset[{4., 0}, {2., 1000.0000000000001`}]}}]}, 
           {GrayLevel[0.45], 
            LineBox[{{{2., -150.}, Offset[{2., 0}, {2., -150.}]}, {{
               2., -100.}, Offset[{2., 0}, {2., -100.}]}, {{2., -50.}, 
               Offset[{2., 0}, {2., -50.}]}, {{2., 50.}, 
               Offset[{2., 0}, {2., 50.}]}, {{2., 100.}, 
               Offset[{2., 0}, {2., 100.}]}, {{2., 150.}, 
               Offset[{2., 0}, {2., 150.}]}, {{2., 250.00000000000003`}, 
               Offset[{2., 0}, {2., 250.00000000000003`}]}, {{2., 300.}, 
               Offset[{2., 0}, {2., 300.}]}, {{2., 350.}, 
               Offset[{2., 0}, {2., 350.}]}, {{2., 450.00000000000006`}, 
               Offset[{2., 0}, {2., 450.00000000000006`}]}, {{2., 
               500.00000000000006`}, 
               Offset[{2., 0}, {2., 500.00000000000006`}]}, {{2., 550.}, 
               Offset[{2., 0}, {2., 550.}]}, {{2., 650.}, 
               Offset[{2., 0}, {2., 650.}]}, {{2., 700.}, 
               Offset[{2., 0}, {2., 700.}]}, {{2., 750.}, 
               Offset[{2., 0}, {2., 750.}]}, {{2., 850.}, 
               Offset[{2., 0}, {2., 850.}]}, {{2., 900.0000000000001}, 
               Offset[{2., 0}, {2., 900.0000000000001}]}, {{2., 
               950.0000000000001}, 
               Offset[{2., 0}, {2., 950.0000000000001}]}}]}}, 
          {GrayLevel[0.45], 
           DynamicBox[Directive[
             CurrentValue[{GraphicsBoxOptions, LabelStyle}]],
            
            ImageSizeCache->{{
             4.503599627370496*^15, -4.503599627370496*^15}, {
             4.503599627370496*^15, -4.503599627370496*^15}}], {{{}, {}, {}, \
{}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}}}, {}}}},
        Antialiasing->False], "GraphicsAxes",
       StripOnInput->False], 
      StyleBox[
       StyleBox[{
         {GrayLevel[0.45], 
          LineBox[{{3., -200.}, {3., 1000.0000000000001`}}]}, {{
           {GrayLevel[0.45], 
            LineBox[{{{3., -200.}, Offset[{4., 0}, {3., -200.}]}, {{3., 0.}, 
               Offset[{4., 0}, {3., 0.}]}, {{3., 200.}, 
               Offset[{4., 0}, {3., 200.}]}, {{3., 400.}, 
               Offset[{4., 0}, {3., 400.}]}, {{3., 600.}, 
               Offset[{4., 0}, {3., 600.}]}, {{3., 800.}, 
               Offset[{4., 0}, {3., 800.}]}, {{3., 1000.0000000000001`}, 
               Offset[{4., 0}, {3., 1000.0000000000001`}]}}]}, 
           {GrayLevel[0.45], 
            LineBox[{{{3., -150.}, Offset[{2., 0}, {3., -150.}]}, {{
               3., -100.}, Offset[{2., 0}, {3., -100.}]}, {{3., -50.}, 
               Offset[{2., 0}, {3., -50.}]}, {{3., 50.}, 
               Offset[{2., 0}, {3., 50.}]}, {{3., 100.}, 
               Offset[{2., 0}, {3., 100.}]}, {{3., 150.}, 
               Offset[{2., 0}, {3., 150.}]}, {{3., 250.00000000000003`}, 
               Offset[{2., 0}, {3., 250.00000000000003`}]}, {{3., 300.}, 
               Offset[{2., 0}, {3., 300.}]}, {{3., 350.}, 
               Offset[{2., 0}, {3., 350.}]}, {{3., 450.00000000000006`}, 
               Offset[{2., 0}, {3., 450.00000000000006`}]}, {{3., 
               500.00000000000006`}, 
               Offset[{2., 0}, {3., 500.00000000000006`}]}, {{3., 550.}, 
               Offset[{2., 0}, {3., 550.}]}, {{3., 650.}, 
               Offset[{2., 0}, {3., 650.}]}, {{3., 700.}, 
               Offset[{2., 0}, {3., 700.}]}, {{3., 750.}, 
               Offset[{2., 0}, {3., 750.}]}, {{3., 850.}, 
               Offset[{2., 0}, {3., 850.}]}, {{3., 900.0000000000001}, 
               Offset[{2., 0}, {3., 900.0000000000001}]}, {{3., 
               950.0000000000001}, 
               Offset[{2., 0}, {3., 950.0000000000001}]}}]}}, 
          {GrayLevel[0.45], 
           DynamicBox[Directive[
             CurrentValue[{GraphicsBoxOptions, LabelStyle}]],
            
            ImageSizeCache->{{
             4.503599627370496*^15, -4.503599627370496*^15}, {
             4.503599627370496*^15, -4.503599627370496*^15}}], {{{}, {}, {}, \
{}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}}}, {}}}},
        Antialiasing->False], "GraphicsAxes",
       StripOnInput->False], 
      StyleBox[
       StyleBox[{
         {GrayLevel[0.45], 
          LineBox[{{4., -200.}, {4., 1000.0000000000001`}}]}, {{
           {GrayLevel[0.45], 
            LineBox[{{{4., -200.}, Offset[{4., 0}, {4., -200.}]}, {{4., 0.}, 
               Offset[{4., 0}, {4., 0.}]}, {{4., 200.}, 
               Offset[{4., 0}, {4., 200.}]}, {{4., 400.}, 
               Offset[{4., 0}, {4., 400.}]}, {{4., 600.}, 
               Offset[{4., 0}, {4., 600.}]}, {{4., 800.}, 
               Offset[{4., 0}, {4., 800.}]}, {{4., 1000.0000000000001`}, 
               Offset[{4., 0}, {4., 1000.0000000000001`}]}}]}, 
           {GrayLevel[0.45], 
            LineBox[{{{4., -150.}, Offset[{2., 0}, {4., -150.}]}, {{
               4., -100.}, Offset[{2., 0}, {4., -100.}]}, {{4., -50.}, 
               Offset[{2., 0}, {4., -50.}]}, {{4., 50.}, 
               Offset[{2., 0}, {4., 50.}]}, {{4., 100.}, 
               Offset[{2., 0}, {4., 100.}]}, {{4., 150.}, 
               Offset[{2., 0}, {4., 150.}]}, {{4., 250.00000000000003`}, 
               Offset[{2., 0}, {4., 250.00000000000003`}]}, {{4., 300.}, 
               Offset[{2., 0}, {4., 300.}]}, {{4., 350.}, 
               Offset[{2., 0}, {4., 350.}]}, {{4., 450.00000000000006`}, 
               Offset[{2., 0}, {4., 450.00000000000006`}]}, {{4., 
               500.00000000000006`}, 
               Offset[{2., 0}, {4., 500.00000000000006`}]}, {{4., 550.}, 
               Offset[{2., 0}, {4., 550.}]}, {{4., 650.}, 
               Offset[{2., 0}, {4., 650.}]}, {{4., 700.}, 
               Offset[{2., 0}, {4., 700.}]}, {{4., 750.}, 
               Offset[{2., 0}, {4., 750.}]}, {{4., 850.}, 
               Offset[{2., 0}, {4., 850.}]}, {{4., 900.0000000000001}, 
               Offset[{2., 0}, {4., 900.0000000000001}]}, {{4., 
               950.0000000000001}, 
               Offset[{2., 0}, {4., 950.0000000000001}]}}]}}, 
          {GrayLevel[0.45], 
           DynamicBox[Directive[
             CurrentValue[{GraphicsBoxOptions, LabelStyle}]],
            
            ImageSizeCache->{{
             4.503599627370496*^15, -4.503599627370496*^15}, {
             4.503599627370496*^15, -4.503599627370496*^15}}], {{{}, {}, {}, \
{}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}}}, {}}}},
        Antialiasing->False], "GraphicsAxes",
       StripOnInput->False]},
     Antialiasing->False]}, 
   {AbsoluteThickness[0.1], 
    StyleBox[
     StyleBox[
      StyleBox[{
        {GrayLevel[0.45], LineBox[{{0., 0.}, {5., 0.}}]}, {{
          {GrayLevel[0.45], 
           LineBox[{{{0., 0.}, Offset[{0, -4.}, {0., 0.}]}, {{1., 0.}, 
              Offset[{0, -4.}, {1., 0.}]}, {{2., 0.}, 
              Offset[{0, -4.}, {2., 0.}]}, {{3., 0.}, 
              Offset[{0, -4.}, {3., 0.}]}, {{4., 0.}, 
              Offset[{0, -4.}, {4., 0.}]}, {{5., 0.}, 
              Offset[{0, -4.}, {5., 0.}]}}]}, 
          {GrayLevel[0.45], 
           LineBox[{{{0.2, 0.}, Offset[{0, -2.}, {0.2, 0.}]}, {{0.4, 0.}, 
              Offset[{0, -2.}, {0.4, 0.}]}, {{0.6, 0.}, 
              Offset[{0, -2.}, {0.6, 0.}]}, {{0.8, 0.}, 
              Offset[{0, -2.}, {0.8, 0.}]}, {{1.2, 0.}, 
              Offset[{0, -2.}, {1.2, 0.}]}, {{1.4, 0.}, 
              Offset[{0, -2.}, {1.4, 0.}]}, {{1.6, 0.}, 
              Offset[{0, -2.}, {1.6, 0.}]}, {{1.8, 0.}, 
              Offset[{0, -2.}, {1.8, 0.}]}, {{2.2, 0.}, 
              Offset[{0, -2.}, {2.2, 0.}]}, {{2.4, 0.}, 
              Offset[{0, -2.}, {2.4, 0.}]}, {{2.6, 0.}, 
              Offset[{0, -2.}, {2.6, 0.}]}, {{2.8, 0.}, 
              Offset[{0, -2.}, {2.8, 0.}]}, {{3.2, 0.}, 
              Offset[{0, -2.}, {3.2, 0.}]}, {{3.4, 0.}, 
              Offset[{0, -2.}, {3.4, 0.}]}, {{3.6, 0.}, 
              Offset[{0, -2.}, {3.6, 0.}]}, {{3.8, 0.}, 
              Offset[{0, -2.}, {3.8, 0.}]}, {{4.2, 0.}, 
              Offset[{0, -2.}, {4.2, 0.}]}, {{4.4, 0.}, 
              Offset[{0, -2.}, {4.4, 0.}]}, {{4.6, 0.}, 
              Offset[{0, -2.}, {4.6, 0.}]}, {{4.8, 0.}, 
              Offset[{0, -2.}, {4.8, 0.}]}}]}}, 
         {GrayLevel[0.45], 
          DynamicBox[Directive[
            CurrentValue[{GraphicsBoxOptions, LabelStyle}]],
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}], {{{}, {}, {}, \
{}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}}}, {}}}},
       Antialiasing->False], "GraphicsAxes",
      StripOnInput->False],
     Antialiasing->False]}},
  AspectRatio->0.4,
  Axes->{True, True},
  AxesOrigin->{0, -200.},
  AxesStyle->Automatic,
  FrameTicks->{{{{-200., 
       FormBox[
        RowBox[{"-", "200.`"}], TraditionalForm]}, {0., 
       FormBox["0.`", TraditionalForm]}, {200., 
       FormBox["200.`", TraditionalForm]}, {400., 
       FormBox["400.`", TraditionalForm]}, {600., 
       FormBox["600.`", TraditionalForm]}, {800., 
       FormBox["800.`", TraditionalForm]}, {1000., 
       FormBox["1000.`", TraditionalForm]}, {-200., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {-150., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {-100., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {-50., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {50., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {100., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {150., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {200., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {250., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {300., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {350., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {400., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {450., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {500., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {550., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {600., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {650., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {700., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {750., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {800., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {850., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {900., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {950., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {1000., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}}, {{-200., 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {200., 
       FormBox["\"\"", TraditionalForm]}, {400., 
       FormBox["\"\"", TraditionalForm]}, {600., 
       FormBox["\"\"", TraditionalForm]}, {800., 
       FormBox["\"\"", TraditionalForm]}, {1000., 
       FormBox["\"\"", TraditionalForm]}, {-200., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {-150., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {-100., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {-50., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {50., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {100., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {150., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {200., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {250., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {300., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {350., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {400., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {450., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {500., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {550., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {600., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {650., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {700., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {750., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {800., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {850., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {900., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {950., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}, {1000., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.0045, 0}}}}, {{{0.5, 
       FormBox["1", TraditionalForm]}, {1.5, 
       FormBox["2", TraditionalForm]}, {2.5, 
       FormBox["3", TraditionalForm]}, {3.5, 
       FormBox["4", TraditionalForm]}, {4.5, 
       FormBox["\"\"", TraditionalForm]}}, {{0.5, 
       FormBox["\"\"", TraditionalForm]}, {1.5, 
       FormBox["\"\"", TraditionalForm]}, {2.5, 
       FormBox["\"\"", TraditionalForm]}, {3.5, 
       FormBox["\"\"", TraditionalForm]}, {4.5, 
       FormBox["\"\"", TraditionalForm]}}}},
  GridLines->{None, None},
  PlotRange->{{0, 5}, All},
  PlotRangeClipping->True,
  Ticks->{{{0.5, 
      FormBox[
       RotationBox[
        RowBox[{"{", "1", "}"}], BoxRotation -> -120.], TraditionalForm]}, {
     1.5, 
      FormBox[
       RotationBox[
        RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}], BoxRotation -> -120.], 
       TraditionalForm]}, {2.5, 
      FormBox[
       RotationBox[
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}], BoxRotation -> -120.], 
       TraditionalForm]}, {3.5, 
      FormBox[
       RotationBox[
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], 
        BoxRotation -> -120.], TraditionalForm]}, {4.5, 
      FormBox[
       RotationBox[
        RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], 
        BoxRotation -> -120.], TraditionalForm]}}, {{-200., 
      FormBox[
       RowBox[{"-", "200.`"}], TraditionalForm]}, {0., 
      FormBox["0.`", TraditionalForm]}, {200., 
      FormBox["200.`", TraditionalForm]}, {400., 
      FormBox["400.`", TraditionalForm]}, {600., 
      FormBox["600.`", TraditionalForm]}, {800., 
      FormBox["800.`", TraditionalForm]}, {1000., 
      FormBox["1000.`", TraditionalForm]}, {-200., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {-150., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {-100., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {-50., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {0., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {50., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {100., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {150., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {200., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {250., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {300., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {350., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {400., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {450., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {500., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {550., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {600., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {650., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {700., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {750., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {800., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {850., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {900., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {950., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}, {1000., 
      FormBox[
       InterpretationBox[
        StyleBox[
         GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
         "CacheGraphics" -> False], 
        Spacer[0]], TraditionalForm], {0.0045, 0}}}},
  TicksStyle->Automatic]], "Output",
 CellChangeTimes->{
  3.52598708155873*^9, 3.525987409197958*^9, 3.5259896303947067`*^9, 
   3.5259899031535473`*^9, 3.525989934305934*^9, {3.5930398570264187`*^9, 
   3.593039881208556*^9}, 3.593041575777775*^9, 3.593044675691914*^9, 
   3.593046197968288*^9, 3.5930462656104307`*^9, 3.593047163075633*^9, 
   3.593048959789455*^9, 3.593049240313435*^9, 3.593055486968162*^9, 
   3.593065050417335*^9, 3.593065104104082*^9, 3.5930977522597437`*^9, 
   3.593136114654663*^9}]
}, Open  ]],

Cell[TextData[{
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is the Trend function for the price of the stock and the rest are noise \
levels:\n"
}], "Text",
 CellChangeTimes->{{3.593055333346265*^9, 3.5930553658691807`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WaveletListPlot", "[", 
  RowBox[{"dwd", ",", 
   RowBox[{"Ticks", "\[Rule]", "Full"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.593040118080717*^9, 3.593040119993412*^9}}],

Cell[BoxData[
 GraphicsBox[{{
    TagBox[
     TooltipBox[{{}, {{}, {}, 
        {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQMSZo17Fke8sa/kfWo65bqag8bxQwksFTC+mcM7
VcbkmXpv7KVPZWusV3R0OCJ+Iu6j9luovJvDx8e6Si8uv7W/HhDnXNnr42CS
+0Xr2rV3UPWBDhBbPtiDuAv/BDu8r3i8Z44zTH+YA6PEw6uiv97ZA2X3tG2K
dHgettGrDsiHmBfjMNG27uKTWW/s2z5JncrOiHfYdbSp/VHbW6j5iQ4v3k5t
UWZ8Yw+S1uhPctDeOMM38uZrqH3JDtqPeQyFM97YA03/JJWV6iCS88luRvEr
qP1pDhZfg+53i72xDwRax+ua4VC+cMH2h/5voO7JdGg2a3aQm/LGHuwNhWyH
u1fnd73Y8NoeAA+slP4=
          "]]}}, {}},
      RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]],
     Annotation[#, {0, 0, 0, 0}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[{{}, {{}, {}, 
        {RGBColor[0.6, 0.24, 0.4428931686004542], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQO5nw/fF5ZmcqjkfWo65bqag0zAozbLNkYo38zh
4NnrFXW3GR2kT2VrrFd0dLgRZJwtqsAGlXdz+OTMnaebwexwPSDOubLXx8FO
9GTlz1x2qPpAh8/aPTt2rGR2AHEX/gl2gNj6wx6iP8zh5/qXJZJbGB2Asnva
NkU6OPYoi9kvgJkX47Bnl/jubZzMDm2fpE5lZ8Q7FKZVqQVVs0LNT3RQ3sAs
Z6fF4gCS1uhPcvCfpd5YzM0GtS/Z4eK9T38CqxkcgKZ/kspKdRD5p6ZxzADm
vzSHLc88bA9XsDgEAq3jdc1w+L9iWaV4MBvUPZkO227vZE/NZIO4WyHb4dLX
1PySX8wOAPAzgCs=
          "]]}}, {}},
      RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]],
     Annotation[#, {0, 0, 0, 1}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[{{}, {{}, {}, 
        {RGBColor[0.6, 0.5470136627990908, 0.24], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQOvYw2P7ZAUdABzFKQdJvTt6JxYLQzlazuEZi34
b+MqBuFHmDjM+zE54y6vCFTe2qF6l1P/ne2iEP4XBwf9guO+E95C9Ue4ODw4
Jvl3rhRU/R53h6B6I/VaOZh+b4crN5iYbZWg/BY/h+xfyh0F7FD9XwIcDNgL
nbWZhCD8ZUEOdic7DITqoOojQiA0gwSE5gpzOBosu7+bCWZfuINM63NxixVQ
fl6kA3fmWpntZ2D+i3Z4cUyLJWw2lH8pxoGJOe7L/klQfkucw3K1+Vcbw6D+
k05wUDHk5P6UCDXvS4KDj3h+U/86qPqziQ6dcwLmr7sO5S9LcviX0y1etB6q
vj7ZQUfq3O2bHjD3pzjUaTV9dZWHmm+Y6jDhTuCtZU+g+rnSHBKXXvEJLYD6
/3Gag/KePeqLAwWg/kt3cF79g4/9CtS8qRkOa+fUzJhxERpfeZkOW67J7NCw
gfLdsxx2zdLa5+oBNU8h2+HH/RvqOieFHACE1olb
          "]]}}, {}},
      RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]],
     Annotation[#, {0, 0, 1}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[{{}, {{}, {}, 
        {RGBColor[0.24, 0.6, 0.33692049419863584`], LineBox[CompressedData["
1:eJxVk38slHEcx9VZiaHLH4p7ngvtphyTsIZrb/K7znVHfv+643BnjbTys9T8
2spZJTKzq9WJWUWkNBr5NWlWi6VyTVZahLUxoqbucc9j69mePfvu+fx4f17v
78dGliGRbzUwMPDUvdT3/8cGxdNq/8gFUyjerHrnPbCmzwQ6nXMOLVaRsOOv
uPZm8XBu9GuCnyFJ/3dE7ulE9p8oAlkiXcRjF2TWtExWLDDx7nAtN0yTVRIY
M3olUDl7oFR57PrwMpMvwHZL9tssEQkr6bMG9jtAqvn7vvE1U88HM3lDSywn
ArrsFm2lLw5YsFan3Jj6/iho/dW3X00inyogDkRRxLDIc57pFwzTjH1dZpVc
bISbH8ccafsj0ZxL9xfCfeV7dIGYhHZUlzAiguW4PMRLxeg5gb7J7jr1DQK6
YEXxgBidmtiIziAOrU+C9AviOeMqa9yiAjShsOjxGixp5dJ6w6BKbrPxCCZB
tRcVnURY9VjNuDtB6w9HdlDPTv5VAlQ5V1kEar0Gjvr2MfNEInu+9eCjcAIN
7Op8K+8odMQt2UnOkPR80bhdW87zv8fBho17Y8BrU82v6XzTzxuL1Kf920p0
flHyp9djIegqzw5hcej543CxcH1LQCgXLRSAT/EYXzRbdqhheCRgfq1JU5dJ
x8cn4uGX+JsB7QTNJxHTg4VDZ3M4+nyhFLXG3k5CF5LmJUV9WbMP7xuhryeQ
wS9OUXaqnuEnw0yD0Hmqk8QOChg/CSEf78Y5ThA0zyQEHtZu/6wk4abDZ8dJ
hpFYvRLQy9yHZAiuPCEX2CQoOdUmctyxbc8IW2V4y3FkYplbUU9ARQn8LYeH
oPn+zxEOzT8FGYoXKXvsSVDp+bMpiOmfdBxzIGk/UrHkax6cwOdgA9eHVOxm
5YVbNRG0P2kIdXoumbXngLJH+jINCSbaXblqxi8FLl9rKT1/iQAld7RDgXJR
nz2vm7mfSjD7p6QANyo390/vZ/rm/v0DbnyMwQ==
          "]]}}, {}},
      RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]],
     Annotation[#, {0, 1}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[{{}, {{}, {}, 
        {RGBColor[0.24, 0.3531726744018182, 0.6], LineBox[CompressedData["
1:eJw1lQtUTVkcxhOL8Si3SJLHZe8maVaKSSWPT0nRU+mpx+1x63YlmhiPjPGY
0kS3oZBBaPSYkZA0hZS1YqZoFD2MvGuqmYRJaUyTZp86+6x11l373HP3/9v/
7/f978yQDe5ydTU1tY3sFj75tWvaAd/IboKt3VUPd9oPLM06MnZLT7WBuB6P
TdnCAwI/i/RZpzbrwk/taKbeeCp+PwOdKq2dN4dR3GGrCwcIHGsP7MvP4e8b
YmL11vbtXQR/Hr7Urwo0RrnSbULMa15vLi49u3awUtsA3xh1+Vqkm2H9od7G
m5P5fvNR5PqH8bVmAu3EseaGu83RE2cxz/c+398CslGhXlNKCTJbqURXaYUL
N1Y+DRpFxXrWSErbnbM2lsLUbknHSI/FmHz5fruWDte/FPmXvgw895Dgea1x
aN9JwFrVbKli9Yb0LMPyE3GnU8oIDHcXu8UeskGqzDz3W0si6rPF03qLyr51
FBuEAgnL8d9FB72tC6mo1w6SvJHmWm0ERc9YgbgVSNSNT77yjuu3x06fs+MW
PSH4qArUa9rggOfunzef6eDnWQnHI5vqmm4QDMoPW4U0j5DZ9aP5+RxRVGyj
nZdAkNy5pbvKxwkpgvxiIp7XGUbDXX9u3UdQd2LESxtnF2R2VBqZpfH+u6Jf
0HuVQDP714gnUjeUZylu2zbyfrhh0P5qggJWTU9/NfYzWhLHULE/qzFuUDCB
p3DpuCPzotBQ3i93DFE2Cx/y9J0OjvdAY8Kul7HZ3F8P7JGU/F5oR3GSyase
vQY6guBw3s81aJ/e3nzPlGCZf67V6BGeyGic8z7OgvfXE1rs57eYny2Xo03t
PnriOcPpkIr32wvdzl0fF6YTDL7+jxfkypKN3s94/72xoqr8wfltFJ+F9k0r
7fJGSq60SeJGRT988NMy54oSxlPN1ZsTP7zywUWNYbfanKjojy82Tv0lZqo9
RawgqM0XqrdjNdMjqOiXH1r7N5uGZxHoKl3UY174YVtTTtfhAO7fWvR1yO6u
IhTX2PZ5TWvR2RsdVnCWin76o6umpyWN5SFIr+lNe70/aoVlFfc3AO+1Hzkq
5lKox5xppTUBqEtlgHhS0e9APPSxvuAZRSHYK6sKRLyZcfL01Zz/IPy2Tqev
VJ9ildSk7kRFEKIXrI+Jp1TkQTbEgzdFr/V2eVSQDN2DgeR8yDDXfWRGNOOj
km2f9FiG74R8FFORl2DsyzfMqWD9PJ4K/1zfYJwX4jCd8xOM9itJ/U81KKLK
fvC+3RAM6+uzo/KmUZGnEMycxIBgfgunbfEIwengf1Ma5FTkKwQvdm2bVG5A
IREaXBuCrAFFQOtbIvIWCqeB2qt3XxAwulZKXUKhr55079gjnt9QaO1nA6KJ
oJDhs+ROKJIsezFjgIg8hqGFxclSkyLhe3YAhzAkC3zUEJHPMOh6O+ypl1L4
3H5vvf1WGCRtDFhXKvIqx47U62WaKyjmCMe1keNvK4878dacXzkmCfPxCwpG
37yiMjn069jEkXKe5UN+nCVg6k3qFoXD/Ip/8bk3nO9wlHZ6fKiKpji1ea9R
V0k4NB58XWjyjvMejstqJnbzMwgEPCQWEWhg46pDRkX+I2D7o4t0OZvHtkKB
wgh4H7W6PvsVEfMQAcu/1p+qYv7rCA01U+BYxDD/pFY+rxTI+PTl4+FfEbQJ
cchXYEbgxAUNLrPEvChwbsInB48zPkrcWEKMI/F6hE1L+AM+3yJRa9pv31FA
kLSjQSM7NxKWBgnuJ8t5niLRkzimQIP9vwjtrDBQYiZL5w4Xni8lvKYsztzD
+DYRgM9UIkcYXxN43pTIDynbQth6cAxJ1+GMoLef4H9PGQJy
          "]]}}, {}},
      RowBox[{"{", "1", "}"}]],
     Annotation[#, {1}, "Tooltip"]& ]}, 
   {AbsoluteThickness[0.1], 
    StyleBox[{
      StyleBox[
       StyleBox[{
         {GrayLevel[0.45], LineBox[{{0., 0.}, {217., 0.}}]}, {{
           {GrayLevel[0.45], 
            LineBox[{{{0., 0.}, Offset[{0, 3.}, {0., 0.}]}, {{50., 0.}, 
               Offset[{0, 3.}, {50., 0.}]}, {{100., 0.}, 
               Offset[{0, 3.}, {100., 0.}]}, {{150., 0.}, 
               Offset[{0, 3.}, {150., 0.}]}, {{200., 0.}, 
               Offset[{0, 3.}, {200., 0.}]}}]}, 
           {GrayLevel[0.45], 
            LineBox[{{{10., 0.}, Offset[{0., 1.5}, {10., 0.}]}, {{20., 0.}, 
               Offset[{0., 1.5}, {20., 0.}]}, {{30., 0.}, 
               Offset[{0., 1.5}, {30., 0.}]}, {{40., 0.}, 
               Offset[{0., 1.5}, {40., 0.}]}, {{60., 0.}, 
               Offset[{0., 1.5}, {60., 0.}]}, {{70., 0.}, 
               Offset[{0., 1.5}, {70., 0.}]}, {{80., 0.}, 
               Offset[{0., 1.5}, {80., 0.}]}, {{90., 0.}, 
               Offset[{0., 1.5}, {90., 0.}]}, {{110., 0.}, 
               Offset[{0., 1.5}, {110., 0.}]}, {{120., 0.}, 
               Offset[{0., 1.5}, {120., 0.}]}, {{130., 0.}, 
               Offset[{0., 1.5}, {130., 0.}]}, {{140., 0.}, 
               Offset[{0., 1.5}, {140., 0.}]}, {{160., 0.}, 
               Offset[{0., 1.5}, {160., 0.}]}, {{170., 0.}, 
               Offset[{0., 1.5}, {170., 0.}]}, {{180., 0.}, 
               Offset[{0., 1.5}, {180., 0.}]}, {{190., 0.}, 
               Offset[{0., 1.5}, {190., 0.}]}, {{210., 0.}, 
               Offset[{0., 1.5}, {210., 0.}]}}]}}, 
          {GrayLevel[0.45], 
           DynamicBox[Directive[
             CurrentValue[{GraphicsBoxOptions, LabelStyle}]],
            
            ImageSizeCache->{{
             4.503599627370496*^15, -4.503599627370496*^15}, {
             4.503599627370496*^15, -4.503599627370496*^15}}], {{{}, {}, {}, \
{}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}}}, {}}}},
        Antialiasing->False], "GraphicsAxes",
       StripOnInput->False], 
      StyleBox[
       StyleBox[{
         {GrayLevel[0.45], LineBox[{{0., 2.5}, {217., 2.5}}]}, {{
           {GrayLevel[0.45], 
            LineBox[{{{0., 2.5}, Offset[{0, 3.}, {0., 2.5}]}, {{50., 2.5}, 
               Offset[{0, 3.}, {50., 2.5}]}, {{100., 2.5}, 
               Offset[{0, 3.}, {100., 2.5}]}, {{150., 2.5}, 
               Offset[{0, 3.}, {150., 2.5}]}, {{200., 2.5}, 
               Offset[{0, 3.}, {200., 2.5}]}}]}, 
           {GrayLevel[0.45], 
            LineBox[{{{10., 2.5}, Offset[{0., 1.5}, {10., 2.5}]}, {{20., 2.5},
                Offset[{0., 1.5}, {20., 2.5}]}, {{30., 2.5}, 
               Offset[{0., 1.5}, {30., 2.5}]}, {{40., 2.5}, 
               Offset[{0., 1.5}, {40., 2.5}]}, {{60., 2.5}, 
               Offset[{0., 1.5}, {60., 2.5}]}, {{70., 2.5}, 
               Offset[{0., 1.5}, {70., 2.5}]}, {{80., 2.5}, 
               Offset[{0., 1.5}, {80., 2.5}]}, {{90., 2.5}, 
               Offset[{0., 1.5}, {90., 2.5}]}, {{110., 2.5}, 
               Offset[{0., 1.5}, {110., 2.5}]}, {{120., 2.5}, 
               Offset[{0., 1.5}, {120., 2.5}]}, {{130., 2.5}, 
               Offset[{0., 1.5}, {130., 2.5}]}, {{140., 2.5}, 
               Offset[{0., 1.5}, {140., 2.5}]}, {{160., 2.5}, 
               Offset[{0., 1.5}, {160., 2.5}]}, {{170., 2.5}, 
               Offset[{0., 1.5}, {170., 2.5}]}, {{180., 2.5}, 
               Offset[{0., 1.5}, {180., 2.5}]}, {{190., 2.5}, 
               Offset[{0., 1.5}, {190., 2.5}]}, {{210., 2.5}, 
               Offset[{0., 1.5}, {210., 2.5}]}}]}}, 
          {GrayLevel[0.45], 
           DynamicBox[Directive[
             CurrentValue[{GraphicsBoxOptions, LabelStyle}]],
            
            ImageSizeCache->{{
             4.503599627370496*^15, -4.503599627370496*^15}, {
             4.503599627370496*^15, -4.503599627370496*^15}}], {{{}, {}, {}, \
{}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}}}, {}}}},
        Antialiasing->False], "GraphicsAxes",
       StripOnInput->False], 
      StyleBox[
       StyleBox[{
         {GrayLevel[0.45], LineBox[{{0., 5.}, {217., 5.}}]}, {{
           {GrayLevel[0.45], 
            LineBox[{{{0., 5.}, Offset[{0, 3.}, {0., 5.}]}, {{50., 5.}, 
               Offset[{0, 3.}, {50., 5.}]}, {{100., 5.}, 
               Offset[{0, 3.}, {100., 5.}]}, {{150., 5.}, 
               Offset[{0, 3.}, {150., 5.}]}, {{200., 5.}, 
               Offset[{0, 3.}, {200., 5.}]}}]}, 
           {GrayLevel[0.45], 
            LineBox[{{{10., 5.}, Offset[{0., 1.5}, {10., 5.}]}, {{20., 5.}, 
               Offset[{0., 1.5}, {20., 5.}]}, {{30., 5.}, 
               Offset[{0., 1.5}, {30., 5.}]}, {{40., 5.}, 
               Offset[{0., 1.5}, {40., 5.}]}, {{60., 5.}, 
               Offset[{0., 1.5}, {60., 5.}]}, {{70., 5.}, 
               Offset[{0., 1.5}, {70., 5.}]}, {{80., 5.}, 
               Offset[{0., 1.5}, {80., 5.}]}, {{90., 5.}, 
               Offset[{0., 1.5}, {90., 5.}]}, {{110., 5.}, 
               Offset[{0., 1.5}, {110., 5.}]}, {{120., 5.}, 
               Offset[{0., 1.5}, {120., 5.}]}, {{130., 5.}, 
               Offset[{0., 1.5}, {130., 5.}]}, {{140., 5.}, 
               Offset[{0., 1.5}, {140., 5.}]}, {{160., 5.}, 
               Offset[{0., 1.5}, {160., 5.}]}, {{170., 5.}, 
               Offset[{0., 1.5}, {170., 5.}]}, {{180., 5.}, 
               Offset[{0., 1.5}, {180., 5.}]}, {{190., 5.}, 
               Offset[{0., 1.5}, {190., 5.}]}, {{210., 5.}, 
               Offset[{0., 1.5}, {210., 5.}]}}]}}, 
          {GrayLevel[0.45], 
           DynamicBox[Directive[
             CurrentValue[{GraphicsBoxOptions, LabelStyle}]],
            
            ImageSizeCache->{{
             4.503599627370496*^15, -4.503599627370496*^15}, {
             4.503599627370496*^15, -4.503599627370496*^15}}], {{{}, {}, {}, \
{}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}}}, {}}}},
        Antialiasing->False], "GraphicsAxes",
       StripOnInput->False], 
      StyleBox[
       StyleBox[{
         {GrayLevel[0.45], LineBox[{{0., 7.5}, {217., 7.5}}]}, {{
           {GrayLevel[0.45], 
            LineBox[{{{0., 7.5}, Offset[{0, 3.}, {0., 7.5}]}, {{50., 7.5}, 
               Offset[{0, 3.}, {50., 7.5}]}, {{100., 7.5}, 
               Offset[{0, 3.}, {100., 7.5}]}, {{150., 7.5}, 
               Offset[{0, 3.}, {150., 7.5}]}, {{200., 7.5}, 
               Offset[{0, 3.}, {200., 7.5}]}}]}, 
           {GrayLevel[0.45], 
            LineBox[{{{10., 7.5}, Offset[{0., 1.5}, {10., 7.5}]}, {{20., 7.5},
                Offset[{0., 1.5}, {20., 7.5}]}, {{30., 7.5}, 
               Offset[{0., 1.5}, {30., 7.5}]}, {{40., 7.5}, 
               Offset[{0., 1.5}, {40., 7.5}]}, {{60., 7.5}, 
               Offset[{0., 1.5}, {60., 7.5}]}, {{70., 7.5}, 
               Offset[{0., 1.5}, {70., 7.5}]}, {{80., 7.5}, 
               Offset[{0., 1.5}, {80., 7.5}]}, {{90., 7.5}, 
               Offset[{0., 1.5}, {90., 7.5}]}, {{110., 7.5}, 
               Offset[{0., 1.5}, {110., 7.5}]}, {{120., 7.5}, 
               Offset[{0., 1.5}, {120., 7.5}]}, {{130., 7.5}, 
               Offset[{0., 1.5}, {130., 7.5}]}, {{140., 7.5}, 
               Offset[{0., 1.5}, {140., 7.5}]}, {{160., 7.5}, 
               Offset[{0., 1.5}, {160., 7.5}]}, {{170., 7.5}, 
               Offset[{0., 1.5}, {170., 7.5}]}, {{180., 7.5}, 
               Offset[{0., 1.5}, {180., 7.5}]}, {{190., 7.5}, 
               Offset[{0., 1.5}, {190., 7.5}]}, {{210., 7.5}, 
               Offset[{0., 1.5}, {210., 7.5}]}}]}}, 
          {GrayLevel[0.45], 
           DynamicBox[Directive[
             CurrentValue[{GraphicsBoxOptions, LabelStyle}]],
            
            ImageSizeCache->{{
             4.503599627370496*^15, -4.503599627370496*^15}, {
             4.503599627370496*^15, -4.503599627370496*^15}}], {{{}, {}, {}, \
{}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}}}, {}}}},
        Antialiasing->False], "GraphicsAxes",
       StripOnInput->False], 
      StyleBox[
       StyleBox[{
         {GrayLevel[0.45], LineBox[{{0., 10.}, {217., 10.}}]}, {{
           {GrayLevel[0.45], 
            LineBox[{{{0., 10.}, Offset[{0, 3.}, {0., 10.}]}, {{50., 10.}, 
               Offset[{0, 3.}, {50., 10.}]}, {{100., 10.}, 
               Offset[{0, 3.}, {100., 10.}]}, {{150., 10.}, 
               Offset[{0, 3.}, {150., 10.}]}, {{200., 10.}, 
               Offset[{0, 3.}, {200., 10.}]}}]}, 
           {GrayLevel[0.45], 
            LineBox[{{{10., 10.}, Offset[{0., 1.5}, {10., 10.}]}, {{20., 10.},
                Offset[{0., 1.5}, {20., 10.}]}, {{30., 10.}, 
               Offset[{0., 1.5}, {30., 10.}]}, {{40., 10.}, 
               Offset[{0., 1.5}, {40., 10.}]}, {{60., 10.}, 
               Offset[{0., 1.5}, {60., 10.}]}, {{70., 10.}, 
               Offset[{0., 1.5}, {70., 10.}]}, {{80., 10.}, 
               Offset[{0., 1.5}, {80., 10.}]}, {{90., 10.}, 
               Offset[{0., 1.5}, {90., 10.}]}, {{110., 10.}, 
               Offset[{0., 1.5}, {110., 10.}]}, {{120., 10.}, 
               Offset[{0., 1.5}, {120., 10.}]}, {{130., 10.}, 
               Offset[{0., 1.5}, {130., 10.}]}, {{140., 10.}, 
               Offset[{0., 1.5}, {140., 10.}]}, {{160., 10.}, 
               Offset[{0., 1.5}, {160., 10.}]}, {{170., 10.}, 
               Offset[{0., 1.5}, {170., 10.}]}, {{180., 10.}, 
               Offset[{0., 1.5}, {180., 10.}]}, {{190., 10.}, 
               Offset[{0., 1.5}, {190., 10.}]}, {{210., 10.}, 
               Offset[{0., 1.5}, {210., 10.}]}}]}}, 
          {GrayLevel[0.45], 
           DynamicBox[Directive[
             CurrentValue[{GraphicsBoxOptions, LabelStyle}]],
            
            ImageSizeCache->{{
             4.503599627370496*^15, -4.503599627370496*^15}, {
             4.503599627370496*^15, -4.503599627370496*^15}}], {{{}, {}, {}, \
{}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}}}, {}}}},
        Antialiasing->False], "GraphicsAxes",
       StripOnInput->False]},
     Antialiasing->False]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesOrigin->{0, -2.5},
  AxesStyle->Automatic,
  FrameTicks->{{{{-2.5, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {2.5, 
       FormBox["4", TraditionalForm]}, {5., 
       FormBox["3", TraditionalForm]}, {7.5, 
       FormBox["2", TraditionalForm]}, {10., 
       FormBox["1", TraditionalForm]}}, {{-2.5, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {2.5, 
       FormBox["\"\"", TraditionalForm]}, {5., 
       FormBox["\"\"", TraditionalForm]}, {7.5, 
       FormBox["\"\"", TraditionalForm]}, {10., 
       FormBox["\"\"", TraditionalForm]}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  PlotRange->{All, {-2.5, 12.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, {{-2.5, 
      FormBox["\"\"", TraditionalForm]}, {0., 
      FormBox[
       RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], 
       TraditionalForm]}, {2.5, 
      FormBox[
       RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], 
       TraditionalForm]}, {5., 
      FormBox[
       RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}], TraditionalForm]}, {7.5, 
      FormBox[
       RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}], TraditionalForm]}, {10., 
      FormBox[
       RowBox[{"{", "1", "}"}], TraditionalForm]}}},
  TicksStyle->Automatic]], "Output",
 CellChangeTimes->{3.593040120507413*^9, 3.593044677724677*^9, 
  3.593046199057144*^9, 3.593046266976913*^9, 3.593047164325796*^9, 
  3.593048960855377*^9, 3.593049242847094*^9, 3.593055488969075*^9, 
  3.593065051766212*^9, 3.593065106059142*^9, 3.5930977542026253`*^9, 
  3.5931361169212313`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"dwd", "[", 
   RowBox[{"Automatic", ",", 
    RowBox[{"{", "\"\<ListPlot\>\"", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.593039983317367*^9, 3.5930399872537394`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", "1", "}"}], "\[Rule]", 
    GraphicsBox[{{}, {{}, {}, 
       {RGBColor[0.24, 0.3531726744018182, 0.6], LineBox[CompressedData["
1:eJw9lQlQk0cUx1cULVoRUYcCFSIioKBg1VIU2IdK5RKQ+zKJQDgC00CRYmlH
4oXWAyvqYK0CtSOljhU8xgOkGy+oYAeQs6ASEAPIHbyQSrpfvp1mJpP5z77Z
997//d5mUbQsQKKDEEqhX+73/8+HnWVuzyrIjlfVrTs3aXCp0FCSf9oQeD0H
0HxNpqV1OYlwPGVRkG4EKJSMFqXfw/y5OaAEzZZPTHJxDVUlhxeDXM+o0XH7
AIu3BiQ119mSfIf0nbz8IUdoC8glKy6/sJLlswcBuN3uWTQd9i5VhzueWgmo
1+xCXk8tu28VyKP9OvQdHxPDA7PWWO9aA/IpeF+89Cm73xGQ+wybHUdekHMq
SwMjqROgqKzbj6ZcxXy+daAQHl/mcFKNHdxd+6cHurB+alj9GJCV5nx56D9E
WW8bM3EWAIkLknWDHhO+HjcAnxavsrvdxHrXTf+03PVQul0UfdcAKfj6NoA8
sUY4TzKKZVyC7I0gj9rfG9Hchfl63QF9w8XXkesdNMF3XwIa2Hn0wh+E1b8J
kGuH9+W4ZjKZIzRul3kA+jTLIAVXs348Qe6VIfnt326iLT/Wi9V7i/XnDYqQ
8nbRoTFyZDDjVXWYD4BTVdX0PhXh+90M4jBZbGnYGGk8M61r/WZfWm9GedPW
Uea/HyhcuPwqol/0V/xTgT/ItfnbmB9Ub5/xu4u5klyh2YxNtwAy1PKAeX+o
Hv9z2DRgiARznwUB1F+/j0w39jO/AsBj8yqT7Pz5ivGLpj7H5gQCGM1pgLr3
bL6BNP/+XLt0FT5Ly/tbLwjEKWNr2w6NMD+DAGR5SfqlSOEWVeykNy0YQCJy
tFV2Mn+DAc3OetGq/wh3X/3KwX0yGAq3vV1y0F3N/A4Bsaxf3+fGCNGGvwsB
5G1+0WJWE/M/FAQhMRbtP41hu5iJhRXqUAABbj9Z04f5eYQB8tdY7eq7iuvK
7swfHwgDuY3s+cvKXszPJxwQ7zdO4wrqCYdCbb0jmJ9XBMh1CqSZDoPESOqr
k9oZAfC+0vSC1RCbXyTI19aOnahoxuX0+ovtkSAwqUpt3f8e8/OMAjTE8VKL
Rcbtw71NUWx+nWy+WwG9Fc7UO/wM66T+orKs2wowd9OTw7J+zM9bCIUJaedz
0kYxN15xtRCQmf2eby1eMv5FII/l/KzHXoIVjWfuiwCt1tQFHGjBPA9igI+t
7YIWDuC36zIlySIxIMAr79upGB9Uf635vsRLSR7S6w8+oXqy7YfZZR8wz8s2
ALOO17t1X+Kfj0NUcfg2QEGcnw2MH6rjuPx3cDL5NbSymerIWs97Zg2Y5yma
nt8YKanvxFy33YHRoEz1m1kUP4J5vqJBvtz+kkFgKzbgDK6n8eHa94nwvMWA
XPteNRBKl6fAl2r7o8cXG7cSnr8Y2m/JhqikFnKN4uNaQ7WYe892E57HWEDR
3HtwF2efpg14xIL8te+Vga5nhOeTnnvKnIxtmnBY5Zt1mQ/ouSDvhElFH+Z5
lQBybjFfnKvCy7h210tAEZ7xo+vy54xfCYjFw+MTKWpM6fvsOqHx3rVmdkON
jGcaj3pqunYMElr9ikbnOEAeHL8PGN9xdB9mnRhsHcUF6XuWqm/R89SCvDN7
FYx3qoezy7/YPUw4PAwc4wFGXSPqnIYxz388oLXmuw61VZINXIJrVFsVKIqP
PST8PtD4meao0mMAL+AMXZkAcq3/dey9otqzSn3W+DXp4dbhUgLcTMh3Jqlz
Ffy+JIAgLfTz1c5KcsufbohtIiBd0ZrC20/Y+5YIYhujZXFNveTg982zi4oT
QalWdwlmaNg+JXL7N9F3cx/m7Ly/RApKy1ARePax/ZKCPKHK41HmKF7BAX9O
CgaRS3OSdKcq+H2TQmFEfaNq3lSF9r9OkATo3aTlmwf55D/PnjMZ
         "]]}}, {}},
     AspectRatio->0.4,
     AxesLabel->{None, None},
     AxesOrigin->{0, 0.},
     AxesStyle->Automatic,
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     Method->{},
     PlotRange->{{0, 217.}, {-38, 848}},
     PlotRangeClipping->True,
     PlotRangePadding->{{4.34, 4.34}, {0., 0.}},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", 
    GraphicsBox[{{}, {{}, {}, 
       {RGBColor[0.24, 0.6, 0.33692049419863584`], LineBox[CompressedData["
1:eJw9k11Ik2EUx5+UqCblJxSitpRCwUDKRLLx/otQEcVtffkxbc42N8MaXkXe
jNIuAvMiEOqiBpV6VV4ELgjeN0srVEgsTbKclFhaMivTirRz9rx6YIyznY//
+Z3z7HKctzojhBB59OHvNXuR0jI3/D0NzdO38svmt8IcoB8ytmvST4Z9Md3W
Vr2kpGUuZfc27oF4Njg4WHxPkf/vhdFKCZO/1cZSini4D8H4+wVT7RGQ8Tnw
G8bueL+F1NebB0ytWQfhnbMEUvIi9X4mgNyWp5+VxJpHnbGjgOB+qR/0ekdg
TqB6NqFRdvfE9aPQWOBAUNeTDyOVN3UsK01cwFII4XGRPdf7FcHHrjsa4fDo
YnhvkO3eqPcvgSiYupjg+qJMjFDCUCmC3C/il67HDHGtdzH9cUilYE9znwUX
uF58rCb1WeE20YDJO7TbHHD3GLpIjmE+BlLvcYDrpc4o3L708gmIm9S/fFWV
+k9CYz0NCyqXy3acgsbzn1vR5ymDn/Mdf9TO2PamxMPl8NvaeheXFxQ5XwWC
zQQ0ZNDCyzRWQiS1zFly+1Q5rw0iSIKudigsf3rFhi6SNzYcr++3Cmae32tA
NwN4Xw37frKeJZ3HacSwvzNaxlfbId5QvaIZVfKxw8fzX9qmhfNLaiB4n5WT
iuRFPu8/+ZUarmdywMjzbojS+TmgsZ6Cf8oWBpZZC98DEvRzVJU8a+FfJesM
KQcIX1rSGYghur9DH1XJl3zmU9GvsJz2KCdEBgFqiITk7QSqiFfWV7WVBf51
Sj3jmzTJ3wXxhICvvlU4vWnWBR/zt75T5D7qIPi+cuO0MK7xOmjMq39Wlftx
o5BwByriNF5PzUs3UMj3NK/vywONzsfW80NluSMBD8QVis/5pN9nPdbeXz0D
7qpff39yn2fX399/aly2Uw==
         "]]}}, {}},
     AspectRatio->0.4,
     AxesLabel->{None, None},
     AxesOrigin->{0, 0.},
     AxesStyle->Automatic,
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     Method->{},
     PlotRange->{{0, 217.}, {-38, 848}},
     PlotRangeClipping->True,
     PlotRangePadding->{{4.34, 4.34}, {0., 0.}},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "1"}], "}"}], "\[Rule]", 
    GraphicsBox[{{}, {{}, {}, 
       {RGBColor[0.6, 0.5470136627990908, 0.24], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQMzjK9I1+7VOADmKEg7KNws+f1oOSOUr+3QcGFH
WFa8sgOYH2HiwLAn73XI5LP2EHlrhwchubttgmQh8l8cHBjS1566ufLyfoh6
FwcGsdqU7uQ7EPV73B0alpwsDXd6ANXv7cDg3xBt7vQIwm/xc5jQy/Rt3UQB
iP1fAhwsvlQyKf1TgPCXBTksaDnLfe4cA9Q9IQ4RdypOLxYwhPC5whwYFvR8
Ytu5FGpfuIPD7UlFgblsEPm8SAeG+ufbkiNfQ9ynEO1wQL6fJfj6Lwj/UoxD
w4mkLVmKfyH8ljiHB/oXCx9dEYPol05wcFDnkT0k+wti/pcEhwMFPs95t3+F
qD+b6NDQlZpj1PAUwl+W5OBQu+Tp12R2iP76ZIcDj7V8zud8huiPSHFYkHCn
KlBNGCJvmOrA4LNWTVP7LkQ/V5rDh1s5HgFLpCD+f5zmkPOdp29rhj6Evyfd
IcHrnUGDCw9E/9QMB4nf+9ey8GpA/ZvpsOAmb+4nQWj8uWc5XHBLjPnsLwuN
32yHDe+4Klx3iBwAAHsAoP8=
         "]]}}, {}},
     AspectRatio->0.4,
     AxesLabel->{None, None},
     AxesOrigin->{0, 0.},
     AxesStyle->Automatic,
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     Method->{},
     PlotRange->{{0, 217.}, {-38, 848}},
     PlotRangeClipping->True,
     PlotRangePadding->{{4.34, 4.34}, {0., 0.}},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], "\[Rule]", 
    GraphicsBox[{{}, {{}, {}, 
       {RGBColor[0.6, 0.24, 0.4428931686004542], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQMSMf1KsqsUD1TyPjWdcl3NYUOBbZe1mDqUb+bw
48wZHv7fygekT2VrrFd0dNgQ07/o4kVlB4i8m0PCdjlXe3m2A9cD4pwre30c
HiwuiK3/re8AUR/o0FBo27VG5ed+EHfhn2CHPe4Pn81f5gQ1P8zBo1rELi9L
9QBQdk/bpkiHhvXuib3Pf++HmBfj4HB9sUHJR8EDbZ+kTmVnxDsUiKx7vmqR
NNT8RAcGY2PjZ/Ne2IOkNfqTHCxE1pVnCio7QOxLdmh5HfhibrrBAaDpn6Sy
Uh0q0tK+SRhrQe1Pc2CoElm3YgajQyDQOl7XDIcbiwv21q5VdYC4J9Nhx+vA
G5W1ag7gwFLIdmBY8TqQ4/bO/QCEI42s
         "]]}}, {}},
     AspectRatio->0.4,
     AxesLabel->{None, None},
     AxesOrigin->{0, 0.},
     AxesStyle->Automatic,
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     Method->{},
     PlotRange->{{0, 217.}, {-38, 848}},
     PlotRangeClipping->True,
     PlotRangePadding->{{4.34, 4.34}, {0., 0.}},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], "\[Rule]", 
    GraphicsBox[{{}, {{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQM81xef761od6jkfWo65bqag/i66c86JsH4Zg6P
qloa9oW2O0ifytZYr+jooBUz/VCzegdU3s2h+fVHwembOhyuB8Q5V/b6OCwt
uJv9p6MTqj7QwfOhkSpXfZcDiLvwT7DDd40132SsYfrDHI5+nSGms6zTASi7
p21TpIPHQ6MpTUA+xLwYhxqRf9sz17c7tH2SOpWdEe/Qf2ju3gtFHVDzEx2O
fJ3hKGXQ7gCS1uhPcpBvPfxXnb8dal+yw43FE5aGtrY7AE3/JJWV6lApYnfr
3bNWqP1pDj80XDiuOLY7BAKt43XNcDA2fpzmW9gOdU+mw4Uzf6rPrmx3AAeW
QrbDWnfGy6vftjkAAIyFkg0=
         "]]}}, {}},
     AspectRatio->0.4,
     AxesLabel->{None, None},
     AxesOrigin->{0, 0.},
     AxesStyle->Automatic,
     FrameTicks->{{Append[
         N[
          FindDivisions[{
            SlotSequence[1]}, 4]], {
          Mean[{
            SlotSequence[1]}], 
          Invisible["-1234"], {0, 0}}]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }, {N[
         FindDivisions[{
           SlotSequence[1]}, 5]]& , Map[{#, 
          Spacer[{0, 0}]}& , 
         FindDivisions[{
           SlotSequence[1]}, 4]]& }},
     ImageSize->Scaled[0.2],
     Method->{},
     PlotRange->{{0, 217.}, {-38, 848}},
     PlotRangeClipping->True,
     PlotRangePadding->{{4.34, 4.34}, {0., 0.}},
     Ticks->{N[
        FindDivisions[{
          SlotSequence[1]}, 5]]& , Append[
        N[
         FindDivisions[{
           SlotSequence[1]}, 4]], {
         Mean[{
           SlotSequence[1]}], 
         Invisible["-1234"], {0, 0}}]& },
     TicksStyle->Automatic]}]}], "}"}]], "Output",
 CellChangeTimes->{3.593039987919731*^9, 3.593046200933848*^9, 
  3.5930462690053463`*^9, 3.593047166052305*^9, 3.593048961832234*^9, 
  3.5930492444900723`*^9, 3.593065053795683*^9, 3.593065106969036*^9, 
  3.593097756164702*^9, 3.593136118782859*^9}]
}, Open  ]],

Cell["\<\

See which Wavelet index contributes most to the price function:\
\>", "Text",
 CellChangeTimes->{{3.593055375815383*^9, 3.5930553999232473`*^9}, 
   3.5930643912948647`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dwd", "[", "\"\<EnergyFraction\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", "1", "}"}], "\[Rule]", "0.000012835073028951755`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "\[Rule]", "0.00004751626420557606`"}], 
   ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "1"}], "}"}], "\[Rule]", 
    "0.00011812265305503345`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], "\[Rule]", 
    "0.00025658862406512486`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], "\[Rule]", 
    "0.9995649373856453`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.593039997279001*^9, 3.5930462023363047`*^9, 
  3.593046271123549*^9, 3.593047167588825*^9, 3.593048963801586*^9, 
  3.593049245659313*^9, 3.593055491397694*^9, 3.593065054978551*^9, 
  3.593065109104648*^9, 3.593097757347219*^9, 3.593136122655343*^9}]
}, Open  ]],

Cell[TextData[{
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], "\[Rule]", 
    "0.9995649373856453`"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " clearly indicates that this index includes most of the information about \
the shape of the price function.\n"
}], "Text",
 CellChangeTimes->{{3.5930554172803783`*^9, 3.5930554471175623`*^9}}],

Cell["\<\

Inverse transform the Wavelet attempting to approximating the original price \
function by removing the noise and only taking into account the most \
contribution by the Trend:\
\>", "Text",
 CellChangeTimes->{{3.593055513853663*^9, 3.593055554600547*^9}, {
  3.593072559294095*^9, 3.593072571757618*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"trIBM", " ", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.525987096518916*^9, {3.525987451797399*^9, 3.525987457880879*^9}, {
   3.593048952141203*^9, 3.5930489527878838`*^9}, {3.5930492526296377`*^9, 
   3.593049254569661*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trIBM"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<IBM\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.5259871098149014`*^9, {3.593048969139106*^9, 3.593048969302608*^9}, {
   3.5930554743789787`*^9, 3.5930554765326357`*^9}, {3.593058771842697*^9, 
   3.593058781122308*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1gk4VfkbB3AZDdkzlWXkf0lGskW2eso9pYVsyTI15d7KpGWKkmrCJcrW
lD1LZSnZ6ZIs15JQ+qdBi0ZNpBFxBt2icEXznt+b57mP5/Oc7Xve8/4WzT0+
Lr+Ki4mJvYAf8x/+euvjaCrhoOns3CxvNlhxCMyzlzCdW0TM/iEe7Bo0oVRF
3BEHjg9N32J0j1isFuw6+WhE4gmx8QD4/m2pnoQeYq5iAk31C7aqv6KJY1eB
yyTz8ro/E7OqwfpXZMJSxPczdu4Du58KLJSVJw6RS6QpgysizVWqxHyLROb6
8AGWNnHvbvBbgcZUgyFxpnQS8/zm7WpWxB0rwe6TJ6UM1hOLccCJoZZzp+yJ
jaPAwa7fO/PciRskL9GUypE3g7UcYuEKMLf9/+3l+4lZO8Fup+5I7DuKecPB
7LI75/ecxrx8sGbQQ6+CMGJFo2Samux6HbPmAjF7O7j53ldZ9WRi3zBwxHq9
VxuyMH8xeK0LZ0ZQiPn/Ao98SPcNqCDmuqfQVJzWkFnEXeLYELDe2zUOPY8w
fwFYYH61IqQL8z8DW6tJHjvyFvN/ZY5fDAjOFWL9clNpanmiqGf5DOZ9Ao7T
Oxs7Pe8AyfsFPLJVJXGRMrGvThq8r3TlUKA2sdgNME//9jtxE2LjdnBOldLF
PGti7hS4pqT91WEH4tgll+H58sNPXX4hbnAA53R5+3kcIHZ+BObJrq8JOEkc
8hnMLggqvHOOmM+6QlPvS5VtliQS99qBo5bMP5dzjVjRHyz/9cAR21LizDFw
sI2WmGwDccfiqzT195jVqtE2zL8ZvESuVF3YjfmPgd1jI3Lnj2D+K2D/oLqX
Ll+IhWrpcL9nLhW3ZA6Sem4Ac53Ekl8qEzv7gFVH7wW2sIhDUsF5/Ovep3WI
+U1gheRUjzFdYva6DJqyz8q1N0H7/pbB9NufGy20iTMvge00ZTeKLybuaADL
Je+xS1Aijj2QSVO5xo+30RLEDQlglVGPPZLjmLcuk7nfZ3/6NTFrMJPJX3wx
4QHWWykL3m8msEi8BOsZC15n59VuEYv1rAEPCPZOmPhgP/SDdzsFaI/bYT8o
XAN7vHHw0sN6W4EHniT5hclhPavAwrspSVvHsX//AQdr07faerB/Za/DeBRF
tYm+9a852NDmVH9nPfYvF2w/5/YkpxzH12uwcAVbKrUY54N52TSl9lx1wZkC
7GdT8IMRSl0Fx4+iJ1h0qorleRPHXyS47GSQ5rZKHF/f34D7DcVqTDTi/LAC
XNb+UdnuCc4Pv4BFutfl7Psx/znwg09ZX79MY/6b4HKfWcv187G+hjk0VX+p
qlpjKdb3Z/DAwY4zMRbYz6Fgw+ENcUmbsZ+LwElqqoPGP2P9n4PVPtuG796H
9XXLpak6Xtehn/ywvsHgkPLmlFAe9nM+eHeyvJxfJPbzMzD3p4oHk/j9jGfB
PK+a1h9ScLwF5tFUraPGouar2B85YJWBntx5OH5Yj8HxejMhb7Mx/zRYX/33
LNcczL80n5nPXebtQLPbGEc/mbMfz/edBOv/MRnNy8S8WgXwvPrm7KtpmNce
nKBl4XQvHsdXK7is0in6E+aP/QRW4cm7GwZh3v8Vwnzu71fmg/0ntAXXpvMy
qjmY9zhYNGm0WNYR6/kRHHw2Yrn3KqynehH0D3Xu4UOcrxQ3gTlGy0Tm2J/s
o0VMPfwEhWM4H18GczP2yizD+VNMrRiu1xQNlwiwH2zAvGfmnDWXsR+OgPV3
um0N52E/pIDdqtyaorywnxvBU4MWtzc54HpBldCU8ui0ToMl9vMhcGlLlsqY
DvZzUgnzvsuie5Wxn++A3SbjAyJlsJ9pMMepZ5ieg+vF/puw/p2W6ZGcxvU5
nljN6TWur2J1N5nzZdhHP+F6PJ/P3K+bX4fHhTF85nnxWc0iXI8FfCaPrlI4
3t/5LZ/Jmykujs8PkS+F9WxQdMwS8/EtwZ7WT+/t18TxVQm2+7BsOn4Z1vMN
uGZ2VqnSCPPKlMH9vV3kOk1x/JmB9fW16WEzrDeXsf3x/Fl0bA9zfsu6LdIr
sZ5St5jvH9OuYIzzgwl4y+Md5gp6uL7tAnM42cFSWpg/Ajy1+bfC6W/1nFsO
/XWxrHrwWz2NwbWGJwvaZ3C/swPcrycI4o8Q+54FJ4QGmJ7/mzizBHzfrKaV
04L7HYPbsF6omOq6l2N9PcDr9Po2H7mG+50z4OhDrQZ5ccQNhWCDV/8+/y4U
69/JONDG5owfcYhrBZy/pdOftY+Yz6tg5uP0Q2+2E/fmVTD7o4ylzY64X3sK
vt/Zdf2BDeafASfssRsYXY39EFAJ76cxPmy+EvshB0xJP6/MNMD8HWCtpcKN
+rqYXwTm+qxLe7EE82tXMf37qDSPhf1xHTwaF3MhVYPY+U/wse41UZqLMf8E
OLL1r2y2OubXrGbGx67ezz9i/i1gbkzbahs8njkO1vp1eaUuXt+hIaCp491+
Ltl4fzFbAbN/y5WrxOcb+wmY/V3LIBfzNXxgvPBpX5YO1vPHGuZ7PJz9XQ/z
bgSfqCuyGjLEvL5grbkBie9NMW8amPt+pcIFK6ynai3Mz4Ev8+9aYz3Xg6MK
D3ld2Ij9cBh8PGhwrdAB8yeDS40+nl27DfPfBbMbI81PuWM92XXwPLOibVc9
sJ4HwW6RO18V4/GGRPDLmtSOfLxeWA8ubd9rHIfflzXEHG8STO/dhPX0rofr
U9JNtNZiPePAWg4Kna0mmL8WzP5Hto+7FPMPgEs9kne+WYj5Fe/QlF9xCeUg
gfWNAUf0ucRnC/eR+laDR6fCHN+9JOb2gXOE1ImFTcSxcg00xW/5Y55RPnGD
BdhzomOQiid2rgDfDJZf4MgjDukF3+BuOL/tMDFf+i7sR9P8HV04xL0rwUH6
GbvsXIkVOWBP5caq1fbEmd3gvh09HJ1NxB2SjTQlOzHmIr2BWMwE3PWvePw7
tPFOsK2VzOJ6W8wfDvZ8LTt+wZlYKNFEU4t6JJU9dhCzjMB+Zl/OqXpj/u3g
4/1D7M4TmD+sidlPdWyKjsL8xU3Mfq80zTKDmK3fTFPpto1nam4R+7qDH7/6
bkapBfOHgEVSJ2StX2D+ArBamwrfmsb8nWBD/eF3C0T72P8BkRR3hQ==
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 178.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"IBM\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {178.15751025819225`, 
    209.27970485685407`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.6224438919732365, 
   0.6224438919732365}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.525987111151629*^9, 3.525987414783845*^9, 3.525987454691777*^9, 
   3.5259896382273283`*^9, {3.525989907672782*^9, 3.525989937319051*^9}, 
   3.59304396344473*^9, 3.5930462070294743`*^9, 3.5930462757186613`*^9, {
   3.593047155185935*^9, 3.593047170683908*^9}, 3.593048971407257*^9, {
   3.593049249162848*^9, 3.593049262387473*^9}, 3.593055493849763*^9, 
   3.59305878207342*^9, 3.59306505885712*^9, 3.59306511173241*^9, 
   3.593097760283206*^9, 3.593136127366593*^9}]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["Trend & Similarity ", "Title"]
}], "Text",
 CellChangeTimes->{{3.59306221604949*^9, 3.593062224261135*^9}, {
  3.593064007049602*^9, 3.5930640079931507`*^9}}],

Cell["\<\

Find the Trend curve for two stocks and by using Canberra metric compute the \
distance between the two curves and thus obtain a measure for their \
similarity:\
\>", "Text",
 CellChangeTimes->{{3.5930623446264133`*^9, 3.5930623968258677`*^9}, {
  3.593064011831015*^9, 3.593064012234576*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<ARO\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trARO", " ", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trARO"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<ARO\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593062258543189*^9, 3.593062263176993*^9}, {
  3.593062301270432*^9, 3.5930623066420727`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1glYjGsbB/DpOHFKK10dKZlKZCljLZHmzRbiKyLRMnU+IXWMJaeSjNLC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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 8.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"ARO\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {7.871549284083308, 
    15.923694545328626`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.16104290522490636`, 
   0.16104290522490636`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593062265015524*^9, 3.5930623072911177`*^9, 
  3.5930651143930397`*^9, 3.593097762639517*^9, 3.593118844441408*^9, 
  3.59313613005588*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<BBY\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trBBY", " ", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trBBY"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<BBY\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593062274495164*^9, 3.593062279759499*^9}, {
  3.5930623104730387`*^9, 3.5930623165818644`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1wlYTPsbB/D5I6XIREkhQ0RZGkUyxDmJ6raYe68k67iSKJqk/I2lMZay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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 12.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"BBY\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {12.584878272758806`, 
    44.35256903290285}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.6353538152028808, 
   0.6353538152028808}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593062280506257*^9, 3.59306231729685*^9, 
  3.593065116149786*^9, 3.593097764544602*^9, 3.593118846547811*^9, 
  3.593136132049152*^9}]
}, Open  ]],

Cell["\<\

Find their Canberra distance:
\
\>", "Text",
 CellChangeTimes->{{3.593062403869266*^9, 3.593062413779663*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trARO", ",", "trBBY"}], "]"}]], "Input",
 CellChangeTimes->{{3.593062321361998*^9, 3.5930623273641443`*^9}}],

Cell[BoxData["73.7717035094633`"], "Output",
 CellChangeTimes->{3.593062327906591*^9, 3.593065118661731*^9, 
  3.5930977658535843`*^9, 3.5931361367170773`*^9}]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["Random-Pick  Outlier ", "Title"]
}], "Text",
 CellChangeTimes->{{3.5931284286566877`*^9, 3.593128441593348*^9}}],

Cell["\<\


Now lets choose a random stock that has no Documetric Similarity to any other \
stocks and for that matter use as reference to see if the dis-similarity also \
persists between the price curves:
\
\>", "Text",
 CellChangeTimes->{{3.593057145496395*^9, 3.593057181473404*^9}, {
   3.593057213648673*^9, 3.593057232717692*^9}, {3.593066599839814*^9, 
   3.593066602944742*^9}, 3.5930720682950897`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tr", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<IBM\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AppendTo", "[", 
   RowBox[{"tr", ",", 
    RowBox[{"InverseWaveletTransform", "[", 
     RowBox[{"WaveletThreshold", "[", 
      RowBox[{"dwd", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DateListPlot", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"price", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
       RowBox[{"Last", "[", "tr", "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Frame", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<IBM\>\""}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<ACO\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AppendTo", "[", 
   RowBox[{"tr", ",", 
    RowBox[{"InverseWaveletTransform", "[", 
     RowBox[{"WaveletThreshold", "[", 
      RowBox[{"dwd", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DateListPlot", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"price", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
       RowBox[{"Last", "[", "tr", "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Frame", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<ACO\>\""}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<ALE\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AppendTo", "[", 
   RowBox[{"tr", ",", 
    RowBox[{"InverseWaveletTransform", "[", 
     RowBox[{"WaveletThreshold", "[", 
      RowBox[{"dwd", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DateListPlot", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"price", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
       RowBox[{"Last", "[", "tr", "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Frame", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<ALE\>\""}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<CATM\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AppendTo", "[", 
   RowBox[{"tr", ",", 
    RowBox[{"InverseWaveletTransform", "[", 
     RowBox[{"WaveletThreshold", "[", 
      RowBox[{"dwd", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DateListPlot", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"price", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
       RowBox[{"Last", "[", "tr", "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Frame", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<CATM\>\""}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<ARRY\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AppendTo", "[", 
   RowBox[{"tr", ",", 
    RowBox[{"InverseWaveletTransform", "[", 
     RowBox[{"WaveletThreshold", "[", 
      RowBox[{"dwd", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DateListPlot", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"price", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
       RowBox[{"Last", "[", "tr", "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Frame", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<ARRY\>\""}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<ADBE\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AppendTo", "[", 
   RowBox[{"tr", ",", 
    RowBox[{"InverseWaveletTransform", "[", 
     RowBox[{"WaveletThreshold", "[", 
      RowBox[{"dwd", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DateListPlot", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"price", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
       RowBox[{"Last", "[", "tr", "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Frame", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<ADBE\>\""}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<ACAD\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AppendTo", "[", 
   RowBox[{"tr", ",", 
    RowBox[{"InverseWaveletTransform", "[", 
     RowBox[{"WaveletThreshold", "[", 
      RowBox[{"dwd", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DateListPlot", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"price", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
       RowBox[{"Last", "[", "tr", "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Frame", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<ACAD\>\""}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<ALXA\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AppendTo", "[", 
   RowBox[{"tr", ",", 
    RowBox[{"InverseWaveletTransform", "[", 
     RowBox[{"WaveletThreshold", "[", 
      RowBox[{"dwd", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DateListPlot", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"price", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
       RowBox[{"Last", "[", "tr", "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Frame", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<ALXA\>\""}]}], "]"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<CRIS\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AppendTo", "[", 
   RowBox[{"tr", ",", 
    RowBox[{"InverseWaveletTransform", "[", 
     RowBox[{"WaveletThreshold", "[", 
      RowBox[{"dwd", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DateListPlot", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"price", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
       RowBox[{"Last", "[", "tr", "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Frame", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<CRIS\>\""}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<AVHI\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AppendTo", "[", 
   RowBox[{"tr", ",", 
    RowBox[{"InverseWaveletTransform", "[", 
     RowBox[{"WaveletThreshold", "[", 
      RowBox[{"dwd", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DateListPlot", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"price", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
       RowBox[{"Last", "[", "tr", "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Frame", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<AVHI\>\""}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<ASIA\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AppendTo", "[", 
   RowBox[{"tr", ",", 
    RowBox[{"InverseWaveletTransform", "[", 
     RowBox[{"WaveletThreshold", "[", 
      RowBox[{"dwd", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
      RowBox[{"Last", "[", "tr", "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<ASIA\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593057512071889*^9, 3.593057514466308*^9}, {
  3.5930588188338757`*^9, 3.593058819137897*^9}, {3.593118468818606*^9, 
  3.5931184866938877`*^9}, {3.593118699579877*^9, 3.593118733712487*^9}, {
  3.593119189757586*^9, 3.5931191974626637`*^9}, {3.5931192308650007`*^9, 
  3.5931192380641537`*^9}, {3.593119352579829*^9, 3.593119384304647*^9}, {
  3.593119469297316*^9, 3.593119478107723*^9}, {3.59311956373114*^9, 
  3.593119573025961*^9}, {3.593119648679678*^9, 3.5931196581670322`*^9}, {
  3.593119690272257*^9, 3.593119810160022*^9}, {3.593121552473238*^9, 
  3.5931215618377953`*^9}, {3.593121937101722*^9, 3.593121943666559*^9}, {
  3.593127458294269*^9, 3.5931274640755863`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1gk4VfkbB3AZDdkzlWXkf0lGskW2eso9pYVsyTI15d7KpGWKkmrCJcrW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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 178.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"IBM\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {178.15751025819225`, 
    209.27970485685407`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.6224438919732365, 
   0.6224438919732365}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.59305602138594*^9, 3.593057515697027*^9, 3.593058823132114*^9, 
   3.5930624651328163`*^9, 3.593065120727556*^9, 3.593097768005368*^9, {
   3.593118738150532*^9, 3.5931187545877533`*^9}, 3.593119198890778*^9, 
   3.5931192392589912`*^9, 3.593119358451747*^9, 3.593119388627735*^9, 
   3.593119479447348*^9, 3.593119574721629*^9, 3.593119659125699*^9, 
   3.5931197059758463`*^9, 3.593119743260062*^9, {3.593119781178439*^9, 
   3.5931198109386997`*^9}, 3.5931215632066927`*^9, 3.593121946779056*^9, 
   3.593127465998534*^9, 3.593136139165308*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1ws0VGsbwPEpSaRwSKgYcjsIpVROMltJkVIUlURKpDKRnNzORC6p3Etu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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 28.8},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"ACO\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {28.91050022020938, 
    36.12273055692903}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.144244606734393, 
   0.144244606734393}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.59305602138594*^9, 3.593057515697027*^9, 3.593058823132114*^9, 
   3.5930624651328163`*^9, 3.593065120727556*^9, 3.593097768005368*^9, {
   3.593118738150532*^9, 3.5931187545877533`*^9}, 3.593119198890778*^9, 
   3.5931192392589912`*^9, 3.593119358451747*^9, 3.593119388627735*^9, 
   3.593119479447348*^9, 3.593119574721629*^9, 3.593119659125699*^9, 
   3.5931197059758463`*^9, 3.593119743260062*^9, {3.593119781178439*^9, 
   3.5931198109386997`*^9}, 3.5931215632066927`*^9, 3.593121946779056*^9, 
   3.593127465998534*^9, 3.5931361394486923`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1wk0lPsbB/C52VqoqZxEkSXVkS3EEJnXTZL+XRQiZaQFbcrSciPVpZJu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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 42.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"ALE\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {42.21336677321234, 
    53.18760791144338}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.21948482276462072`, 
   0.21948482276462072`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.59305602138594*^9, 3.593057515697027*^9, 3.593058823132114*^9, 
   3.5930624651328163`*^9, 3.593065120727556*^9, 3.593097768005368*^9, {
   3.593118738150532*^9, 3.5931187545877533`*^9}, 3.593119198890778*^9, 
   3.5931192392589912`*^9, 3.593119358451747*^9, 3.593119388627735*^9, 
   3.593119479447348*^9, 3.593119574721629*^9, 3.593119659125699*^9, 
   3.5931197059758463`*^9, 3.593119743260062*^9, {3.593119781178439*^9, 
   3.5931198109386997`*^9}, 3.5931215632066927`*^9, 3.593121946779056*^9, 
   3.593127465998534*^9, 3.593136139565057*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1ws4lGkbB/BJomwyHRaVGIl8iKkkaredt0I5tLJOnTTVl0MnYkm+/ZjV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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 25.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"CATM\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {24.918374042543597`, 
    39.63747277641903}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.2943819746775087, 
   0.2943819746775087}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.59305602138594*^9, 3.593057515697027*^9, 3.593058823132114*^9, 
   3.5930624651328163`*^9, 3.593065120727556*^9, 3.593097768005368*^9, {
   3.593118738150532*^9, 3.5931187545877533`*^9}, 3.593119198890778*^9, 
   3.5931192392589912`*^9, 3.593119358451747*^9, 3.593119388627735*^9, 
   3.593119479447348*^9, 3.593119574721629*^9, 3.593119659125699*^9, 
   3.5931197059758463`*^9, 3.593119743260062*^9, {3.593119781178439*^9, 
   3.5931198109386997`*^9}, 3.5931215632066927`*^9, 3.593121946779056*^9, 
   3.593127465998534*^9, 3.593136139759775*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1gtcjOkaAPDZkKTLlEq1ZIbQQUS6SOx8SqmsMzlxdKHJJQ1hRButy6St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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 3.9000000000000004`},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"ARRY\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {3.8832476116693595`, 
    6.339222688442098}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.04911950153545478, 
   0.04911950153545478}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.59305602138594*^9, 3.593057515697027*^9, 3.593058823132114*^9, 
   3.5930624651328163`*^9, 3.593065120727556*^9, 3.593097768005368*^9, {
   3.593118738150532*^9, 3.5931187545877533`*^9}, 3.593119198890778*^9, 
   3.5931192392589912`*^9, 3.593119358451747*^9, 3.593119388627735*^9, 
   3.593119479447348*^9, 3.593119574721629*^9, 3.593119659125699*^9, 
   3.5931197059758463`*^9, 3.593119743260062*^9, {3.593119781178439*^9, 
   3.5931198109386997`*^9}, 3.5931215632066927`*^9, 3.593121946779056*^9, 
   3.593127465998534*^9, 3.593136139943036*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1gk0lOsfB/BpsSQxdVvkopGKk9JkiTZn3uytk2yVy+jfikTpXqVlKEtd
528s6So0rqUhMqQYUROhRTdRkaWIpFdpKm4Tqf/v/T1/5zjO57yvZ77ze7/P
M2O444DrrvEsFusF/DJ/4afrVgJN7XMMqx3mOfDA7HfgXHaK52IWmvdLIk3V
Dt8wOF1mz7gxAVw33KY7shvNqgTPdbhy+L4emtsHbusxXvK51Y6xgJ1EUx+f
8J1CL6JFK8A+2gtubdqJ5sjApmmXk05boPk9YLewZ/XTJqGFU5Jp6kVW0baR
3jWMpdbgmwbL1q+sR3f5gZX9e9OeFaHFGudoKmG887r7GehGS3B0QLPXzGQ0
yxfcajS5tjIezT3DXDf9GF+ZgJarpdCUKPKkbMYFtGIp+KtJJXVPguZ4gysM
ckyeVqH50eBY0/1Dx5vQQinYZ9P0nNo+NHvJeZrinb2w4soImrcVvKjjZ6mZ
Fr6/4FNgQwf76XxDtLiQce0eL21LdGMLc7+3f0SgI5mnx1+wnsb6+D1eZJ5C
sM9jzUiWP1qeD469UrDVOhyteAq+mWE6UzOOzPsnWCk5U3YiDd11ORXWe1C3
Or4AzW4CJ47vkayuRPO+gwc3v1SeeUjyLrgAz6e8fHFoG5qVc4F5vaU1Se/Q
3MeMTV1k/UqS9xvY3ean9iF17IfI6CKs92RLvbkOWr4B7K50fGVsguY3XGTW
a/V0tUEL/2U8oL60xBkt5aTB/eUt/k5b0V1rwYNTHVSm+aPZh5nrSj5rWjha
/AUcGzC63SmO9Fc/nbG9Tkk66a9zOnO/qZVrEenvwXRmvZIS4ztoQRpzvfy5
yLwZrdDNYPKkPj74Bs1xAPvGh82685XkPwBuyzq4V18D948wFaw0ia2O0UNL
azKY/sjms5aQ/bXmEk1xolQSoyl0cCDY1Hu/2q9uaHHKJab/iqiq3ehGOV6P
nxJ0BC3aJ4a+RLlkLIpDy5PEzP6YY/MtA62oEjOvz25vLkZz+sXMenoxlXfR
/GmZ0J94+1XXWtBdInDMQMxIGU3Og5uZzPPuu/NgjOR9k8mcB4LEAbYj5tX+
m6aOW6qv7J2LFi9nHNpxs9QCzS0H117vnP6bHVrwGuymnOzYuRkt0syC97Nq
zyYrX7R8GXhtxEfurgC0QgCW1mfTgb+jha+ymPMj5th6IVo6KRvW80rpm3AG
3WUBFv3dZJIkQrN9wDMGV9qNpKB5seCeFU1Wy9PQjao5sL9jz7H4YjRrKXhL
a1SWbRbJvz2HmV+WgUoOyR8F7jn6ISSLWFQE1vSsCPozG80xy6Wp0KpJM6oy
0Xwv8Kyr7Ttt0kn+yFxmPa7PGMkjLQDrmKmN04wn+Z/j/ws27Iwi83W/TFNa
LavsVI+S+Z4E9x69+PpTIMmfB/4mOWZq7EPyPwWv8+vSz91A8v+4zPSxTha0
ksz3mISmLgcv+Sk0JvPNBRfX6w52TCX5n0iY9WKjI0dIP0bBJ6YfuRfSTfo8
P4+mKI331/LrSB/+AfurFuglFpH+KsEj6rLxJmmkv3Pz4fyf+svuQNLPxvXg
dYYVjr5CtOAhWMv6ajYrjPR5GGy95eNJ/iHS5zlXaKr+8PHWjQdJn13AVRle
V0dDSZ9DwbP/EY7zDCf76zO4fcK/TwRRpM96BTQ1kVc+Z3YS6bMTODmynj6Z
TfKHgM8+NLI4JyP5L4L7dB8pvZrQLN1CmpIE16x8OIjm2oObGlS/D2iRPgSB
dxzQ5bqakT78Bfby+tEytp7MuxpcGlPyZdCf9IG6SlO/jy07NT+W9CEAnCH7
MzqT9Ed6DmxWKR3bISd9uA2ep5Lbv6+d9JkGC5MDnG4Mkz7sLaIpO/9xus7a
TjjfRLB/9B7BHBM0qwo80p+uu4qHFkyV0pQiIds5wxOtiAevjwinHYLQnAqw
VtlclsVpNL8XvMziwpldqWihVjGz/7ujOwvRUpti5vw4PvzjNppXBp7A2v/s
/mN0cDe42Em6wLYTLZ5cQlN7dzu9295P8lqBF3qb6xt9InkFJcz+CKlO+ooW
vQQ3Nkx4UTiKlqtfo6kSJ1oQMkbym4MzUudte/md5P8NnFhdcnfoG8kfg04W
lw6hu1RKaSot9cEH/Q9oNhcsdXIr4PaQ/NvAjxuWdrx/TvKfLmXy/Oe46z2S
/2op83ncH+9XhuYuvs58f/qh+JBL5usJlr7NFn9NIfkjwON5HRknYkj+K2Df
TdkDkWEk/zNw3Yyx6In+ZL5uN2DeSX3BE7zJfE/cYPanIO/kRpJfwly/FsA9
QpH8zeBadzVVhSXJPwb2KbJY2Euef2N4Gby+XJHmrk/mmwsujrH1sZ9G8jeC
96nqB0nVSH44+KlFq+IaUsdIn+eVw3lgEneENUTOh6xy5nnoHe6lSZ8fgStP
LF/x/g3p81fGtq/vzSKWGsrgfs1Zhnv6SZ/XyZg+tqxp+0j6OwS2aZ5nFjJK
zjODCvh8fTj22nQyyetSwXx/3OGnMYfkPQQO7NuSp2lN5vkJPKr+pMJ8C5nn
rzehD8vbzh07RPrgCPYIO7CCPk/6EAyeVyuShMvJvC+AVTi2Xdz/92F2JeSL
/aN7koEzztMOPJG1ukB1Czp4P9go6r884zi0+DxY+/zbqZY16MY74DorZ85i
JVrAq4L95ScNmGbqgvP0B1+azRnq2Y6WJ4Nv+ZyXZZ5FK26B87gzK9eVoTnv
wH7xaaPd3Wjpnls09fbowrCdGmtxnglgmy+3lzZz0exKsKfS28TMHc3rA9ud
Hed9+A90MPs2vD9JYYPkPJoVDxa6+R29dx3NlYGb4/R2PX2CFvSAP29+Fdcw
gBZNkdNUZ1beJ+mEdZjfGhwR+l4kmIHm3wC/rLns385BC7vAnxPaTxguQEs1
7tDU7Zcxj8zno7sswfb5BR7aBmi2LzhyyEW3jI0Wd4LDqnx1Fo7h6zeqVTPn
4SB/bw/Jb17NnN9DNSE1JL83OJ8dGuKYTvJHgyOeBmztC0YrJtbA85rVEb7Z
Fs1ZAvZovdsao4LmbwV76iwIPlOH8xaeYu5v+Ul5RJD5F4KF0103DlqheYvu
wvmu5q+M+UD64QHOkzrxjCSkH0Kwn/bAfPku0o98cLuRW57PAjTrGVhnMPLB
j3dOvP8BYJ5iMw==
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 37.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"ADBE\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {37.122948294105015`, 
    54.2978972026939}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.34349897817177777`, 
   0.34349897817177777`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.59305602138594*^9, 3.593057515697027*^9, 3.593058823132114*^9, 
   3.5930624651328163`*^9, 3.593065120727556*^9, 3.593097768005368*^9, {
   3.593118738150532*^9, 3.5931187545877533`*^9}, 3.593119198890778*^9, 
   3.5931192392589912`*^9, 3.593119358451747*^9, 3.593119388627735*^9, 
   3.593119479447348*^9, 3.593119574721629*^9, 3.593119659125699*^9, 
   3.5931197059758463`*^9, 3.593119743260062*^9, {3.593119781178439*^9, 
   3.5931198109386997`*^9}, 3.5931215632066927`*^9, 3.593121946779056*^9, 
   3.593127465998534*^9, 3.5931361401794662`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1gtYjGkbB/D5VM7ViKXSYRSJktFJsX3mDYsKg44qjT6yyWFKxSaMpaj4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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 5.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"ACAD\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {4.717558515281419, 
    26.64732339343058}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.4385952975629832, 
   0.4385952975629832}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.59305602138594*^9, 3.593057515697027*^9, 3.593058823132114*^9, 
   3.5930624651328163`*^9, 3.593065120727556*^9, 3.593097768005368*^9, {
   3.593118738150532*^9, 3.5931187545877533`*^9}, 3.593119198890778*^9, 
   3.5931192392589912`*^9, 3.593119358451747*^9, 3.593119388627735*^9, 
   3.593119479447348*^9, 3.593119574721629*^9, 3.593119659125699*^9, 
   3.5931197059758463`*^9, 3.593119743260062*^9, {3.593119781178439*^9, 
   3.5931198109386997`*^9}, 3.5931215632066927`*^9, 3.593121946779056*^9, 
   3.593127465998534*^9, 3.593136140369385*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1wtYzNkbB/BxWSVkakp/7KawLuVSishtfi7ZyiW3FKWJBy2L+oe2UMmy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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 4.25},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"ALXA\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {4.269076603972356, 
    5.227932220844089}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.01917711233743466, 
   0.01917711233743466}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.59305602138594*^9, 3.593057515697027*^9, 3.593058823132114*^9, 
   3.5930624651328163`*^9, 3.593065120727556*^9, 3.593097768005368*^9, {
   3.593118738150532*^9, 3.5931187545877533`*^9}, 3.593119198890778*^9, 
   3.5931192392589912`*^9, 3.593119358451747*^9, 3.593119388627735*^9, 
   3.593119479447348*^9, 3.593119574721629*^9, 3.593119659125699*^9, 
   3.5931197059758463`*^9, 3.593119743260062*^9, {3.593119781178439*^9, 
   3.5931198109386997`*^9}, 3.5931215632066927`*^9, 3.593121946779056*^9, 
   3.593127465998534*^9, 3.5931361405790367`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1gs0lPkbB/CpiEY0RWrZtUq1Ukr3y1n957UVhVAi5VpH0c2QOsWWUemi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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 2.95},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"CRIS\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {2.969605745216833, 
    4.425643022651789}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.029120745548699114`, 
   0.029120745548699114`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.59305602138594*^9, 3.593057515697027*^9, 3.593058823132114*^9, 
   3.5930624651328163`*^9, 3.593065120727556*^9, 3.593097768005368*^9, {
   3.593118738150532*^9, 3.5931187545877533`*^9}, 3.593119198890778*^9, 
   3.5931192392589912`*^9, 3.593119358451747*^9, 3.593119388627735*^9, 
   3.593119479447348*^9, 3.593119574721629*^9, 3.593119659125699*^9, 
   3.5931197059758463`*^9, 3.593119743260062*^9, {3.593119781178439*^9, 
   3.5931198109386997`*^9}, 3.5931215632066927`*^9, 3.593121946779056*^9, 
   3.593127465998534*^9, 3.593136140771015*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1gtcTNseB/C5QqRIhfLoTqKr9xQiR8xOdKOO4TglUpNX5NGkdEm3xqPH
dS89Se9I74eJkGo0enmcnCblENGkh2wOE5XUiftf/9Xn06fP99Pea/3Wf//X
2ttgp9/mPeM4HE4b/JK/8KO4G8sy3/KGbv8xi8cHa74DF4jqHKwVlsR87TiW
OakT4bkiEi2PBQfZWUvrF6A5VXHkes/+Lw8siHm94NklaqN1AWihZjzLPBi0
ebF8ITpmBbjMsev8xlfmxNw74PasaXqTU9GCLvAatapje7zRYo0Elnkb3Fe8
2xwtWZZAxkson8hBK7zBvcH3Lm1oMyPOVLtA7j/88+I7aPmSC2T85DZpBprj
Bb7h6Lji/f/QvP9cIOMFiCrFaJnqRZKfG2JxAq20AueLXHY4hKC5HhfJ+ke0
x06jBRFgZ+8qn/Pn0GIJ2KI9fuvwJbSmZSLL6JWIe1fkoPnu4KnPTk13vYkW
nSZ2S25zaqD5i8n1FvdXzaTrkT8DW3hMZir/RAtdL8F8nULF8vG4/hgxOFD6
eG70XLSsAJyn3DgktUErW8E9wW8P1m+m9f4BNvNIEGeLaP1yk1gmNMHVyjMG
rfkE/MLQIuxTKZr/F5ivNsfX/SlaZJTMMqWO8z6njKA52eD13sNXVuvS598E
1nArCnGwoM//G/jbItuwgpX0+RumkPWnF/ivQctcwBu8X31PskcLGsHX7w+c
MFyBFg+BGbUeg6kmaAk3lYxXonTXQivWp5K8gr6JX2j+o+DukUeTZjSiM7+A
Z5Xobz6ThpbPS2OZALsNdVt8aP5/gofzBF4RxmjeEXCu0sJQr5vWOxUcptM7
TSOR9sPsdJYR6wQt3GlP+2FtOum/74Ejn00xv1866a+w70/z0OIk/P/wvYFd
aEkt3u9b7boAzbfPIG4dGn1ngvU9mEH63WZfdxk682IG2S+x2prhaLksg4zX
PRy6DR2zP5Pcz9O1WoqWxaMD/Y1moJXSTHK9ZLzXiDHm7csk4/U0v+hGC7Qu
k/m02pJa0YqYy+T+5bNTH6I1Ky+T9bte6KxF83suk346uN6XWjTtCjk/fg/Y
Sp1pC65KD5leRM0rv0L6LchwTx1a+Aa8obMy/3Q9OkY9i2V0LVyuqt5Hy2zA
cfYm2v0P0EohuEr/l6HVv6HFHeD4mvsuA4/RkslXyf1RelObaf7FV0k/Jrif
o+vR9LxK5v+gceQ5zR91lYwXY1PVjpZPzGaZkbywlgOdaI4VuGekolvcS/Nv
B4fq2PuOvqf5w8ENgzq7X/bT/NfAcTWKPSuHaH0tcqD/grP99L/R+m4FV+rv
OnmS1l98Kof0o17KHmpJUQ7p54dVj4Zp/j/Awmj/Xskgre+vuWS/a+nq0vky
w8BS/eJNHJpHnp9L+o0fv7+L5m8Fm3s0tv/ygub/jt5kUd1E6xuSB/vLsSmy
kD4fZU4eqce6d7q3aP7mPPJ8bm5WzaX5R/NIHv26oIs0/8J8lhldJLbzOUPr
+Xs+6a8Zx4+H0bzDYMPw10HFkTTv/AIy30sblTSa1xmcUDPlTnA1redvBeT8
9RvT/kTrOVhA1qs6vsmU9vPfC8l4LY2FR2k/O4FdOp+4FTSiuYGF5P4J2Y94
dH99LiTjHyxTv4JWzC0i9VGNEHHpeewIXhD+VG+okJ7H/kUk/zO/NAd6vqUU
kfVpRO1l6fkwu5hlvKODdm5Ko+ebQzE5z7V/7NiB7z/hYXD9UcsDURPx/Rlz
CdxmaDawxBUtqwGv7wxLLktDC5gS8vxNPFVfocUHwPyzZqvNdaww/4USMl64
ndEatKIanCNa6v55P1qTBXcFr4yLjUJn7rvGMv9OSO5TyUDL48BHpBs9nIrR
HCm4bnD7n9430MLpEvi/XXWKSylaGQ0OSTjuo56L5laAu0bOCtIT0IJuCZn/
i6tKMFo8tZSMdz34Jzeadzm44nWqUs8Gzb8NjjAtLU+fiRZ1gk3aPz15OIzr
zZxynWWylVtXp7Sj5UvBX/d9GNOqQXOEYO7agqlW+bSer4nD4/wHY2k9J92A
6xdlGwlD0EprcDbvjbn/PjR3B9gk1SlyEa2/IBIceeCldcRatGJCGeRNT+Sd
taHfOzxw/dJQ8RJjNH8bOIcXPT98Hlp0BuwZ/WhmiDbNXwL+uIm3Q28Kmmd+
k2VsAvSdUlXQQjfwoV7jm5NHsD9iToJfZ/3DMOcjWlYIlunbtGv0oJVPwVpu
vyr4r9DiLbdYptU53HL1M7QkFKzKaXg4qQWtyAMXimZdS5OjNVvAsvTjHWNN
9HttDLz27Idtxs30e+3EbZb5abHIgNtKv9dywJeTxi9+8xzNk4OPSfOj/Tpo
P4+Aq9O9lj14S/MvKCffO0YmH/rR3CxwRtKYz8sxtOAxOO4U3yN0Au3nr+Bx
/OcaeepoicEdljGY0PDAV4fWfwP4Y/Pkcw1zaT0HwPtzsrZVLqT9oF9Bxou3
crKk/eAE3r+3bbrIltY7oILU/+iopQPth/4K0i8+H6M20n6YU0nmv8YGb6f9
sK6SvE9clBNofwhE4CZn5ofxUZo3GVzp+d9Zb0/RftCrYpktx0xt7Wi/8deA
U5MMdptl0n44VEXO+0OXyq7R/Ilgzyb1n6Uymv8eWEX2/cy6FtoPfCn5vlpj
J3hL+9kXLHd+GfTiL5o/ATzcV2/Vo033413ifSqHRWZ0P74DNzXGm4aso/vN
5y55H/3Ld9JOej7EglX4xSYzwuj5UAUWbrQ5eCWN7sdecLy9lqVESvejZjXL
pOkxAas66PkQDQ5trVnuMs4a63unmvRzYli7EVrYVU3ed3cdPzijYzRkLGPq
YRsbEoiWLZOR/XQsY+giWnALHCANObKtDC1WgLeUr1XLa0RL1O6xjFd0y96O
DrRiyT2SzyiK8xGt6QX+1Gx3eMpXdOYrcKDdbD3OKFquWsMy88Mro15/Q3Os
a8j3h4E05wvN74F2vrW1j+aPwOtXBg48QyvH15Lx+oeO16C5lrVkPt9V73Jp
fvdakid/vX0UzX+6luQtmhO+i+YvriXrCSwttUXzzepIP4p6k6ajRa51pD4Z
FXbv6fksBqs/+5tFWgM9nwvqSP8k8suzaP2fgiv0vT+fP2XF/z8Yl06y
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 12.8},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"AVHI\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {12.7489736403199, 
    18.980470246225607`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.12462993211811416`, 
   0.12462993211811416`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.59305602138594*^9, 3.593057515697027*^9, 3.593058823132114*^9, 
   3.5930624651328163`*^9, 3.593065120727556*^9, 3.593097768005368*^9, {
   3.593118738150532*^9, 3.5931187545877533`*^9}, 3.593119198890778*^9, 
   3.5931192392589912`*^9, 3.593119358451747*^9, 3.593119388627735*^9, 
   3.593119479447348*^9, 3.593119574721629*^9, 3.593119659125699*^9, 
   3.5931197059758463`*^9, 3.593119743260062*^9, {3.593119781178439*^9, 
   3.5931198109386997`*^9}, 3.5931215632066927`*^9, 3.593121946779056*^9, 
   3.593127465998534*^9, 3.593136140976737*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwtlwtYzOkXx2cjpdimYlFbOxU2l9LFyqWYn7ZSiXGLCBOrRBTK/lmPxiVs
9iGXVLqYpGkqZVKULtNEFuFvtIiVTEo0/THaRdLlf8579Dw9PZ/n/f3O+33P
+Z7z/rJZE7lwnR6Px3sCv/gXfjTKY1pupOPqw9N/GCsE5rcDR1fd0TaZMhaa
H9dyL3dK1I/1GKuPAW8I3elu3zkGmVcJvGRqfrhNC2OnNuAcndmy2oeMxfwT
Wk58tMjAtI5xwnTg2GEH/2OgYiy4AjxQciIvp5SxqAVYd/9R+nsFY8nQk1pu
ttGChS/zGSvcgLvt9W7ulTPWhACPctT23ZIxlholarmMUYM/lROrJwPHd6xS
LKHneauBG7M6xp+meE6/A5+cfSH0EO2nMjil5S7eyF0rID06Z2A316c2a6pJ
bzCwbZxnZsAt0nsA+Nulyldf6kmvAviz3P9DRCNj/qQkLde6s+OW9CVjYRCw
+k76uqS3jKP2AVdkrLkp+kT6C4Blummdd/pJfwPw8at2LcaGLP/iwGQtt3uY
IHUon3GCBHhDm6NF/QjGqrxkrIdIHET11D0AFhrt35Q1lrGgH3hicB2ncGCs
yUnRciMc7Z7FTqb61wMPkByZZTaD6t8D/G7BkPAwjnHU2NNa7u+stKBYH8a8
bGBbfe/LjfMYO90DvhFjGBu7lPR+Rv7QUhwWQnrtUrWcXdzjxYkRpDcAuNGu
LcRwB2PRHeB394c8VR1gLPmYiv6Zq1ImMlYI0lB/tqmejPT7peF5R9yLLyX9
McB/253tWlbHWPoPcIW195GIJvKvVTrUx35AwvV/SP8c4BOzn/SuNfqR6d8K
/PvGmw0+tozFacBPs9RWW2Yw1llkwHrH+3vPlzAWeGWgHyxG1UYwFkUCy6P8
PltJGEtSgEcW7ol6c5Sx4hpwtIdqt0saY+HsM6hv0Og35xhHRQC/XbBIbJXH
WHoKeGhDjuu1fMZq1RmMNyCjKZdxQrgU/NcQeiaS3ledkGK97rttTyW9VcCV
1p5hnUdI72sp7l/p0Lqb9JplYjz3w/4bGWsSMlF/baz9Ysb8ikys1yLj36aR
3peZeP52B09L0mtyFuvvv8OCR3qnncX+3f6G95r8UIa8YFP8x3rywwt8Ps5R
9EVFfhiShfkun2lykfwwJQvjmQa6UH114iw8j8upX9LJD8+zMJ51f3YS+WHw
OdCn/zDh40nygytw/MZA/0DyC38V8Oi4s47Xk8nPh87h+1eme54hPwzKRr2n
I9Vy8oMz8Gh9n7sRl0j/imycH1WLRl4n/XHZqL9f768G0n8hG/vTN2huO/WX
o4z1R+D+z+TnZcBd9l3dOw3JD3tlWN9gb6fvyA/nZVifW1PPkd80j2To95n1
jxwov0ty0H+VZjfdKL+xOeh/z+5fheSHXODFZfWH2nwY8x4ALynboDSfR37u
Y88bp/YvJH/skmO8Euu8QPKHTI77hfqaB5E/7stRj43ljOXkjy9y1Nt6woZY
MiYXz6Mo/nMZ+eG/wDZx72fZLSW9XcDhofKpbtQfUts8nHcP0vUWkd65eahv
e2SciPrrdh7245GC6gDy84c83N9yWZEf6f0hX8ulp1hFLqfz6XyB01ISO8s9
SW80cLn1vhf1syifnfmor23mWepXzffnMT9Kg3GUP77PedQzxCPMhfRvOY96
1U3BX/Odeh7PM/jNYHvKp0UBxisL20z1cfq5APPROC/+e9K/GXhi4/r5h0eQ
/mTgohsrw7eYk/6rBTivK9Lc+ZRPrhDmzVVJ+/+GUj43FuK8K5y/dwjpT8T1
2V73eoxJf3Uhvv/z+mBa52uBi3zyLTLpfen6C7j/zrY6E8rvceC39y/efmJG
+qsuoP5FdXfJb2JThZbza17xQkb9qzsK3Np9x3ydDeWzHPjPGNkqQzq/qFWB
/ff6asIk0vttEfrluLCP8qmYWoTz/cn6KMq/sLQI54VyxisvymczcIyH8Moa
f9JrfBHru7r5xXzS+9NFvM8tS8LIHzwxsENwtPN78k9CE3Bg2YagWPKXyrAY
51ffBDPyn86lGOeRY24urQtWFmN+e9Re5G/RQcZhWW0UX6NfouUOdUQK/iD/
8Z2At3kMnzNlLulfXoL+XGrx0pv07y/B/nFLSqZ+kxaWYD5LlCKah04Ol7D/
Tby2kJ/ESy/hut/47gmkfw/whOC1mzvGkP78SxhvhamXgPQ/ZM+7mBtQPSSL
L2O8V9ucv86H3ZdxfZdrrSnplwOPD363oJrqz//rMsbn7tnS/SXsZc9vzX87
iPL7WynG29NmO5DyKyvFfouSVH9D+tWlqMdjR20/zbduxu1q5z6ab6PLMF70
QYNemm9ZZRjvWZpXD823u8DC+G7nhC80nz8B60nqvF9103y2uYLzMOCpH7HG
H/j6h33vymk+Sv9Fjtm0z41YbV2O97dRkqqL5rEv8ADe8vGBxE7bgDmjlR5d
n+i+eF+O/WKulhHrLCvAT/JdL0KIBd4V6L+U6HHEoijggbzwA70fSe9pYLmu
Y0QTMX9UpZYLMbEdd5tY6AnsGGxcXksctQnYpCGnro5YmgRsUSiyllB8dQ1w
QLP+pVbSKxZWabncqBtHuuj8CRuqMF5ifgXlU3WyCr9HI40dqR46JXCxT2Dh
fH3ycztj35MCqq8iTInPz6mSUr9rjikx3uJx6uHkh0ol7hfxuJDmk7ANeG5z
Qp37aPIzvxrv+5r+HRPJD0er8fuh79fQn8gPV6qx/nNc9aifxS3V2B8ZzgG+
5OehKvx/gLfNh74PVG4qzOdtFbeS+u2yCudrr4X7L+RnDbB/c/KeKeGk36gG
+zftXyf6XtJMrsF5ZBA9YRPpX12D7z/tH0Pr0mc1WP+RyQJ6X21wFb+nK90t
KT7PBXirx603w2l/p2Bghc/MfD7pEx8ATk2xjDEm/bqB17TcZNcQ/0HulN9J
wLuGmTh+Q/NfFHQN442x6vnaj/uAvyvMGvmJ7m9FAfD60HhBJ30/CifWQn/I
F7b0Pid/BNain3vEFnfJH5JaPM/BFJ8K8kdeLeb/3z/i8sjfD4HTR3nOeHB6
rPD/96oxFQ==
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 10.850000000000001`},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"ASIA\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {10.82564517961583, 
    11.835473646391188`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.02019656933550717, 
   0.02019656933550717}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.59305602138594*^9, 3.593057515697027*^9, 3.593058823132114*^9, 
   3.5930624651328163`*^9, 3.593065120727556*^9, 3.593097768005368*^9, {
   3.593118738150532*^9, 3.5931187545877533`*^9}, 3.593119198890778*^9, 
   3.5931192392589912`*^9, 3.593119358451747*^9, 3.593119388627735*^9, 
   3.593119479447348*^9, 3.593119574721629*^9, 3.593119659125699*^9, 
   3.5931197059758463`*^9, 3.593119743260062*^9, {3.593119781178439*^9, 
   3.5931198109386997`*^9}, 3.5931215632066927`*^9, 3.593121946779056*^9, 
   3.593127465998534*^9, 3.59313614117487*^9}]
}, Open  ]],

Cell["\<\

Then compute the distance between each Trend curve and the random pick set, \
as you can see is much larger than the distance between the two Trend curves \
i.e. much dis-similar:\
\>", "Text",
 CellChangeTimes->{{3.59306249400491*^9, 3.593062546294299*^9}, {
  3.593134926567135*^9, 3.593134927003955*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"data", " ", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"CanberraDistance", "[", 
     RowBox[{"trARO", ",", 
      RowBox[{"tr", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", " ", "1", ",", " ", 
      RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Sqrt", "[", 
  RowBox[{"Variance", "[", "data", "]"}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.593062475172913*^9, 3.593062486478627*^9}, {
  3.593118763962715*^9, 3.593118854627368*^9}, {3.593119440723444*^9, 
  3.593119443332633*^9}, {3.593119483212508*^9, 3.593119494733309*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "190.6366940315707`", ",", "94.10598662017907`", ",", "127.13927928677327`",
    ",", "88.94817078932121`", ",", "88.2489268085452`", ",", 
   "121.5598881857907`", ",", "57.34938928196712`", ",", "97.8091665899386`", 
   ",", "117.13908771531143`", ",", "27.18002630877718`", ",", 
   "21.542787508937984`"}], "}"}]], "Output",
 CellChangeTimes->{{3.593062482679862*^9, 3.5930624868326607`*^9}, 
   3.593065124082498*^9, 3.5930977702569*^9, {3.593118836063138*^9, 
   3.593118855429028*^9}, 3.593119202254588*^9, 3.593119241970175*^9, 
   3.593119361464724*^9, 3.593119391954504*^9, 3.59311944379563*^9, {
   3.5931194867462587`*^9, 3.593119495102993*^9}, 3.593119579354403*^9, 
   3.593119662769808*^9, 3.5931197104738417`*^9, 3.593119747737871*^9, 
   3.593119785433992*^9, 3.5931198159089317`*^9, 3.5931215701714993`*^9, 
   3.5931219549440813`*^9, 3.5931274715015087`*^9, 3.593136145390457*^9}],

Cell[BoxData["93.78721846610114`"], "Output",
 CellChangeTimes->{{3.593062482679862*^9, 3.5930624868326607`*^9}, 
   3.593065124082498*^9, 3.5930977702569*^9, {3.593118836063138*^9, 
   3.593118855429028*^9}, 3.593119202254588*^9, 3.593119241970175*^9, 
   3.593119361464724*^9, 3.593119391954504*^9, 3.59311944379563*^9, {
   3.5931194867462587`*^9, 3.593119495102993*^9}, 3.593119579354403*^9, 
   3.593119662769808*^9, 3.5931197104738417`*^9, 3.593119747737871*^9, 
   3.593119785433992*^9, 3.5931198159089317`*^9, 3.5931215701714993`*^9, 
   3.5931219549440813`*^9, 3.5931274715015087`*^9, 3.59313614539191*^9}],

Cell[BoxData["47.814924284047336`"], "Output",
 CellChangeTimes->{{3.593062482679862*^9, 3.5930624868326607`*^9}, 
   3.593065124082498*^9, 3.5930977702569*^9, {3.593118836063138*^9, 
   3.593118855429028*^9}, 3.593119202254588*^9, 3.593119241970175*^9, 
   3.593119361464724*^9, 3.593119391954504*^9, 3.59311944379563*^9, {
   3.5931194867462587`*^9, 3.593119495102993*^9}, 3.593119579354403*^9, 
   3.593119662769808*^9, 3.5931197104738417`*^9, 3.593119747737871*^9, 
   3.593119785433992*^9, 3.5931198159089317`*^9, 3.5931215701714993`*^9, 
   3.5931219549440813`*^9, 3.5931274715015087`*^9, 3.593136145392949*^9}]
}, Open  ]],

Cell["\<\

Compute the mean distance to the random-pick outliers:
\
\>", "Text",
 CellChangeTimes->{{3.59313750067153*^9, 3.5931375208205557`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"data", " ", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"CanberraDistance", "[", 
     RowBox[{"trBBY", ",", 
      RowBox[{"tr", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", " ", "1", ",", " ", 
      RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Sqrt", "[", 
  RowBox[{"Variance", "[", "data", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.593119519899946*^9, 3.593119521311634*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "163.52897842478083`", ",", "29.269528993455744`", ",", 
   "63.21055821605466`", ",", "18.754466807178083`", ",", 
   "144.41882095581087`", ",", "56.808566114334546`", ",", 
   "69.44450570136392`", ",", "149.6730135959583`", ",", 
   "162.93049666762442`", ",", "56.935716481700574`", ",", 
   "82.92256981322018`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.593119521957698*^9, 3.593119581972301*^9, 3.5931196647552156`*^9, 
   3.593119714794466*^9, 3.593119749456037*^9, 3.593119787519836*^9, 
   3.5931198196110497`*^9, 3.5931215742918177`*^9, {3.593121957812997*^9, 
   3.593121960064724*^9}, 3.593127474937172*^9, 3.593136147158822*^9}],

Cell[BoxData["90.71792925195292`"], "Output",
 CellChangeTimes->{
  3.593119521957698*^9, 3.593119581972301*^9, 3.5931196647552156`*^9, 
   3.593119714794466*^9, 3.593119749456037*^9, 3.593119787519836*^9, 
   3.5931198196110497`*^9, 3.5931215742918177`*^9, {3.593121957812997*^9, 
   3.593121960064724*^9}, 3.593127474937172*^9, 3.593136147160244*^9}],

Cell[BoxData["54.21374528962186`"], "Output",
 CellChangeTimes->{
  3.593119521957698*^9, 3.593119581972301*^9, 3.5931196647552156`*^9, 
   3.593119714794466*^9, 3.593119749456037*^9, 3.593119787519836*^9, 
   3.5931198196110497`*^9, 3.5931215742918177`*^9, {3.593121957812997*^9, 
   3.593121960064724*^9}, 3.593127474937172*^9, 3.5931361471612577`*^9}]
}, Open  ]],

Cell[TextData[{
 "\n\n",
 StyleBox["10-K Filings\[CloseCurlyQuote] Cosine Similarity", "Title"],
 "\n\nGo to URL: \
http://thorek01.lossofgenerality.com/visualize/SimilarityGraph.html \n\n\
Actual 2012 section 7 (Management Discussion) of about 1000 10-K securities \
filings in USA. The edges represent 60% or more similarity between the \
section 7.\n\nAs you can see the 60% similarities are established for certain \
number of companies. \n\n\n",
 Cell[BoxData[
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJzs3Q18k/W9P/zr4EznQ204U9qcTWhwQ8KcUBwPZZtgezuxPYpr3ZyjnE1b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     "], {{0, 1174}, {1177, 
     0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   BaseStyle->"ImageGraphics",
   ImageSize->Automatic,
   ImageSizeRaw->{1177, 1174},
   PlotRange->{{0, 1177}, {0, 1174}}]], "Input"],
 "\n\n"
}], "Text",
 CellChangeTimes->{{3.593055666775704*^9, 3.593055748011757*^9}, {
   3.593055831320253*^9, 3.593055832319709*^9}, {3.593055890518175*^9, 
   3.593055924210236*^9}, 3.5930626254641647`*^9, 3.593066615488935*^9}],

Cell["\<\

Let\[CloseCurlyQuote]s choose some of these similarities and investigate to \
see if the documetric similarities of 10-K filings do reflect the price curve \
similarity.

\
\>", "Text",
 CellChangeTimes->{{3.593057277910008*^9, 3.593057321311982*^9}, 
   3.593072150308078*^9}],

Cell[TextData[{
 "\n",
 StyleBox["Similarity: CTS, BK", "Title"]
}], "Text",
 CellChangeTimes->{{3.593057242922181*^9, 3.593057263272951*^9}}],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsnQt8FOXZ9lP0BUtrC231hdcWG9pasS0Va23h+1oVXqvAW2uBr34IfEWB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    "], {{0, 452}, {533, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{533, 452},
  PlotRange->{{0, 533}, {0, 452}}]], "Input"]], "Text",
 CellChangeTimes->{3.5930561425994062`*^9}],

Cell["\<\

Find the Trend curve for CTS:\
\>", "Text",
 CellChangeTimes->{{3.593057334947703*^9, 3.5930573507535057`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"price", " ", "=", " ", 
     RowBox[{"FinancialData", "[", 
      RowBox[{"\"\<CTS\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dwd", " ", "=", " ", 
     RowBox[{"DiscreteWaveletTransform", "[", 
      RowBox[{
       RowBox[{"price", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
       RowBox[{"BiorthogonalSplineWavelet", "[", 
        RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"trCTS", " ", "=", " ", 
     RowBox[{"InverseWaveletTransform", "[", 
      RowBox[{"WaveletThreshold", "[", 
       RowBox[{"dwd", ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{"DateListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"price", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trCTS"}],
        "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "False"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<CTS\>\""}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.593046100621051*^9, 3.593046120103314*^9}, {
  3.593049077455863*^9, 3.593049112353223*^9}, {3.593058799001259*^9, 
  3.59305880495059*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1gtUjOsaB/A5rtVWTWkvyq0ku45Lo0IuMV/RhWwdt5CtsfcypWxGLsem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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 10.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"CTS\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {9.76862168582157, 
    18.206957702245575`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.1687667203284801, 
   0.1687667203284801}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{{3.593046111429391*^9, 3.5930461211276293`*^9}, 
   3.59304623541101*^9, {3.593049051795006*^9, 3.5930491134375267`*^9}, 
   3.5930491777469893`*^9, 3.5930493019894733`*^9, 3.593058806331374*^9, 
   3.593065129919248*^9, 3.593097776921939*^9, 3.593119954480255*^9, 
   3.593136168305765*^9}]
}, Open  ]],

Cell["\<\

Find the Trend curve for BK:\
\>", "Text",
 CellChangeTimes->{{3.593057358247034*^9, 3.593057364883334*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<BK\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trBK", " ", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trBK"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<BK\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593046726280445*^9, 3.593046758615855*^9}, {
  3.5930472043070707`*^9, 3.5930472072657948`*^9}, {3.593048024663784*^9, 
  3.5930480256069*^9}, {3.593049210701269*^9, 3.593049226664315*^9}, {
  3.5930493081384573`*^9, 3.593049310551242*^9}, {3.593058810148534*^9, 
  3.593058813511956*^9}, {3.593065136346835*^9, 3.5930651385532703`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1gtUjFsbB/D5Ih2hmVwLpb700aEMScoX8yYSReNScpLJnaKijogaSnVy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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 25.8},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"BK\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {25.887430290498315`, 
    31.761111212708077`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.11747361844419522`, 
   0.11747361844419522`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.593049228525158*^9, 3.593049316519513*^9, 3.593058814994588*^9, {
   3.593065133068331*^9, 3.593065139336894*^9}, 3.593097778536767*^9, 
   3.593119956656865*^9, 3.593136178684973*^9}]
}, Open  ]],

Cell["\<\

Use weighted Manhattan Distance e.g. Canberra Distance to establish a measure \
of distance or similarity between the Trend Curves:\
\>", "Text",
 CellChangeTimes->{{3.593057375324562*^9, 3.593057405147483*^9}, 
   3.593057670212081*^9, 3.59306662105759*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CanberraDistance", "[", 
   RowBox[{"trBK", ",", "trCTS"}], "]"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{
  3.5930467697506037`*^9, {3.593047263436797*^9, 3.593047265385556*^9}, {
   3.593047582445092*^9, 3.593047595313385*^9}, {3.5930491255043716`*^9, 
   3.593049144370028*^9}}],

Cell[BoxData["85.81947712434132`"], "Output",
 CellChangeTimes->{
  3.593046770321698*^9, 3.593047175126861*^9, 3.5930472663992147`*^9, {
   3.593047582884448*^9, 3.593047595828848*^9}, 3.593049144944951*^9, 
   3.5930493203348293`*^9, 3.593051268735507*^9, 3.593051399756516*^9, 
   3.5930651440659723`*^9, 3.593097780715073*^9, 3.593119958554789*^9, 
   3.5931215903543453`*^9, 3.5931219668040037`*^9, 3.593136181218525*^9}]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["OK!", "Title"],
 "\n\nMeasure the Canberra Distance between the Trend curves of CTS and BK to \
the Trend curve of the random-pick which we show by tr (array) variable below:"
}], "Text",
 CellChangeTimes->{{3.593057423441193*^9, 3.5930574895567837`*^9}, {
  3.5930575225305653`*^9, 3.5930575240835114`*^9}, {3.593062563958481*^9, 
  3.593062568918255*^9}, {3.5931307354397793`*^9, 3.5931307372167*^9}, {
  3.593137547742712*^9, 3.5931375495406427`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"data", " ", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"CanberraDistance", "[", 
       RowBox[{"trBK", ",", 
        RowBox[{"tr", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"i", ",", " ", "1", ",", " ", 
        RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"Variance", "[", "data", "]"}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.5930491519852743`*^9, 3.593049163804158*^9}, {
  3.593051395800082*^9, 3.593051398050042*^9}, {3.593119940058549*^9, 
  3.593119948786674*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "160.45112344522767`", ",", "9.923099127743395`", ",", 
   "53.731708033155016`", ",", "7.816971151529818`", ",", 
   "151.1475794823694`", ",", "46.64434693781996`", ",", "76.53405865524351`",
    ",", "156.98403740990153`", ",", "168.51640484629283`", ",", 
   "67.07271059641054`", ",", "94.0522719528149`"}], "}"}]], "Output",
 CellChangeTimes->{3.593049164310796*^9, 3.5930493234032288`*^9, 
  3.593051266616756*^9, 3.593051400729352*^9, 3.593057518677126*^9, 
  3.593065146433868*^9, 3.593097781966187*^9, 3.593119960523637*^9, 
  3.5931215928723383`*^9, 3.5931219690223*^9, 3.5931253634059687`*^9, 
  3.593127482076582*^9, 3.593136183553875*^9}],

Cell[BoxData["90.26130105804623`"], "Output",
 CellChangeTimes->{3.593049164310796*^9, 3.5930493234032288`*^9, 
  3.593051266616756*^9, 3.593051400729352*^9, 3.593057518677126*^9, 
  3.593065146433868*^9, 3.593097781966187*^9, 3.593119960523637*^9, 
  3.5931215928723383`*^9, 3.5931219690223*^9, 3.5931253634059687`*^9, 
  3.593127482076582*^9, 3.593136183555355*^9}],

Cell[BoxData["60.36406077346289`"], "Output",
 CellChangeTimes->{3.593049164310796*^9, 3.5930493234032288`*^9, 
  3.593051266616756*^9, 3.593051400729352*^9, 3.593057518677126*^9, 
  3.593065146433868*^9, 3.593097781966187*^9, 3.593119960523637*^9, 
  3.5931215928723383`*^9, 3.5931219690223*^9, 3.5931253634059687`*^9, 
  3.593127482076582*^9, 3.5931361835563917`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"data", " ", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"CanberraDistance", "[", 
       RowBox[{"trCTS", ",", 
        RowBox[{"tr", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"i", ",", " ", "1", ",", " ", 
        RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"Variance", "[", "data", "]"}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.593119977936207*^9, 3.593119982631412*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "190.1283144558509`", ",", "93.97793919807982`", ",", "126.77578724986463`",
    ",", "90.0408005408986`", ",", "89.81826688620677`", ",", 
   "122.12940564485545`", ",", "37.31647140643817`", ",", 
   "98.91991837050145`", ",", "118.91422812964092`", ",", 
   "21.577285960845245`", ",", "18.618366937703353`"}], "}"}]], "Output",
 CellChangeTimes->{3.593119983559043*^9, 3.593121596275112*^9, 
  3.593121973324546*^9, 3.593125366090715*^9, 3.593127485279715*^9, 
  3.593136185555904*^9}],

Cell[BoxData["91.65607134371686`"], "Output",
 CellChangeTimes->{3.593119983559043*^9, 3.593121596275112*^9, 
  3.593121973324546*^9, 3.593125366090715*^9, 3.593127485279715*^9, 
  3.5931361855573273`*^9}],

Cell[BoxData["50.85694056821856`"], "Output",
 CellChangeTimes->{3.593119983559043*^9, 3.593121596275112*^9, 
  3.593121973324546*^9, 3.593125366090715*^9, 3.593127485279715*^9, 
  3.593136185558313*^9}]
}, Open  ]],

Cell["\<\

So the computation shows:

1. The two stocks are close in Trend curve similarity as they are close in \
Cosine Documetric Similarity  
2. The random stock that is afar in terms of Cosine Documetric Similarity is \
also afar in Canberra distance between the corresponding Trend curves
\
\>", "Text",
 CellChangeTimes->{
  3.593057551601761*^9, {3.593057583944859*^9, 3.593057640049254*^9}, {
   3.593057683802189*^9, 3.5930577477233963`*^9}, 3.59306663669514*^9, {
   3.593072159713127*^9, 3.5930721659907637`*^9}}],

Cell[TextData[StyleBox["Similarity: ATRO, BEAV", "Title"]], "Text",
 CellChangeTimes->{{3.593135822938877*^9, 3.59313582945076*^9}}],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsnQl8VPW590fal1hvW4YuQlqtxLbW1HtV9F4p3PtWJJdayGu5Df3UWqC3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    "], {{0, 366}, {514, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{514, 366},
  PlotRange->{{0, 514}, {0, 366}}]], "Input"]], "Text",
 CellChangeTimes->{3.593135850573114*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<ATRO\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trATRO", " ", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trATRO"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<ATRO\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5931356138232937`*^9, 3.593135649113721*^9}, {
  3.593135707029706*^9, 3.593135713554057*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1gtYTOkfB/ARyqXLoChipyRCme7lOmckkn//7CKX1FQrpXRZtWI3O661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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 17.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"ATRO\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {17.050762149496016`, 
    47.35472866616681}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.6060793303334159, 
   0.6060793303334159}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593135621214054*^9, 3.593135714159823*^9, 
  3.593136189788393*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<BEAV\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trBEAV", " ", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trBEAV"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<BEAV\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593135628223096*^9, 3.5931356329476013`*^9}, {
  3.593135723579056*^9, 3.593135731925558*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1gk4VPsbB/B5lKX+llFKhZqytGu0qIjmaCFUkqJs06JQ3aak5NY0LdKi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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 49.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"BEAV\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {48.77647397759374, 
    80.5295880006068}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.6350622804602611, 
   0.6350622804602611}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593135634035585*^9, 3.593135734959318*^9, 
  3.593136192442916*^9}]
}, Open  ]],

Cell["\<\

Distance between the two Trend price curves:\
\>", "Text",
 CellChangeTimes->{{3.593137565663105*^9, 3.593137583346936*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trATRO", ",", "trBEAV"}], "]"}]], "Input",
 CellChangeTimes->{{3.593135751804344*^9, 3.593135759189002*^9}}],

Cell[BoxData["81.61177271255752`"], "Output",
 CellChangeTimes->{3.5931357602839813`*^9, 3.593136194947225*^9}]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["OK!", "Title"]
}], "Text",
 CellChangeTimes->{{3.593135793687476*^9, 3.593135794496396*^9}}],

Cell["\<\
Compute the mean distance to the random-pick outliers:\
\>", "Text",
 CellChangeTimes->{3.593137560403132*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"data", " ", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"CanberraDistance", "[", 
        RowBox[{"trATRO", ",", 
         RowBox[{"tr", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Mean", "[", "data", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.59313577310981*^9, 3.5931357812961617`*^9}}],

Cell[BoxData["91.65386777285458`"], "Output",
 CellChangeTimes->{3.593135781817977*^9, 3.593136196130844*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"data", " ", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"CanberraDistance", "[", 
        RowBox[{"trBEAV", ",", 
         RowBox[{"tr", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Mean", "[", "data", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.593135783302153*^9, 3.59313578684214*^9}}],

Cell[BoxData["119.51221741719978`"], "Output",
 CellChangeTimes->{3.593135787655648*^9, 3.593136197347692*^9}]
}, Open  ]],

Cell[TextData[StyleBox["Similarity: BRY, BCEI, CWEI", "Title"]], "Text",
 CellChangeTimes->{{3.593135440211508*^9, 3.5931354556221113`*^9}}],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsnQlcVOe5/6fpLfTmNn/xtlVomzbY20Ry0ySmbaze3CxabxK8aVq1zU00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    "], {{0, 408}, {524, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{524, 408},
  PlotRange->{{0, 524}, {0, 408}}]], "Input"]], "Text",
 CellChangeTimes->{3.5931355567857037`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<BRY\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trBRY", " ", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trBRY"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<BRY\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5931351521207123`*^9, 3.593135157767494*^9}, {
  3.593135256745102*^9, 3.593135258231085*^9}, {3.593135653658752*^9, 
  3.593135655329809*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1gk4VfkbB3BLpoVylRZlLNFUCNm1zNyD7JU1LZZLGzK5RU3F1KVUGuWS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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 34.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"BRY\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {34.12103418197019, 
    47.70186941349883}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.2716167046305728, 
   0.2716167046305728}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593135161578477*^9, 3.593135259334824*^9, 
  3.59313568290269*^9, 3.593136218084866*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<BCEI\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trBCEI", " ", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trBCEI"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<BCEI\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593135169591446*^9, 3.593135178174576*^9}, {
  3.593135263721032*^9, 3.593135266150257*^9}, {3.5931356591833277`*^9, 
  3.593135662563143*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1gk8VekbB/D71zqSaCNTukhpGV0UknIPCSVRljYlo/8UqlvWGEZpQYtr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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 30.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"BCEI\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {30.439892881012074`, 
    53.74864371367733}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.4661750166533052, 
   0.4661750166533052}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593135179007419*^9, 3.593135267058915*^9, 
  3.593135679561355*^9, 3.593136221565549*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<CWEI\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trCWEI", " ", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trCWEI"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<CWEI\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5931351882552137`*^9, 3.5931351971195793`*^9}, {
  3.593135271022223*^9, 3.593135275532946*^9}, {3.593135668915154*^9, 
  3.593135671664693*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1gs0VGsbB/D56B4+UjmSYjr1VciUyOn7OmZSYYjRKiQxUkIXpMspJZSi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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 38.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"CWEI\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {38.34280811849983, 
    75.14390975119318}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.7360220326538669, 
   0.7360220326538669}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.5931351978648863`*^9, 3.5931352763444033`*^9, 
  3.593135672595014*^9, 3.593136224108917*^9}]
}, Open  ]],

Cell["\<\

Compute the pair-wise distance between the Trend price curves:\
\>", "Text",
 CellChangeTimes->{{3.593137601133957*^9, 3.5931376221934147`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"CanberraDistance", "[", 
    RowBox[{"trBRY", ",", "trCWEI"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"CanberraDistance", "[", 
    RowBox[{"trBCEI", ",", "trBRY"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"CanberraDistance", "[", 
    RowBox[{"trBCEI", ",", "trCWEI"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.593135219552561*^9, 3.593135248532156*^9}, {
  3.5931352937129097`*^9, 3.593135318496828*^9}, {3.5931353551159973`*^9, 
  3.5931353681086683`*^9}}],

Cell[BoxData["18.95636351170482`"], "Output",
 CellChangeTimes->{3.5931353190664043`*^9, 3.5931353686731873`*^9, 
  3.593135687109171*^9, 3.593136226155301*^9}],

Cell[BoxData["14.94140539173501`"], "Output",
 CellChangeTimes->{3.5931353190664043`*^9, 3.5931353686731873`*^9, 
  3.593135687109171*^9, 3.593136226156636*^9}],

Cell[BoxData["20.797905796407406`"], "Output",
 CellChangeTimes->{3.5931353190664043`*^9, 3.5931353686731873`*^9, 
  3.593135687109171*^9, 3.593136226157667*^9}]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["OK!", "Title"],
 "\n"
}], "Text",
 CellChangeTimes->{{3.593135385782714*^9, 3.5931353870869093`*^9}}],

Cell["\<\
Compute the mean distance to the random-pick outliers:\
\>", "Text",
 CellChangeTimes->{3.593137596387294*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"data", " ", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"CanberraDistance", "[", 
        RowBox[{"trBRY", ",", 
         RowBox[{"tr", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"data", " ", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"CanberraDistance", "[", 
        RowBox[{"trBCEI", ",", 
         RowBox[{"tr", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"data", " ", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"CanberraDistance", "[", 
        RowBox[{"trCWEI", ",", 
         RowBox[{"tr", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Mean", "[", "data", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.593135337146318*^9, 3.593135378803041*^9}}],

Cell[BoxData["99.47167529922685`"], "Output",
 CellChangeTimes->{3.59313537951471*^9, 3.593135689277451*^9, 
  3.593136227605691*^9}],

Cell[BoxData["96.57324678703131`"], "Output",
 CellChangeTimes->{3.59313537951471*^9, 3.593135689277451*^9, 
  3.5931362276070013`*^9}],

Cell[BoxData["103.71968509453899`"], "Output",
 CellChangeTimes->{3.59313537951471*^9, 3.593135689277451*^9, 
  3.5931362276080027`*^9}]
}, Open  ]],

Cell[TextData[StyleBox["Similarity: ASH, ALV, AXP", "Title"]], "Text",
 CellChangeTimes->{{3.593058057540975*^9, 3.59305806580846*^9}, {
  3.593130363377976*^9, 3.593130368235714*^9}}],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvQucFOWZtz0hCbgmJpqjrFkNmDWSzavBzbqR711NIG5Uvmgi/tZVMKuC
SRBdo8hGg2ZVNEYRT4hrFCTKSRTwhBCjHDwMGCMDMRzEw4CamcFVmdEYZmKM
z9tXdd89d9dUVVdVd8+h+778lcB0d3V1T/fzf+7zoNPPOf77/erq6ibulvnf
8af9+BvnnXfahaM+lPnH8AvPP+P0D2b+cvsH6upaMwc/dIZhVJz33nvP7dq1
y/3pT39yf/nLX3r6cgzDMAzDCOGPf/yje/755926devcM888kz82bdrkXn/9
dff+++8nPGOTWzbrUjdx4mQ3efIUN3PplsKb21tdQ0NDyLHZtVbsXIZhGIbR
t0GT//CHPxToddCxdevW2HZ4x/rr3ZC6OlfnP/Yb5R7NCemO+Ud3vV0dNzSX
/1yGYRiGUQ00NTUV1W05nnvuOffXv/41+oRtC91gTzMHuJOmLnet7e0Zs3iT
mzH2H7JaesTN3t1alozy/v3PZ97sFi+e5+bNU8fiVVlbuZznMgzDMIwqgJh2
XN2Wo6WlJfKcyyfs6+nokTNf9t3S7s4fgg4Pc0+4Tr09cdHb3XIuwzAMw6gG
XnrppcTavWHDhojYd5Mbt3dGUz840m0Kurm91TW3tnt/Fb09duZz3ODa2/VR
7nMZhmEYRt8H/SWXK6l2c5DXFkxOb+tGupeKPL/obeDxrdllPpdhGIZh9H3e
fffdVLrN8cYbb4SctcmNQW/7nRCutzk7WPT2i989y02ZQv64HBPd9KXby3wu
wzAMw+j7lKLd1IwFszMXhz7EPRrgq14y9lOZ2wa6Oc1xYtTlPJdhGIZh9H3w
mftrueMeb78drpEbphzs6egXxi8vvKFtoRuKD/ujp2Qs6nh6W85zGYbRe6H+
lPwUbIrkvSQMo7Z44YUXEus2MfLoOrFn3Ij+2VjzfkdPcotW1ruH5l/ohgzI
/uzwqb/z7iV6u9/wMW7ChLFu7Fh1jB7rblv3VpnPZRhGb4J1ZMeOHW7jxo1d
8mFffvll9+c//znVeRvpybS5scvPWxs3ZdavbQGPaHebM495qaCYdKdbNW+6
mzJ5spsy5Rq3qH5LwOMMo2fAfk6q3fRxKUrLo27M0I/48sYGuvEzN3TeZckp
kf1Ujp27vfznMgyjV9DR0dFFs4PshNbWhN0ZtlzpBuR6QlxVIN9Nbsye/Lxr
/sxbub1/vha17QE3Ys+u68iHvzgmY00YRu9g+/btsXWb7xr9zuPCPre+vt7V
l6EvaTnPZRhGz4Ff/Nlnn4297rz1Vny/mfSE4Nj/3MfULbm6lVycTZOvMc3t
8Wcfo/tBZazytmfcRcd8zrvPPqfdW/obYBhlgNjStm3bin5/6Gue1odlGIYh
JO0rgQ89ns2Qi7EdOMING5j5cw9tY4dr91sF2v1i1j7f/QzX7jv3sMx9djvu
rpJfv2GUk507d3r6HPS9aW5uLt4L1TAMowj4ytPkx7722mtFz922bExeg9dO
3Mf7+zlPir2R0+49RronM+tZY2Nj9mhudWtmjFDavdOdPyhrd3/j9Mvd0oZt
BRpuvZ6M3grfLXxUxJnomWo5n4ZhlAty09JoN7OQijFjeLamlD7JbtvP3F4F
drL0eiqeF9Ox/srcHIXOY+8hw9yZU5c7k27DMAyj1iB/PI12Ex+PpG1hbt7g
Ie6aWbPcrBnjPe2WmQed2j3YXTZrvpvFfTjmzXPTxv5TQE7rTlf/0Ew3ecLJ
7rAhn81r+Ke+M7ti741hGIZh9EaS5Mbq43e/+13keZ+bdlioPX3ioh0ur92f
PqNLrqv2tbuOZ9z5x492Nz7py49redSNJIb+oRGWa24YhmHUFOTOpNHuLVui
6qub3FmDsjb2owhzbgZRx5brPdu736HXuth55i23ZGvMcvOFNQu8/HPTbsMw
DKO2eOedd1Jpd1OTX3EVuZruT5y0wHfDzpymD3b3tDZn5yMUrRGTXsx17oDv
XuFW0uelfqm7fPT/ydrxB0yyGlXDMAyj5njuuecS6TY9WqgJDyNb0z3AXbKu
aw3r+mnDcrr826yOR2j3iRLvbnvCjRu6exff+2e/MiZr1xuGYRhGjbFr165E
84f/93//t0eus7VxnVu5cqVbWV/vNjV39Mg1GIZhGEZvgX7M69evL6rbxMcN
wzAMw+gd0KeR/ihB8wzJTYuaV2gYhmEYRs9Bv1P6Qb3xxhteTyjrvWwYhmEY
hmEYhmEYhmEYhmEYhmEYhmEYhmEYhmEYhmEY1Q95xG1tbV6PDXKJ6Ytps2UN
wzAMo/fxl7/8xZv5GFS/y1yo1157La/hSbS8kR7Tmxu7/Ly9+SWvX1fg4bv/
lpVz3OSJE91EjsnT3IpG65tlGIZh1Db0vWTmcrG+WS+88IL761//Gv/EubkT
9K++yiff2TlPYcdI95J3rxfdRYd9MvA+h57pn2VhGIZhGLUB9nYc3ZbjpZde
in3u7NyJrNbuf+5jBbe1NKxwix96yD2UO1bWL83Ojsrc9yNfv9a1Z/67/LDs
vz928Blu6eYW197e7rasusEN3TP7869etrbcb4dhGIZh9Hrwkyed8Ug8vDjP
uBH9Mxp74Ag3bGDmzz1OcFGqv2P+CVmd32Nkduby+ovD5zh23O+GenuCL7kH
bVaUYRiGUUOQlxYU3y52PP/880XP3bZsTH7O8tqJ+3h/P+fJkP6ZW650e9Vl
ZzfflvOti81+Qchjloz9VOb2ge5WG39hGD0K68ibb77pzW1/9dVX3Y4dO7w4
nGEYlQH7Oaluc6D3xfLVZgxHiw9xT/CPbT/ztHm34+7qeseOx7P2eeb2Uxft
yP/43tH9PW2+M8SufmtJ597AMIzuh9yXP/zhD6H7f2a//+lPf0p41ia3bNal
buLEyW7y5Clu5tItBbc2b17n6hs2u3b/w9qbXEN9vWvYvM1tbnjSbW5si/G4
nd591zXG8SMaRu+BOrA02s3x7rvvhp+4baEbUpfV7mtmzXKzZozP2dXDslqe
Z6c7f2hWt7984eqCW+aP3i1Su7fMGB5plxuGUTmwtZkfV2ydoG6EmTVx6Fh/
fW7d8B37jXKPeqdodxcNyf7sny58Sj0ys47kfv6tay/P5sceeq26faMbmTuX
9v21LDna+9nfji/MxTGM3g7122m1mxy3MJ6bdlhoDvmJyrZeMmE/lZtWyOqJ
B3q3/cfStwKfI5vHFq7thmFUDmpO4q4V6HdRH3pmvz84V5Ny0tTlrrW93bW3
bnIzxv5Ddu044ub8/bL6PtDdkIuvbZgyzLvP7kdxnxfdGHJZPzjSbZJz52Ny
hTmz2bjbAPfjdbb/N/oWf/zjH1Pp9oYNGyLO2uTOGpS1sb29Mt/BjDB3bLne
+/70y+2Ht0lu2hfPyDwiAKkv+8wpnd/BHG2rzs7eFpTHZhhGRUkTayuWIyP5
LUfOfNl3S3vOpu702eXXjr+b5Jpb7sxpfuftWZ/dXkrbD+60H/Y9O7dm7Myv
U8+U7Z0xjO6BmDV9V5J+D7dt2xZ+0pzmfuIkf/21fFcGu3t2PJj3jX1m+Bg3
ccJYN3asHKPd6efN9r5fs4/ZI/t9+/gwd9msZa6+od7Nn3JsrmZ8L3eJ7ZcN
o9tJYnPro6MjrKdSkxu3t89W1rS3uubWQs/cDF9/iB8q/5zUrByb2wdcTlxu
3zPc/IsOya4/LC4d93trUL8C37ph9B3ol5Y0T4066zCy++cBgbq6flrWt3Xc
jOtye+WQ46On5Gzxdjd/wuFdb89o+W2m24bRI+ADT6PdxOiCyWl3vidTHB7J
7/+72Altd7iBmZ8POO6+zD8e9+6356mPZQz2i3Jxu7edW3OW9/fDp/4u9ftg
GD0JtneSfTRa3+20vuTqV9a7+vqVbmX9lq45poZhdAvklqfNkWlpaQk5a1O2
L1O/iB4Qvi99y5IzOvfynxnls9dze4FPne22rDlb5c0840Zk/t7/pPvcmmkH
Z/s9Bhr6htE34PtIv7Ri9rbWbXLUt2+3+izDqCXY66fV7vB9v+SJH+IeDdiY
Sy+HOdLLQfVmGjv6oEDbe/nYT3q3jz7m77w/5bxe7erHh7lRQ/uF++gNo49B
Dgo5Jbpek7w04tvaT07N5hVXXOEmTZrkfv/73/fgFRuG0d1s2rQplXa//fbb
oeeUfLIvjF9eeEPbwqxOqzia9Er+1xuJZzfleynrmHfbsk67vN+hV+TN9m23
H5P/+ae+Nbu8b4xh9DDsranfDqoD47b58+e7H/3oR97BbK/6+voeuErDMHqC
5ubmxLqNDRDdz+mZfI+m/Y6e5BatrHcPzb/QDRlQVxCXlr4OWo87a8CGddrt
uVw0b+7BpSqm3XKLFwsPzmk3jOrnzjvvzOv3ueee65YtW9bTl2QYRjdAXxa0
OIl2E2MrSsujbszQj/hyUwe68TNzNal5PT6kyxwD6Qexz2n35n4ifvi9fDHt
JjduUJ31UzZqmgcffNDTbdHwu+++u6cvyTCMbgD/d9xZCElmD0Jr4ybPl0cP
U+vfYBiV4bHHHnPnnXdeXr9vvfXWnr4kwzC6AfS7WH+IV155pejsA8Mwegbq
Pc8///y8fl977bXuz3+2+mvDqHbwnzM3jLkj69ev92xx8lepQUk+h8QwjO6G
GvELLrggr9/kob/zzjs9fVmGYRiGYUTA/vuiiy7K6/d///d/x8tRMQzDMAyj
x3jrrbfcZZddltfvCy+80L38stViGIZhGEZvhj4uU6dOzev3f/3Xf7mNGzf2
9GX1ecj5oX8OeyFiFBzkAkX1vDAMwzCMuNDX5aabbiro4fLUU0/19GX1WZjX
yv4nLJ93y5YtxWck++hofMLdNOUn3u9m8pQZbsXmtgpdvWEYhtGX+OUvf1nQ
w+Xhhx/u6Uvqc2Brx6mlJd8/bn7gqinfDJzhZhiGUW6Y/0o8FR+h1SD1He67
776CHi733HNPT19Sn4HPfJKZi/S7Cuplq9l2+zfys1Rn1m9z7Zn/mrfc40YN
6tdNr8owjGqHGB+5ytQM+tcpeuLv3Lkz1XkbM+thw+bG0Ntb6u9x10z5iZs8
ZYqbPm9Vrg9+jvYm11Df4F4KaPrT2rjOrWs036OflStXFvRwmTlzZk9fUp+g
sbExce/oV199NeKMG93I/tkZTPf4P79td1TypRiGUSNgP1DzH6fnHnMsY7Pl
SjfA8xEOcFd1ke92N+P4gQH+xIHu0hXZOTU75h8d0su+yY3ivt/6ZSkvu2rh
d6V7uFx//fVFbcRahr4XcftO6oNeV6G9rFru8GYx7G4zlAzDqACsPXF0Ww7s
k7gsn7BvXpP3P/exgttkdty+R13h1jV3uPb2Vrdqxr9ltf7TZ3j2d8uSUd59
jp3rn1/d5MbsWed2O+6u0t+AKoUZoz/+8Y/z+n3llVda/6UQyE9LM2uRA197
IG1Z7f7yhZY3aBhG+aHPR9L1ipye4uRmzR04wg0bmPlzjxOc7pS/bf4x3uyZ
W33+xAXH1+Xnv4t2nzjXP0vetDsOf/jDH9zkyZMLeri8+eabPX1ZvY7W1tbU
2h2as5bX7tXd+2IMw6gJivW4Dzqw04vRtmxM3mZeO3Ef7+/nPNmZ9yb+8I99
ZYybvniNa25t73xwe/bvot2sf63NjZ7Nz9Hc8oQb1d+0Ow7kKVx66aV5/f7J
T35SJE5be5CTWXa7O+cz73fotQE3Wg2+YRjpoU417ZpFjDCKGcOz81+f4B/b
fubNbC/U2o1u3JAPFMS6+w8c5L5x8kVuXc4WF+0OOz5p2h0LerhcddVVBT1c
4uy/aoW08W5yzcNnN3XOL75qXWGtxrbbj6n8izIMo2opxVcY2Z+ibWF+dvs1
s2a5WTPGe9pdVzcsq+WKloYV7qYp57njh38ldx+OEd79RLsPOv1aN29e5jyz
sse8eVPdsAFmdyeBHMMbb7wxr9/ksv32t7/t6cvqNbz44ouJvwO6By0z1Z94
ovDT3bZqXO7zvJc7acrt7qGHHnIzJn7L6rsNwyiJSmn3c9MOC7WVT1y0I3OP
ne72iSe5k89b4NoLHpn5+dhB+Rh3Pt69yN+Lcqcb93HT7jSw9xH9ppZsxYoV
PX1JPQba++6773p/5/OcxPZmDqM8Fp+75PUTk1i8eHE+Dr5t8Y/doAGF34H+
nx/ZY6/ZMIy+T2V85k3urEFZG/tRfN/t7V74umPL9Z5dnY3/7XRn7R1sh/95
2fH5OLnlmVeGRYsW5Xu48OeSJUt6+pK6FerlbrnlFvf973/fLVu2LP/zN954
I9ZnH42nd5Hgr6mX3rS33nprzjZvd5sbGlxj42bXsLmlB16xYRjVxrPPPptY
t7du3Rp+wlxN9ydOWuC7YWdO0wd7vSq2zPha1g757Eg3c+Ua19BQ7+ZfM94N
ruu8j2l35XjkkUcK9IaeqrXAb37zG3fWWWd5us3B38nHF6ihiMrfpHdRUG75
66+/7u644w4vl0BrOAe5BjyvYRhGuaCXWlLt1jaHn2xN9wB3ybquvVTXTxum
tLjdzZ9weFe/+p5fchcuzWp1Z42YaXclQE90Dxfi4Yl67/Qh+MxeccUVec3m
+MEPfuDmzZvX5b68B9jg9CJi9ggH9Q3U1+ncNDSf2zT0ECauTT2eX8OZuU7f
2vb2dv9TGoZhJIK1CDs6rm5v3+7X0RJpfcnVr1zp+R3Nn9j9kG+ubUVsxGrT
lvvvv9/98Ic/LNDtiy++2Nu3CqtXr+6iw1HgN+d9u+CCCzydD4KY+DXXXFPQ
Y17yBA3DMEqF2DV9uIrp9rZt2yJqYoy+CvXe5FiJtlAPnrZ/fW+CWDO95bRm
n3nmmW7VqlUF92Ovggbz2olRU7Md5H8gN23z5s3e3/XctilTpkT6K5qbm93t
t9/uJk2alH+MYRhGOUCTsR+YO+LXbOyReL3UjL4K/mDt56UfG5rTFyEXDQ3W
ms1x7bXXBs7F07n3CxZk8zToAf8///M/Xu0X3HDDDe4///M/3fjx471/o9U/
//nP848j960Y7BEeeOABz+Y3DMMoFb/NgH1Bj2dycmyGRe1Av3P6noseYbO+
8MILPX1ZiWCvefbZZxdoNq9F7GU/+JIkZ4/9imi79JK9/PLLvX9jlxMf5xDf
OrVh2l9BnNswDKO7IMaZJNZnVC/s1bA5dWyWuda9Hfaa7Dv8tvadd94Z+Ti9
V1m7dm3+56Ln06dP9/6Nz1u0W34G7G2oB5N6+Y0brd+pYRiV58EHH8yvc/gI
DQNuu+22gh4u/hhxb4LPsD8XjZzu117zz7AphL408hqnTZuW/zmxAvm55KEz
s0e0259rxnujfRU6B84wDKMSaP9iX/OPGpWFWK9oErnS5Gv3Jsix8+eiEY+O
0ytO56exN9Gxffzu8rqpgxcmTJjgaTf7BD/UduvcNYs1GYZRKZYuXZpf88hT
Mgw/v/rVrwpqnIr5oLsD8jNmzpzZxT9OPVbc+jZ84PKa5s+fX3Ab3wu5TfvA
iW2L7U2NmB897+Xmm28u7UUahmGEYDa3EQfiwBLT5ZgxY0aP2ZXE3v25aOec
c06iODM9CiSejR77c891/ZeulcN/LtpNzrof+r/oeensAQzDMMqJ2dxGEqgd
1D1cpk6dGlhvVSnIRaMmy29rp+nlqvPT1qxZ0+V2dDmohwo6LtqN9gdBLzad
u0Z/VcMwjHKhbRf6shhGMeh1cuGFF+Z177LLLovsj1sumBfiz0XDXm5pSd6H
j/59QflpGqlzD9rTRsW8BXq06dw1ep0bhmGUitncRlrIof7pT3+a1yb6jJCD
XQmampq8vYI/F+3Xv/51qvNF5adppP8Z8XM/vHaxvf3zujXkBeg9juWuGYZR
KvSHMpvbSAs9e5jrIdqEHuIrLhfkopFL5vePX3311V7/mLQE9U/zg29e7sM1
+GF+qmg31xOF5a4ZhlEu6P1kNrdRKsS6JS7Mga3K7I1S2bBhQ8HekoN/M6u2
FIrlpwn0X5PXRP9SP2i7aDc5clFwX527Rh26YRhGGszmNsoJfcN1D5fHH388
1Xmwp7Fj/bY2tm855pIWy08TdDw8bOY2M7+LxbwFeq7KnFXLXTMMIw3a5iZu
ZxjlgPpo3cMlyF6Nghpyfy4ace5yzULRehwUw9bo18J87iCIX4vtrXu3hPHY
Y49Z3zXDMFJjNrdRKdgX6h4u0ks0CrQZ/7XWbDQcLS8X5KdJbjx2b5geCzfd
dFN+DxJm79NfTrSbuH8c5syZU5C7ZhiGEQezuY1K8+STT+Zjyhz0xw/TP3qI
+v3j1G+XkosWhO6fFpafppEcPPYUYbAfEO1mPxwXauJtfrdhGEkwm9voDojn
So2V+Kh1Xtjvf/97L8fLn4tWjjw3P9Sjx8lP00gNGfHxKLhmiXnH7VFDfr7k
rhmGYRSD3hZmcxvdBfViuocLszmY6YWO+21t+pKXIxctiLj5aQLXIX7/YjVd
zPUW2ztJ71PJXTMMwyiGtrm3bt3a05dj1AD0a5EeLvQi82s2OVvFYs+lkCQ/
TcBOl8csXLgw8r7kqIl2J41fR/V0MQzDALO5jZ7ixRdfdGeeeWaXXDRyLypJ
0vw0AdtctJvc8Ciw0XktaDf9hQ3DMMqJ2dxGT0Betd/WRueY00HMu5LoOWD+
+Z5R3HffffnHPffcc0Xvz/3E9o47e9QwDKMYZnMb3Q3zxtA0rdnYpT/72c/y
uoh+19fXV+T50+SnCcTe5RrJKysG8XTR7sWLFye6zs0NDZn3oME1meQbhuHD
bG6ju8DupEeq39am75rkoukaZ3LCKuE71/lpSfcH9HXjccw6jQM95ES7i+2N
X331VW8vPX36dC/XvK6uztXte4YrXxd4wzCqAW1zM+vJMCoFeWHM9/Lnor3y
yitd7ktPb93DpVhOWNLrSJqfppHcuksvvTT2YyTmTZ9UzQsvvOD54K+77jrv
vZDrkqPfP1/sWhNfoWEY1Y7Z3Ealoe6LfaE/F61YT1TywHQPF2zzUvHP90yT
w44vn8dff/31sR/DPkRs77lz53qzw6R/edDB/ZkBZLptGIYfs7mNSkMOGHql
dZueZMzOigO9WLTG4W9PEpv2o/PT4vRj9UOPcXk8Pd+ioPcbc0qY0a33yOTU
+7WafQS14Fzf2rVry943zjCM6kGvJ3HyZQ0jLlu2bPFsR63Z+It/+9vfJj4X
fmWxlTnQ/jg5Yn5KyU8T6Acn18HeV7Nz507PV3Dbbbd5/nTt8+e1a58D+xF6
u9J/taGhoaT9iGEYtQNzHMzmNsoNGoQv2Z+LRs/yv/zlL6nPSw8XPqeihcSc
k87ZQivl8fRUTwPfGzkHcfNf//rXXm+1iy66KNT/LXlt4jMn5l+pHnFGenbt
2uWampq8vSK2DH0H+NzZvsroTZjNbZSbVatWdemxQs9y7N1y8NZbb3m9yUQP
6asS99xcmzyOWR9poIcrNj/aK/NFwrQau/7GG2/0cuTlGrH5Rb/ffPPNWM/5
oNWGVRz2UfSgfeaZZwKPdevWeZr+/vvvJztxe5NrqK93m5o7Iu/W2rjJ1Tds
7pLb0NbwoLtmyk/c5MlT3NRZSzLnSfb0RvVhNrdRTt544w3PDvbnot17771l
fy5yzfScLezZjRs3Fn1M0vw0fASbN292ixYt8nLRZW6K6DaHzivj9eNboAfq
66+/HnhOtFweS1w7Dh886GJn8l053nvvPe/3HKbb+mDvlkS/V0/8XLbGb/cz
XFPE/RYcn7lP3QB3a16bd7oZowdnH+s7Dr9sdSkv1+jjmM1tlAvitf5cNGaK
tLW1Vew50VWZny09XJ566qnQ++v8NHK8g8AvyvrM7dR+Sy65/5BaL/wLzA2l
5zj+gDgQKxftZi8RB9brr162NtZ9jeQ0NjbG0m05mCUfjxfdqD1Fc/dyV20K
v+e9o/tn7jPQzWmWf3/Ge9yHvzjGLd3cktl7trr1y652w3LnO+dJ8+HXImZz
G+WAekJsWH8uWpSGlhvyvLXt+/DDD3e5T1h+GnpLTxb0Fz+8rkXzH+g4/d7Q
dck/oz9LGsRuR/vjMNhb+we7e6xYrOyQ75hEtznIK4yTt9Gx5ixPZ79yzHA3
IPPnPqf9KvS+Bdq97RduYK4fTxdbff0k75y7HXdXSa/b6JuYzW2UAtqH79ef
izZjxoySctHScv/99xfkc999990Ft1NHzc/53NPL9Be/+IXn39aP8R/4x9Hm
e+65x+vdKq8L33upteacW2zvSs5HM4pDT6Ck2s0RFhPRzD6GPdeX3KMdjW4M
9vIHR7ow01tr9475J3j6fOTMkDyOzGfQYii1h7a5yYs1jCTQ29Ofi0atE3k+
PQn53tpuRqNZl9lPYOfi5+YI02r81+TGsw8gphkG+cfymCVLlqS6VnLSRbup
JTN6DuoY02j39u3bo0/c8Ygbgu18RHa2+9qJX/T0+AcrgmMrWru3zBjuxb6v
2ix+8Z1u2uij3PBjjnHHZI7jM8fJPyl/HonRuznnnHPyay6fW8OIAznRl1xy
SZdZX+Rx9QbIE6aHKj578UnrnDJ/Tjj7VjSUvWz8+GW2z1vaHugC+i/XFLcf
ulEZmFOXRrupHYti2+3HeFr96aMnuVmzZrlpY7/s/Xv3b80OvH+Qdl+yTrS7
yZ01ZHc3YM893UCJn+9xgvW3ryHM5jbSgA/an4tGfLi1tecCsPjtyfsiT073
FmUOmeii3mPgH8fGRXvpn5IWfOii3aX4GuLGvNP0fTPiUxm7e6c7f0jX/PDs
cYh7tL3DLZl8mhs/fUP+EVnt3svLMxef+eFXB/Wn3unG7Z05z0dPicxbN6oL
s7mNJGAfkqOlNXvChAluzZo13X4t0luU3DT6hkbllfnruNDHlpaWslwHNWDy
HKX062DmiFyftuGIqxMDJx+KXP24+WxGOioS7952nduLfLLvzPbi0jKvfdXk
oZ4mHzv3t25U/05/OmS1e1hG1zsfj23tj4+3rTrby3ur+4xpd61A/q3Z3EYc
0CTqr/y5aPysu3LRsOlXr17txa2ZxxGVV4bNje2NDY4tzjXSP0XP7SK/nNma
pSJzQ+PWd/l5++23vfxQctblfWV/hB8DPZfXqfceRuVgT1juPHOp6e5Sx9Vy
SzZ//KAL3anYznUD3bnzVrlV83+UrSVQtvT80Z/N2ukfH+amLl7lGupXuhkT
v5XVbdPumsJsbiMOxHCxrbVmoy1R+VvlgJgz+8s4vUXROOaRkCsWVCeB5nM/
PvM6xk1sudS6CuZpcy5sYj/aZiY+xQwWcuXow0otpq4Xx7evffphPgPT7sqT
tL472ofTlPVpB9jMnb70wW7W3Rdmbev8Mdhd/eRbBfe9fcLhXXzu+x19sbv9
/C+5ug+YdtcCZnMbxcDOZXaGPxfNX29VLogVk9NNbreeMRLWW3T69OkFvUXD
wGdAn1Tpn4ZPlHo2baOnmYUC9JphP4Adz/eIunBmbvtt5riHxOT5k5o1bHqu
GT85+ye0nl6cRmWpZF+1SHL9UleurHcvhRV9cZ/MXpCjsUhfVaP6MJvbiIJc
cX8uGjnlpeR0abBHqZEmz4teptJbNOiQ3qK33HKLW7FiReJZI7pXi87zItdX
fo4+0rdUQ556mM2MTqOj2PBiC6OtcfSZ18PeBDudfQp6z56FOSi6zpvnxY8u
j8O+T5L/bpQGv3/yz8I0O3U/c8NIidncRhjYENihWrOx+dLO1xLIzWG9QzvR
o7DeoqKj2K1oK/76uDO9g8DGlhw2bG+dS0acmTxzbGZ0l9fJfXhutDWOzcxj
/drN+4c/nHg7eWxoPnPF0GK01z8rjGtiP0IeIH5/2TPhJ5eDc+NrEFve6D74
7NocMaM3oG1u/EKGgR2MTenPRcO3nGaNQhfRe/Q3Tm9RfMP0FkXfy7Emis2M
hoouY+dqmzlIfyUHvZjNzGvCZuZPzs85sNvJc2KvgR+fHDn6muPXJ87Ae4Gf
n95sxCLQYqljC4p5i++c/Dr/bDLDMGoL9v9mcxuatWvXdslFQ2uff/752OfA
bsSfjZ1ZrLco+WHM4MIvz6yvNHnq9B3HBkIbmUum48xiM2tNxnaNaz9LrzVy
5NhPLF682C1dutTzV3GQD3fnnXd6Pnx83NKfDR1OGt/2H+KD13PX+F3gL+e1
EV8gt98wjNrCbO7qBnuTHDN8s9idr732mtu1a1fgfcmzwhb123nUVRUDuxJ7
Ersc+zFKj6S36AMPPBCrdwmvgeuPijPH0UGpB5P+aegq+wbOgQ5i66OF+KnR
fWrIsLlFi9F7vi9RzxE0+zPqQId5P9jfEDvgeemlTixBZppo7U7bp80wjOrB
bO7qhXwZ6lTWr18fmFdDPiLzkQR02++fpWaaPqc6j5WDxy9YkLE1M/YmOof+
/ehHZ7nTR492o/Vx4onue2ec5fmp0do7bpvhHnn82cILzZz78Uced/W/f77A
Zr70golu3PhzY8eZtZ3K68Bu5k8ei/2r7Wj+7vdNF7N7tQ0ept88l+wP8Fuw
D+B1M1uUHDz2HfSsISePfVRULIA9DbFsziu94Tkv/gnDMGobs7mrE+xU/NvF
alnIi9V54swQkVw0+oIKr955VEjvxo+5/3tizvd8xr+6/oH3qXOH/eD2zB7i
127ER/j3Pm78DTfnbebjhvTPziv84rc7dfCs490neGz/A904pcUSp5Z8Lf4u
tVJyiGZrfdX6GzVrJCjuzt6B65Qe6BycD9t/1apV3t4InZXer7InmDZtWurf
H75/nWfPubQtbxhG7WI2d/WClsTtIYF+i/2N5lM/hQ4xX1t6i/7w2wdk9PWD
7p/+/393J2Zs6RNPHOWOOmyw+6Cnr19y52bs6qlT/t3tkfn35755RkbzznHj
xo1zJ333G+5vd0ev+7sjTj3HjTroY55OH3zC+JzWnuqG7J7T+L85wH0vZ7OO
/c5XvJ995Isj875q0Wh0Ge0s5rsO85Wjrbwm7FfPF5B5jcTZiVvzmtnD4p/3
28TknEm/NA5sYn/8n5i73E4eWhrIZ9M+AWLoIH4DXothGLWL2dzVCTqctH+j
rucnnqp91OjkuGO+4OnviHFZ/eRnHId9Gu3+gjsFHR43wrO7P3/UaQXzNE//
10GeDg8+8ntu3LcP9P7+iaHfzerQ9/7F7Z63z3d3w793tqfNow/7tPezg44N
zydD36jfIj+b2ivi7NR3YQ8TR8dvgE1MHpnoPPncpUAOHXF6fQ28fwJ5dnIb
88qSQi92HbsndiBQSy/7D3rCGYZRe1C7IrpNvqpRPSSxufWBXQnksukZW/x5
ypGDPO0e9m+nux+MPc2NzRz/dvQ/enZ23ccPdqdx/9O+4enw5w4/MXOfse70
0093p3/vO+7AT33A861/a1zGZh7/HfdpHrP3ME+bxh75uex5vz3M68G831Fn
evlhx30+28f5vJlzPO3l84qu4UumjjZuHnpQ/7RyQP90nWvGXHDgOuXnXG8S
iFfoujl/fiC57fJ7Id5gGEbtoW1u8maM6uHZZ59Npd1oouDPz/peznYOOv5u
xGnZOPMZ38xqedDxmW97PuSFC+e4k/bnZ//olvzud27KMP5+lGvK/OfNTPon
ZiZtdCP4+wGTXFgLyLhQtyVaOGfOnBLPVgj12TpHjT5o6K38jFy0uKD52tfB
fsUP/UDk98H31zCM2sJs7uqG+HUa7dbzs6jxkjgzunzGyC948e6h/3qsG3Pi
ie6UU05xJx93mPssGlv3CTf5/nXuhYar3GfR8pOucPPmzfK0etZNl7mRQ/bI
zhme+jvv3GsnH+DNIL5tc70bmfn57t+a7f18wfGca6Sr33KrN39h/3MfC3p5
seH1hPVPKxfEyLXmSs91fhbXN4B/X87Bn9TZhSFzx/nd+HuxGYZR3bBGmM1d
vYTVhBU7dF9sqWESP3rLklGe3t7ZWvhcO27/enbW8MyXnWu7w9PcExe97bui
Z9wIbO+jsnOIO9ZP8h7ztdHHe37yb899TT3HAHf86H/2br/APxsxIcS2RVPx
R1cK8tskRi37HfY+cSBHLsj3HgY16GJ7s28wDKM2ePTRR83mrnKICafRbqkV
wz7l80EeFj3R2AuIdt/tc2JvmTE8q91zt4drd9tCb+6w2NfOPZ71iXv+9C+5
e1o77zdEfOwfHuaeKOE9QKtFE8ljqzTkqFHjLvnsxByK2fn0XdG6Td13MbDJ
RbvJlTcMozawOHf1Q65ZUt2m3wozDmHDhg1dephLvPvAfznK/fC00zJ25mR3
1vEHFepvRrsHkm92zLjMvnCiZ4tOnHiyGzQgq8f/On1r/hqnHZbT6H3Pdp2m
vMwtrnP9DroidawbzZS+buXMTysGM1tEu7G9sZGpGQuCfHhdQ65z1aPAD6/7
wglRfnbDMPo2+OPM5q5+iINSI5zWX06c2q/d2Tzzrjlou//toe7mJ3M1zhnt
HhyUp9Z/sBs/c0PBNT53zQjvti9fWFjrtHbyVwpi42nQ+Wn8vbtgNiR6in7L
/DD6yekcQH431JTL9dF/BZs9Cey/JebNjBN6rFu/FsOoXszmrh2o8Y6bs7Z1
69b8vGGpD/Nrd9DP9IGdSf0xfT85R09BjL7S+Wlh4PPmefmeSc6a5K8xKxLd
1rXh+NiTzHYR6HkutrfOkysn7Al4L/ElcJD3xxw4m0ttGN2L2dy1B/pdzP5u
bGzM5yvjM+egPpz+YUEaTZ4zWuTve+4/sDup06Y/CX3Suwti26Jluqdrd0Bd
lzw3e2P6vGu/OL3htZ5jp6eB77LspaS/a7n6IlKHFpUvQQ8nyV9MdN7mTa6+
vsE1dQmEtLvGhifd5sbcZ6S91W1WffPl2NzYXPCo1sbs+V5q9Z/PZXvvZ25r
2NyY+DqN7of9ILk2rDv0iOIzxjx05hBKHK+W0TZ3Uh+d0XdBl/HZ8p2Q/HP0
HM3GthL4/lD/jI9XtJw1mr5e/lmg0u+cPLaFCxd6c8eC7qMPfMnkfZMrmWbt
jwOzwbszP82PjmHLa7z11lvzfnSZgUIsXscoksLvSftD2COU4z1lrxenRgEt
DYvjB9PkxuyZjZ/sf+5ThTe1ZPMb63J5jDvmHx3aR6DuYyPcPc2F56s74uYu
z7Z24j7Z2/qd4F5K+2YY3QKfW/Qo7LNG7o03CykhoXtFb1+3xQVt+QLO4u0j
A/eH3QTzEszmNsIg/4mZk/IZoceoHzSX2GyQLuPDxe/OzDL6lWBf4kOP0nL0
Df8xeptmVrcff34a80i7G2aGiS9cYH/E9eg5KHfddVeq8+OzFr+C7nmHrVwq
/A6S5Eig8bHjEesv9moBsz16TinU01x+4yePy74n2XqGOnfoeQtc/cqV7qGH
VrqVKx9yl4/+P0qrm9y4QaLpw9yjBS9f3ZZ5rqaS3xmjUvDdkJmExY5kcbjw
vaLsDW+NsXV+K/dZPHJm968lgtncRhCsvdRSodXY5TqmjR4HQeyT24L0GG2n
74+AD4xcMTS1WLwcnzI5V8To0/Qc6an8NA0+C56f/HLADyh+cvwS6DY2OP9m
NncS8GPrmeh6Rjj7pVIhnp20NiHO3HW4d3R/r7/tMcP38+r3f7xOaX5Ou3fz
afeJi3b4zrLTjdtbbGmt3b77brkya8ebdvdq8IVjUyf5vGk/YSQRe0WpdZ0T
Q7vls+jVv/YA2uaO2y/CqE7Yt61YscLr44UW4IPRezp6qWqNxY4Mg+8R+egy
V9rvT8fX7v+uEQPGr8z8rSgd5+A+9AyPMyNH56cRRy6HHZoG6c+CP4FYHTFo
0VpqsYlT6zkjxBzi7FOWLVtW0OecGAV9WUS72TOUAvGSpHUJ4jsvfv2Pu2Gs
oYde69q2XZmdQ3PSfZ03h2q3r0dAyx3Z2v+DLnbtaDc6vueXsvWHym++eiL9
8Qe744d/2tV91LS7t9LU1JT488aaFYeovWJf0m6zuQ2BXCr5LPzqV7/ycrnk
37L+Y/dqDSWWWgxmyYb508l5I8faD2s+30fqpdCzKB1Hn9hnEOcNsvV0flol
+6dF8frrrxfM7NQ2Mu+B7CfQSD2XmzmkYb5nfi71X3IQPxe9lBg6Nn0pdHR0
JF5H5ZDZsWHsmH+C0uKc7Vw3wuWr2UO0e89BQ9zQoUNzx5C8HfWjFcTZc9q9
7xlu2ri9Mz8/JOc3z/lKv36Fu/2sjHZ/wLS7t/L73/8+1eeteJwmeq/YV7Tb
bG5Do3vqUcsF+HDlZ5I/RY9PrZ3oaxzQaHLLw/zp2PxhEG9Fd6+77rqCnr1h
9Wj4ovEVY5OKrvXkbC3ivzIvVc8VR5v98XziDjLbTGxyf+4XvwtiGTpPXccj
QMfRmbeeljQzY+WIft52d3muB893psxws2bd5EblfN3/sTTn5w7R7v4DB7kh
Qwa5QRkNHzRo77x2n+r5x3Pa/amz3eb1P+3cG2z7WX6tXT32A6bdvRS+D2k/
b9L7MYxie8W+ot16DTSb2/jtb3+b/zzIXOh77703/zOdm42Oar3E3osLvnL8
3WH+9NmzZxeNXZF/ij3PNRWrRxM9xy4vRcNKAT+GzAnhT757zBMPy8PDp/7T
n/40r838nZ8Bs0O1bY7PAb33g09EtLuUGWn4BNKupZG/x5asLgfljH9E/Nxx
fea5GGa2r25Ouz96imt1L3nzbOiVv+ryAzx/+QOZeywfXWfa3Uspxc+Dfyuc
4nvFvqDdZnMbfrCL5TNx0003eT9DW3ROuF6LsZO1Pv7yl79M/JxoGn3Rg/QW
OzlIk4KgRpw4PTZqsXo0tBPNR/srVY/mhxi3ns+J37wY2Nq8HtFobHHy/XW/
Fez2sNdAvFmes5T6EeLdaebXEF+Jqr/dMOXgnK3M2teeixu86M4alO2j+yD/
DNHurutl1heavZ/W7oxOj/2k9xjPNj/oCu/e95p291r4zFTEzxNjrxil3S0P
/bc7+czZ+V7MPaXd2uYmtmAY1EkG2di6Byr5Uxq0V+vi/PnzUz03/cPQqbC8
NPaaSSBuLLnbxWxyvgv44vElVKLPGv4M/Amio7yfceF60Gd87ZI7zt4D/aZ2
vhjyGP4sBfrEJF1Hg/IYOnnRjUFfPzjS+Ts4iqZ7/e1ja3dGrz/eWSM2Jqfd
njavmZRfo6Wex7S7dxNV0x11vPvuu6HnjLNXDJupBNkZxIOze8oMbcuO73bt
NpvbCAIbWz4XuoYbW1t+jhb6/bzYu1oLJVaeBp4L/3uQPx0tvuOOO2LZynq+
Jzl31HPjN8b+LKbnxI6J4aO5pc7AfuKJJ7y4s+SNpelNSv4sPVtE+zni1pDx
WuQxpcAeIm6trdjcu3btCj9hrlbrC+OXd72t5RZPr/sdekW+B/4nTlrg3dS2
bExIjVjO1s6srfe0Nmf/fsCkXI+NjW6UV897iHswZ5Z5ucaWZ96r0OsKvSCS
6nZ0/+B4e0XZG35t9Dg3YexYNzZ3jD75fPeL87+U7S2Qsb0b1t+T87cPcFd1
Y/tws7mNMORzgX9WM23atPxtQb1DmDOt9Q89LxXyzMJyzPELhNUP19fXF+Rw
B0FtGTF3bPpiteXch9q1pD3+yR0T/7bke0fV1QWBX0Pqv9jPSA04540zG2z6
9On511cq+CPLE3c0jEJYL/h8U88J7JmT5JqXa68o2t312Mvdtq0+Hx+X44if
BJyvQpjNbUQhNimaqWEfrOPFQSxYsKBA89DecoDdSc1ymK7qvuRp+qexTvDd
p94qTj0a56e/S1TvkaVLl+Z1mz9lbhh7gDhggxCf0PVfxLrvv//+gnh3sRgF
+41StVv7IendRp1/2BpKP42eygc0+h58d3UtC3tNAS2O258lTV/UtNBfn14M
TzZ23xwGMJvbiELyvPTsZ4E5YPLZCavnwqettY66s3JB7hb6FdRPletGT8mX
E13jWtKAbtKLVWZ6Fctfl3o09jdAzECuQeLS8m9q6ItBf/mo+i/i8roXS7Ec
/1K0m/owfBz+OaXY1cyDYG/AQWzbZkMYcUGTg3o+kPOi7Wf24vRTDtNsNIz9
ZLWje234faKGAdKrB/+VH9ZoHRMOA1+0/j6We14X2oG/GP0K0lN8B6wL5eqf
RnydPQgxdG0jhD23zOdGt/Hfr169Oq+zzAGNghg7/c51/VdQHI+8b10nRj1Y
UJ4d9a7iS0kKexjq8fWcUsMoBepG6PPk/97wOY/yY7GHxJ/OfpHPIf40/Du1
MnPWbG6jGLIXDsttQlfkMxTVEwD/s/5url27tiLXS9ya/uBBOoreVKKPGvY/
s0vRtTj1aLyn3I99UdRcT2IO/vqvqL5krGF6DjjX478/PgDxUyRF+uBID/bu
nHVuVBfMCgmac4ANgA1uhGM2txEH3cM8iKA+qWHgc9bfU3xclQK7OGw2GTna
c+fOrVgfc9YlepPHqUdDv7GReR9FC8mtlxlj4mdHx+OAL1tmnPh7uAD/xldA
DX0S8J3IOXltyWZ6GkYWPtv0IPJ/D/hMltsfV61om5tcE8MIQueEhfX80n5j
ZgZEofPTseWpuy43/vw0dDrIn87zo5GvvPJK2Z6b90ji4jLfk1g5NVxx9Bwt
Z2/Bwd95fNI9DrqKXax7uOBTxNeOrcN7nqTWjdi9nItcwFJmiRu1Cd9JejP6
aziIxcXJ+TCymM1txAU/rXxWdH6SJqxPahjaV8Z3Oc7srySgk0H5acTnyfkK
0ky+B2hsKbA+aXsZ/3WQTxyfOWuW9GeJ0nJ8iOSeJY1p+a+FPQD1ZUlzx8iJ
k3Ngq0fXzBpGV9Bmvw+MPSx5pGH2gBGM2dxGXHScmpndQUT1SQ1Dx6T5Hpcr
70nP90SPg/zi5LTwuoJ86ti71Fkl9adzf/YkonPY/UH2KfauXJ/Uv2BXo63F
dFzq0diPxOkNy++FXrY8F/F4/3tQDK5LrpU/KxnjMKoP9n18n/yfYz733dV7
uJowm9tIAnVWcfLLovqkhkHsVet3VF5pXHT/NPK5o0BH6QFBPDlIJ/E5vPrq
q0Wfk70KsQUdDw7rRcLeQu5HDBtfhvZvo5HUvd1www2B1+W3XXgPOU9UrIL6
Pcm/xe7Gdi6mw9wHO1uuyz+TzDDCoDYiqC8CfZG6s+662jCb20iCf4Z3GMX6
pAaBdupcOOxg6aOUBuqtivVPCwOftK5X1we2blgtFzVX1HPL8/L3KJuWmV9y
X+aj6fovnsfvf8CeR3vxfxerR8MHzz6AGEbQGsn7je9EamHDwF9AXFuuix55
hlEM6q75DPs/l+ROljOnpBYxm9tIStAM7zDIl5b7BvVJDQKNRye0/khPkyT4
89Oiaq+iQIvpXR6UU0Z9Fzau5IOTv61zurG9o2q4AN+19DOV2Z8c+AvixBrI
Q6OWHf98kD/S7//XvezYF+k+FmHnx28g15VkTopRm7DXC+pzSF5H0r7BRjDa
B2c2txGHoBneYcTpkxoEWqh7KlH7/MYbbyS6Tp2flmb2qB/2FNivQX3U8Kej
ndo2xc6PEyMn70xmeUkf8rj1X0Gwf8A3Qg5e0LwWyXHDV06f1yjt5vegff/U
cxtGGMzZ1ft1OaiPoAeRUR7M5jbSEDTDO4o4fVKDQPd0HRc2Y9w+2Oz7JaeK
3O5y121TU4UvPCx/jJhznD4lvJd6/hf7FXzo5YT4PLl22M7sEaT3OD50f/9I
Df504vu6r4v1XjGC4HPBHtSfW8meu1wzC4xOtM1diZpaozoJm+EdBvVecv+o
PqlBkHuq7Vzs0jg9QHQtVCX7O+AL+PnPfx6YD861EicI0ztyvXg/ZPYnNnJY
zV0lIJctSrtvueWWgn4ucfz3Rm3B/g4fkT+exL/xe5U6H9foitncRlrCZnhH
ofukJq1LRjN0ThZaElVPUkp+WlLY85J7jU8QGyOoxgxdxtcs9WGsZ9goco3c
zuOwcbsTf6xbaze9a3QfF92HzTCAPFV/v18+y9SUmH+mcpjNbZRC0n2f3ivi
u00KvnLi5XIO/OFBfnDWDPLUS81Pi4PUvfhzuJgBomvd9IH/XvcX55DZn8Vy
B0oFbWYGk9SG0ac1SLvxccq14cOPUzdu1A6yN/Z/tvF1Ee82KgezF8zmNkoh
bIZ3FEn6pAaBf1rv87F3/ft7bS+WIz8tjCeeeKJgxib+QT/YqvRpDspPxz7B
Vic/XM5BXXklQHulxp3Yurz37H382s26LLNOeH22rzcE8sN1/Ycc5LNYT9zu
wWxuo1SiZniHkbRPahDEg3XuNGuJ1I1XOj9NIE6tZ3ktXrw48v5cHznoQTFx
8ZfzPmLHlxP2DvSK09fKcy1fvjx/H//cY/Ej8BibA2EAuY5BfQ74jvH5MboH
bXPz3htGGqJmeIeRpk9qEMRp9Xmo4ebcOj9t1apVqc5dDOxk0UL+5N9REJdn
1opcF35/ee+C1sKnn3665Gtkz4IfQPvzZYaJ9FCV/c6uXbtcQ0NDXrvl/vfd
d1/J12H0behrgL/G/znlc1/ufaZRHG1z20xUIy3FZniHkaZPahD0StW+aK4H
fUJ3sHErAb3E9AzOYvVuXKPE3iV2LPVfxJrpcRpki/M66HmTdCYD91+6dGlB
XzaZOSLzwaUWbeXKlfnHkbcv+s3958yZk/zNMaoG9pt6ZoGu0bQ+uD2D2dxG
uSg2wzsM1gVdR1LKzCBqo7V+83d85uXoge6H+mjdX7zYfDG0Udu9YTFB+p6E
zQ7jZ8TL49SNEafWvc/kOnX/calFYw3GptJgq/N+yiwUo/bgu8i+zZ+fgY+L
ma9Gz2E2t1Eu4szwDiNNn9Qw6MWtdQ+9Kjfkf4v+ocdRfb+p/5o5c2aBhmLD
hNXMSM45tWycF/0N8qfTZzXoeZ977jmvZ4p+PtFt/8/YI2DT09816vqN2oM8
SX8PPr5Xt912m9V79TDYCWZzG+UizgzvMNL2SQ0CW9YfPybuXS7w6+tZ1VG5
ncwJ0/1D0c+oeDhrosTOdfyA9/P6668P9afT75SYPza51mZu4znJe9PXQI8V
/Tr8rwE/ha3PtQn5iEHzbNhfWy+e3oHZ3EY5iTPDOwqdt8psk7RIz05d+y1r
TyngSyAerWPG2LhhEC/WcWZqL6PuD2im3D9opgvXgK8ybFaY5KeLVmvN5vuO
tssMNrHvyVPzw5wx6tHZExi1Afs3PS9ADur/ycUwegfa5qamxjBKJe4M7zBK
6ZMqPPXUU3mtIj+Nf+t1KMo3HAU2qO7jje5FxdDRXV2HRf3b22+/XfR5mM0Q
t28rry0sPx37XM8f49p1PxX9PhG31/B7EJs9Sc2A0Tfhc0z8xf8ZIn/FevD0
PszmNspN3BneUZTSJ9XfP020VedjchCvSwI5W8SeReuwU8Pmh5N3h32vbV16
w8SF91Ae65/RrUHXZZYptnVQrxfJ1aPXqj//AP+7PI8/X05uQ7eT1OobfQtq
/flc+z8z7JvpA2j0PszmNipBkhneYZTSJ1Xnffv7p1G7pdenuP3ViO/peDX2
CTHsILBR9Jxu/I9J/Q+6p3lQf3b8mvizdTybHHEOsZPDNJz5bvSh47yS7+6v
neO1se+Rc3Efo7rgM03sxP8ZYZ9WqR4IRnnQMxRtf2WUiyQzvKNI0ycV21H0
CH92kO7hC9Brld9X7IeaKWZ6ik7yd38dleCv/+K+YbZ5FNKnFP+D5uWXXy6w
57Vm69w0YtT0ZsUnjl0epONcp/jTH3744YLnYU/Dz6n7lnMb1QG+F76X/nxH
9miW19D7MZvbqBRJZ3iHkaZPqo5F6x4jfqh70etWmH8A+1PXRmN7B+XYsh76
67947WlztMVux7YG9grY4hI7l9lkHDoPjVhBUI8M9j70cAurFad3q/jTuWZ8
BdInVfLojb4P2uyfZ8fvf/bs2SX1UzC6j2q2uZmF9O6773rxyffee6+nL6fm
SDrDO4ykfVL9+WnFoBeaXsP88z6wlyWWLHXWQX3Q8T8nqf+Kg9RgMx+UfHLd
RwW9lhi0zpl78MEHi9Zgo8v4GfzzGcWfTg4fz8c5sbdljlklZ7cYlYc4lr/e
ggOfedTMXKN3Ua02N+sSPkVy7vQMBWbcUNsg8w2TsGXlHDdl8kTPnrls+hLX
pJfu9ibXUL/FtYY8tr15k1cf1HnUu4bNLaleW18izQzvMOL2SfXnp8XNi0XH
9FrGjEsgv03P48SeD7Kh2ffyHdL1X+RnlwK5Q6LRWp/RUjRb+8exj/EZJLXv
77jjDu88QXa46DgHz8/7GRbbN3o3MkPG//tlH8oe2+hbVKPNjU9Rz00IOtDw
+GvcRnfWYX/j6urqfMdAd+6i7NznHfOP9n52a8iIuwXH+x+bPT584Cj3aJjg
Vwny+Sp1jmzcPqkLFizI61nSGDs65o9/63ps8q2Dnhf/o67/+vnPf+71/y4V
7F7pUSrxZvwPYgOLD5u89bQ2E78X2WvgX2BvEuZPJ2ZgPdX6Fs8//3xgngOx
mFdeeaWnL89IQTXa3Mx0j9JsfVBvVDyu0+4uH5rV2f2Ovtita25z7e2tbs38
H7mBnv4e4ugY0rJkVObve7k5Idp97+j+mduHubkrV3qx15UrF7nzj/n7rIZ/
cKQL757Z90kzwzuMYn1S6TVWLD+tGNSL6TVObFv6zPjBb44vW9d/UdNeKuQJ
EGPQc0F4HyXPW3wKxNVbW9Nv/sgllPPpujX2tewJwuxwo/dDX0Ldk1gO/DMb
N27s6cszSqDabG7i2X4febGj2DyKjvU/dQMy+trv0Cu63PbctMM87T110Y4Y
2p3R6A+c4vwZ0ssnDPHOcfjU6p2PnmaGdxjF+qTGzU8rBr2/9XoXFKvfvn17
Qe4aayKzPkoBf7Sepa1j/LKH4Dbugz+9VHS/VOYvC7w2XSfut8ON3gv+Hr3H
lYOcRvr8GH0bfofVZnNjcyXRbTmifOdbZgz3tPUHK4L8n+2utTlr86TVbtdy
i9src/7dvjM7zUvuE6SZ4R0FcXP57Oo+qczNFB1Ce9OCP4p9rT8HV8/4oOZc
54ylrf8S8A9g94rPAM2U5xe7G83GZ681thTwGcjz0eNSQ29z2TvInoGcdXrA
J53nanQPrGPUH/j3WeydyV00qgNtcxMbrgboC51Gu6PslwXH7+7Fte8s4pZM
rd1uoxvZP6Pdx5U2J6s3k3aGdxhBfVKJfUh+GhqXtm8j/Vp03Bq/u4734tch
Z65c9V9cNzntElMXzcbWxa+g53FG9VRLA/nv8hokLw+w23hf2XPx/Nyu8wyD
8uuNnoP8A+JH/j56/Jv9oOUnVA/VaHMD/aXSaHeUHbN8wr5FtDu7jqXW7o77
3ZC66tbutDO8o/D3SdX5aWhrGtAy0W3+XLp0qfdzasyC4t/sf0uxZ/geSu22
9CxjvdV5aOg4Gk5/lnIjtWy8Dp0XIHVhXI9ci/XW6p3QW8hf48dejzoM22NV
H9Voc0PSWLccUbmWWU2ucyfODZiZs2aSd9uxc7en1+4tF3vx9H1Ouzf16+7t
lDLDOwzdjxzbWHy/7EXT5KfRj0Tnm/l7mpCDrddH/OVp833wG8gsbdFsySOX
a8DO1TNIyEkrJ/Sck3MT8xb4/fBatc1NjrLZbr0L+uryu/HHtIlpkK9rVB/V
anMDa2Ia7Y6cK73+Sk9b6z5zittUcEO7u3z4hzJ6PcBdsvnPee2+O2SrK9pd
aL7vdOfncth/uLT0eqLeSikzvKPQfVKl9jlNfpruec6+lv6hGnq68XMdR0TX
iuU5+kEvZV6otrP5k39L/1KZFUYMSK7rvvvuS/y6opgzZ07+3DqOz/une75U
4rmN9LDGsW77NZtZuXF7BRt9k2q1uYFcoTTavWvXrsjzzh+9W7aWa+9hbuq8
Za5+5Vw37rDdsz87YJKnx2Kff230ODdh7Fg3NneMPvl892Sr1IgNdmMnTvZs
xIkTTnZDB2Z1+wNfL22GdG+n1BneYeg+qWhgmvw0Hbvm90LNlIDPUc/WQl/1
fgF/dpz8NOLHPI/M85C6L5mrLbatv484Gi7PXWr+uh/pEYfPQkPfVbG5uTZi
E2lj+Ub5IK6nZ9lr+6vY/Hej71PNNjewxqxbty6Rbm/dujXGmXe62yd8tUtf
lQO+e23eBy7a3fXYy+vXcu/oz3S9rf9A9/Uzbw7IX6suSp3hHQbaqtexpD5s
yaWW/ibkSwj05MMG1reTf45PWds92KbUrQXBfenZIv3ARbMlD018/Pfff3+g
T3rhwoX55+d6ygV7djkvvWgE3j+5TuldPm/evLI9r5Ec+kyR6+DXbOI6Tz/9
dE9fntFNaJsbjatGktSJsYYlyudope9pvbcHamzuqNyLqDLKMcM7CHzduo4r
qk+qBk3Vdc3Yltp28dd/oeE6n1Hmc+gaHPqYa/A9i21Lbpv0FZU8Nx6PNkfZ
tPgrJP5eztkQ5MUH7QnEx6D7n4bNSDMqCzkb2l+l8yT9/hmjusHnVs02tyaO
75xeNG+//XZPX2pNUI4Z3n6kf5rUjovfvJjGoZW6fwvfBaknw/aVeZc6jytI
X9nz6b0wayr9zfQsbdFsnYfGngA/xDvvvFP0NdJnOsivXQrSL43zkkMoUCfJ
HkGumdvxSxjdC59f6rr89V7sUYP6CBrVj+5BX602t4Zcy6DcNV57Y2OjxfC6
kXLN8NYww1L0lTorOX/U+obeih5KjFni1eiu5H5Lzhq+7CiwjXSur9irui5b
8r2kf2kSO1bs9lL6zPjB7yGvUWrgQPYs4htAx8vVA8aIB3X+fF789V706LX1
qjbRNjf+wVqio6PDW5fxaZIz5J8DSozPeg5VlnLN8Bb8/dOwwbX9GwR2rp7N
id5LTx7qw/WcMP4eN3aOvvltJLGT0HHpX5o0vx77S2rNy/GeCbI/YS8hc1Ql
BiD9T7mdnppG90C9o86BlIPfQbFZt0Z1U2s2N7HLYjM+WRuZ2Sx1P0nrfYz4
lGuGN/j7p8nvLaxPKrB3o2ep7l8q9i/1TzIfm4M+LHFsY/SOfjD4n9kv+Ndd
fPnEj9PmmOEPkGsirl8O2D/IfoBrE7D3pA+M+PZtVkXlIb6i8ybkYI9ZzlpK
o29SazY39jVrMTMY/XW6fvS8KNbacuYDGZ2Uc4Z3WP80as/kOfS8MmZ76Hkh
xKKxZfCf63w1DvzGcXqQ4HfGNpf+pdJv3J8HXIqfU/sWSpmpoiFnXM7J+QXe
H14Lr4E/y+mjN7rCflPHeeQgRpK2l69RfdSazU2eh6xP+KKKoecc0pPIqAzy
Hpcyw1vP9wzqn+bvk0ovFIkZi02NZtNHz1//VWyfB+gdNrvuhabz0LhN571z
jWn3g2ILc5C3UQ7EX8F1yR7lqaeeytvcEpsvdy25kYUYDfkWfs3mM11tvTaM
0qCWtpZsbtYj1iWJWcaxoV577bUCm8n6NleGcszwJv4neubvWQr+Pqk6hs2+
DDsYjfbXfxXzaz///POer9+v2aJ1+BLEjsXXrfU7bT9RcvrkGstRD4F/VvsX
BPxTvC6xubEHjfKCnwcfj1+zyWm09cYIQtvcuu9htcJ6LusT8xTiwuwonStc
jrnIRiGlzvCOO98zqE8qsV1021//RX/SqPp+PgczZszw/N9asyUPDV+z9C/V
4BPV+WvoYVL9ljo24qHlQGrFOSRHgD/5N69NerHoeWJGaeBzmT17dpd4Cu83
PQ8MIwhtc5fr+9/bkbpa4t3kJyVB99yulferOyllhneS+Z7ML9b7MLSX3DP8
5br+K6pHN754arDZ+0ovNOmHhmZjSxPzjtJjcuu1fieN80tuHX+Wiq7p1tdB
LxuxubEBS/HxG4Wgzf7577zPaLm9x0YUtWZz67kN06dPT/x4vk/aZkMDjPJR
ygxv3Rs0ar4nn3P9ueegttxf/0UsPAg9S9uv2eSSS//SuGsv+XPa5mL/EBfR
2nLUaml/lNSs44eXvYnUhfE+G6WBD499kN8/js88zXw7o7aoRZtb93lM25sf
e05/3+i9ZpSHtDO8i+WnCfSplVovbe9ITFp87WH+GHqV4wPXvdBklrb0L00z
D/nZZ58t0O84NXL4CYJi02mRfjS8P/Q4ANkPyWtkr2C1xOkhD9i/b+Tgvff3
yzWMMGrN5mY9knVb93lMAzXfet239aw8pJ3hXSw/DaihkrplDmoN/LXW5H4F
PS853JdffnmBZkvuON8jZnWU+hlgXdfXo2urg5CZIP7eZ2mgRk7eG7HhZUY3
r5nXWsyfYYRDbIQYil+zyXEo5/wYo/qpRZtb+1TxWZWKnrVnebflIc0Mb/zd
xfLTHnroobw28Sc1zOSO61gz/VP9UD+Ghur+pTp3nNr/pDkTUVCLpdd24vBh
aB93qXtvXQ8vtV98R7TNzb7XeoEkg9lxej+q19ywmIxhRFFrNjf5QtgQ/rrV
UsAvq/sKl2t+Ri2TdIY3tqH0VAnLTyMfSHSJ+5CjIHFinbug+6Tio8EGxxbX
fVX4Oz8j9lIpHdM1bBzsD4LQPVTYY5SCvIfE8MXvQE4nexapCyMWa8SDzw/+
C79m89kh7mIYadB7+1qxuanRkXWunLOGiXXr76b1OyqNpDO8qfGT3yszPPxo
exK7kfptXf+FTU2OtjwncxOJh3BfrdkyS/u6667rFh+nrkfk0POzBXIt5XWV
shfVvnfxiW/atKlLLxbq141oyNVnb+iv98JvYfMQjFLRNjf+xlpAz1Yod102
9pmuFbbajvQkmeFdLD9N9y3B3pb6Mfm31M7qPqliW/tzx8kdS5vbmBZev17/
/f3Kib/zWnhdpcAMT3lfRJ/Zo+j+p6X2l6922Dsxm84/b4Z/k1dRDj+fUdvU
os0tvSXEzqoEelaArXPpSTLDOyo/jZpkbV+LxovO0z9MwHfiX3MlDw2/sb5v
d0Mtmr4u/Z5ITRs9z9Iis8F0jbjMImEPI71YaiGulhb2WEFzZoj/pKk5MIwg
dF/uWrG5tV1RqXWY+g69/vtnVBnxiDvDW+enYX8K+Dz07BBsRumbJveVWpzt
27e7q6++usssZA7y2Njn9gbQa31t6DmaK7l3fL7TQu69vDf33nuv9zPqzaQX
C5pUjr4v1QifD34H/s8On6ly5i8aRi3a3MxjFpuLvPBKQs9hbbfRA91IRpwZ
3vgfdX4ajwF0W3qEoj3YzVq3ieVyH9ZVbCLdV8Ufn6TfeG8Cf7m+Pp2nRnw+
LfiIJJZEvTh2ImsD+xnpxVKOmoxqghgLvhu/ZrO+NDU19fTlGVVILdrcrGuy
xhWLn5YD4oTyHvN+G8mIM8Nb1/pJDjaaI71F0Gu0R3Sb3wP7KmxVNFByp3Xu
OHpFjZg8dyl+6EpBvpo//4nXF2cOXhC812K7s+cB+qmJzc35qc2w/I0s7Od0
Xagc6HicmgjDSAMzGmrN5gbJT+I1lzInOS6sc9KTm4O4qxEfbGp574J6e/vz
0/CrcEjelvROEd3GPiffgX0b/9aaLXYlvmJ+bzy37rXWG/vt6FnyUtcmfoek
6Bx9mW1KnwLxR/A5Fj96LYOfhvoEv2az79Hzzfsi5HcSO6LWnN5AGzZs8HIy
8Rlafl3vQNvcTz/9dE9fTrdAj4ly9oyMC1qhv+OW55MMed+CZnjj19D5aayr
2EL8W/y8otvcF5uUfZvuqyL3wQb35xLhV+/t+y76tejPV5yZ4kHIbHJqulmn
qcmT/Q3vJe9bLeda8dp1vwG9X+oOH14lef/9971aR9amsIPcoLj719bGTd5s
8c6j3jVsbgy4z7aQM7S7xs0Nheeob3CNzR1d7tm8eZ3vuRq856rGDINatbkl
lsf+uLv7QWGvyHuOLdcbbbjeiuisP+bAeiK6Ta8qav2wE7EPeYxoMr9var25
TWu2+IHJgZN+3X6wQyT2zWN7q7+Y90DrCTZTEujx6o87EHOQ/qe8j9Ta1yL8
zqnr8tce8D2mDqyv26Po9osvvhip23LwuSq+djW5MXvWubq6rseHDj7DrWvP
3ac/PzvBBXbAaLvD7RXweI5/Pn22a1fPNap/8P3q6ga4U2d2bx1npalFm/uV
V17Jx/KCel12B9QXyfuO79aIB7Y064uG9RIfuuzF2I/SH1pi16Lb7E15r3WN
ttiR5L4R4y2G7ofFWt0b4TVqbeE1Ms8kLvQP0TN56Ckk/U9578hdi/NeVRv0
T/HXHfDe8n51R8ytO8AfHke3tf393nvvRZyxyY3bO6OdHxvhFtWv9+b91K9c
6s4/5nOepu5/7mOd9/noKS4wmy+j3QMz993jnye5lfUrvfqHVYuvdiMGZnX5
705akH8u9gn9cvej1zH3XXLTuW6wp9+D3T1VYoDXqs2NLSFrEz6VngAbDjuv
t+tAXwFNnzNnjlcDRm2zxGVFt/39SyUPjVhlkp6h+Gi0f7Q3IjN1dG4Frxd7
uhjsg/CT83j85oBvWGxu9kO9NV5QKehTqt9LOdjHVZPPjN89Me0k2s1BX/Zw
wnT5fk9Pd//W7Ij75Mhp9ydOus93w0Y3ak+tyVnt3u24rmvp8rH9Mvcb6G4t
rT1wr6EWbW7iVNKvWtamngJbSK8F1lcyGtYW/Nn4w7EP2trauuz52ddjG4k2
c/h94/wbO53cgzTw2N5aq8/eQs9C0/4dXnex3LXVq1cX1JfJjG6JO+DXqJXZ
Vnw/dV8lOYjJVOPcFb5bSXWbI3pPmNPlD470/OPtre2ZfXazmz/xHz2b+fCr
t7q42h2kyc9NO8w7z7FztzvR7v5dNH6nu2honafdc6pAu4lpyKyFWrK5qXOR
tak39BAmT07WBGyaavG9lRM0m9pYfCRBMTdiIFrD0VO/Xsvxk//6T6/fqc5l
qa9v8OWytLvGhifd5sY235W0uzWLZ7pzMuce+tWvuSOOPM5NyOhab4LXo+se
ee/Yo2r9jtqz0DtEYg/0qaHnu/Q/xZch9WLVDO8P+RB+zSYOkzZvvy/AfiSN
dkfnU+R0OTAGPdg92K7uk0K7W5aMKtRuztN/sBs6dGj+GJSLt39hfPXURVA/
w966Vuq5QfJnsb17S56s7uVATpDRCblB1McWWz+oY+no6Mw7xa+rNRvbkc/5
jvlHh64jVz+Zy1FryeXGeP68HC0PuJEDgx63p7tgYc/EXYIgxufvE4h+6/nQ
+CKC+svQf0X87Wg47z3xB4k18PNyzaZM6/OoJOxV+P75NZvPTk/F1roT9sdp
tJvDn4OizprV5Q8Pc1PnzfNqNWbNusmdf/xB2e/PQRdndsTptfutJWMCtHug
GzRkiBs0aJAbkjkGDsh+V3c/6lrXO1b8+PDdJb6KT4Q/+3ouZFp0LnLY7MSe
gLwfnVvEvCojm/NKrlTc9YOZV2J/41OXftu691d2nz7AXbh4TTZvpn6lmz/l
WDegTq0dubXik/m14hk3Mpe/euiZs91Lre3uV/ff44786uddPx7X7+/dpm5/
d4KhR4t8xnU+GTqs94jEFfx+X92riNl61NmJzc398RWXA9agSuZnEoPGr8+e
j88EnyH2Krt27Qq9HvIk/JqNH4xcp1qBWFQa3SZGHk6nLvvTxGYcJn7sltTa
vXzCvt73+apN2ecK9pm/mI2Lh52/F4L/lf2t39fIv/l5Kv9se5NryKx5mwJq
64Jr9Ha6zYH+R+9k3m31oXV95UV6YuIPfPXVV7vlOeOi5zKzVkbnf9QGr7/+
euJ1RPedDJoTmtXuvdydvoXkcuJhe+RqVHxrhcTUvuzlxHaCrh39D3/j3Tbu
rt5Rf8I8HZmv4kdmi+jea9K/HehNrnsVEdeX3AFea9pacT/yPSw37E/waUd9
PtB0sRH5c/ny5V163rLnkzlyHqFrXja2si5wbcs9zldrXN+w2adhwesjdcrc
tz3gvqHPVyL4IdNod/Rs45x2f/qMLnGpyz3t/pJ7sLU5e5/d/ffJEZartu0O
N8TzfQ1zT0itWUiu2r2j+2fud4h7tA8Y3uTxMAMp6j3ns8T9krB6Yja3n/e5
cA8TUqPXkc0nrOvXtXavY9W47LmOuDnVa0yCzD9izeits7xuuOGGAj9drcOc
6DQ2QLj/rlO7b9zcRuJMZr1qdVuWXZL9jB4wKbt2+LR79jF1gd97qdM//fTT
e02fVKmVC8vDZH3GL65tS3L0yZMUm/sXv/iF5xuX/qdoWbnsZN1rvZyg21xz
nM8Ir1U+I+wPpe6L10p9v79uP3TNC4qtKKLiM+cu2p47xy1Zn8+h16pHbnQj
c/c958lO+6plSfZ8fzu+cA9ZTpL4ueQI64eQReLde7mTJ17krWsTJ090I4fs
kfOZX+H5zD1fd+Z9OTmznxw7dmzuGO1OP2+2a819H/t/fqT3WM4xYfTX8zXf
J87dnn+uaO0e2GXP3tsgjk3+QJz3PV59vZDzPdRlfxdXFTgKw2MWtx//Ec+v
8eN1hXb+guN39871oxVRv/vyQE6YrBm9ZQaUH9YM3VeDHlm1Cu9F2tibzOom
R5pe5dT48Dvns77yum+GrKd1bvis7dl1u0C7c70lPqM+122PuNHDh7ujjz7a
7bffYLfv3w5yw0adVmQN6x5kZie1b2Hw/ujPGTa1notK3jB957TNTRy9VPCD
yP6ZOrRyUsze9h863k8PPXzm/hnvWSLWvC6xlUIkj+rQ8xa4+pUrvZrj+VP+
Pa852XXvxezn64MjO+MuW67M32d/5etZMvZTgetoOeE9iKsdHOQ8R5PRhUHB
vVIOPvna3HeqyZ0VeJ+snjS33Z2rzy48+u99iLtw7oaC5wqtEfN86119Z70J
9pPEeJJ8jtmvRtkqQseas7zX/5Vjhnt7xX1O073/wrW7Y9XZ3uP2OU3n+T3j
RvT3fWYrhJ5DTA/z3gw509p/19d7IqeFNSStdsuMRXxK/hjmKUcOynwW+7kD
vnaEG37EEe6IzPG1ofu7PfqxHuzuDj/pB+77p37d7Z75vH748yMyjxnjvsDn
tP/fu+/l6qTGn/Ftt0//fq5//91d/37ZdWS/4Sd7t2HTYhfweSO+TO9WPnPk
LdOflZqtK664wsuJIh8M/zF+7unTp3t11Ni89H1jr0mNF3nezPnExqcuYtmy
ZV4c2r8noZ4JnwN2NFrL+fCH8x7wXvptSfbrUmciNid2Nva1+Kikng6dLbX+
gRiVfAc5dzlzv9ijJf2M8J69++673uPlzyAi17yIOCyIdp+4qDCvoGPNpKyt
7eVpZfYOo3fz9gU35NqEbphycKdG7Xt2zo+8M6dvw1yluyiTsxhHv7HRo/uy
GElg3Uqz3vH7KkbWd/gl92hHY9e9YmSu4MZsrk+/E/L3F3/5F8YvL9dLD4X1
TmyKgjhWL4UZzDr21hvsue4mbexN+/D03LFC7e7vvnFqYYzzlCP28T6Pnz/8
ZJ92f9/9f/t+KHPbHu6bp36/y/m4b/+cdne5rQ8eotf6Z9jf7EmozdB7EnQ+
bE9Cv0LZk2DTsk/gsyw5b+xJygXzMtJ8TsjNKkbkmhdTu4/N+3SF9ly98QhP
h3fMPyF7v5nZunkv92LfM9z8iw7p7DvScb8X2+1X4FuvHOz3wuo72HeRVxLH
3jPik/ZzXLRmo+ORbF5ALja9duIXvc/bD/L+7ug8f/FZXJCL32T95X6/e2WQ
HBzsIeIJfQFmX+m60lqDWogkvjt9SK0YsUz61RFjpf82scxrxh/i2denX3+T
l19Abyz8y+cft7/3+Txw1ER3yQXfdR9Fu7/4Xe+9P+1fsrq+15eP8zQMuxEb
FT066ou75+1uXUMdNPfbjsKjXODjT/M5Ya2MpNial1q7xf+9V7bPV+48A44j
F+tx7zn3PPUx57ZdlLPb33YuZ/8fPvV3JbxTyUHD8cPgN0Gv2Q+brV0Ztm7d
mupzzOOi2Hb7Md5n59NHT/Jq9KaN/XK2Zi6fp1GkRm/LlZ6faE/P57TRjSjw
B1UOalzF5r7lllsq/GzlA7tT90wlJldrJI1hcpDfJgTVMMt6+o2x57vJ5M1M
nOzOklrTjH3l2Thd1uTOGrH9Mp//pfRlfmiuG3fYp/O+TdHuOH1S2Zfgs2Yd
pJ6AOAm5uvggiV9h19DnkBo2arXoNUOflaVLl3q+c3zosiehJozvIz21pVc7
x89+9jNvT0IOHfYwti72MTls3A8/PvYz+9moPYbkqklftXLuR8pF3Bw1/xGd
Hx1jzStBu7O2i+Q/5tbOT53ttqzJxhf/Yyn7g2e8dZKapzXTDla1UEY1Uhnt
3unOHxLWG8f3+QutocvlI2Rur1/1427bQ0rNDEdv7AcRBXkLeq1jba8l8JEk
/RxLrBuoJ0Crfv3rX+fjvbKe+o+PHzjK3dOYqwHKrMmDvZoU5ddte8SNGfqR
Lvk2J11zu5cju/8J5+Z/Tz3VJ5XcRoknx51xxl6Ax+BD8PvK8S0k6fVOTJx4
BXF29iTsNzgvMXiuiTg9+RvE6dmTlIs4vXuCjujerjHWvNTa3bXeePnYT3p7
x9HH/F3WR5+raZgxPHO/jw9zo4b265bcIKPnqIjPfNt1Xt7jbt/JzluTfmSr
Jg9Vn82m6Bq9DOunDfPuv2dB//jKQTxL+kRhh/RFmK8hayk2Xa31TEU70vhA
yd2SPRsHNia9R0qdHUEPA6+ni69OF/2Q31NP1ffxGee1Bs02D0PmmxPLJhdE
azeft7R9nPi96dy0SuZc4s9Ns+ZFzkKLs+aFzsjI0pmr9nbBz9dPG+H9/FOZ
cwtty87I7w36HXpFvq5bbH/v/iG1aEZ1UIlcNalv1LWGHi23eJ/dWDV63D9n
z9R1U84FebqydtP7pK/CWizrKf7PWgMbrtjnF7+z5M7QP4tYCX5kmTsjB//G
/1mJWRK6b1mSmZvlgtg8rzHuZ4T9urwv1IiRZ+b3iZODlhT2l5JjwnH33Xcn
PkcS+H0nXe/ofREVt4215uXrjke4sXrNGz3anTtzQ1679ztmnJvs1SVPcKMO
28/nr8yRy0Xjtq9e+ruuz5c5jpxZGzNgapU0NWLcv2g/2j1OCPDXiF8JG7o5
skYv6xtqd9MO+1Bg3US5wV5gLRU7pC/3gWU/pv2Z5M3XGtg9aI2eUcj6S8xS
5x+yHpODxvtF7Bs7m1wB+SzIgS1I/nM54xD4guV31N0z2fGRS+103L4A5O7J
+4GfX/qf+vU7qc+K3HI5L7mA3UFSf2N0jnm8NW/R9jmBdcd1OT96WHzm818b
45Z2CbXLeQP6ZnjravXMrzTCqVxvlr4DsTVZPxYuXNjTl1My+Gl1/pDu/Vlr
oM9B8Vz2n9ja+n3iMw7cn1wvapq0hnOQz1WueTy6ZjooV65S4DeW1xOn/krv
bclbQ+9l5gi+cvLhtIZT9xUHiZ9zsH8J7ndSfng9cXN9amWGqdE3IWekEj1R
+wr4+lg/iHdXS330TTfdlF9LeV192ZdQKXhP8Ndqu9EfL6EvNzV4fg0nr409
Xynvq/RJ5ejOPqnEk+V1xJmfsWbNmvz9qZ/j8yS13bx/wL5ev4/kfUbBeiO2
P7GJ7tZI9m7sYcLsFq4vTk23YfQ0xJ3wJZV1FkkfAD+orEvoXbWAprA2ylqK
z9cIBj+v1h1ynv3wOcGnK3ojB3MvsTvT9ALgd4T9Ks/bXfvG++67r6CnaTF4
3RI7oI+b9D+lLpH9i0AfU/0+hvnj0UT6r8k5iR/0FPRJY44caxw9O1kDyX23
umSjr8F6Qj4HvQNrYQaojrdVW10VfljtywyalWVkwU7UuhPWU4+caGr/yQ/3
57URE06a18Zj5DnJAesOyL+T6y62XyBGpusv8J1LnJt9iz8eoWfccfjn53J/
8XNxUHduGIaRBPK6ZF0q17zh3gZzIWQdxcdZrXGPcqDj3xxRuoLmUZsQlNfG
fpD5U3Fgfyz7K34/cWutS0HmalKXVYz7778//9qwo7G1ZUY3dXRBMANdv4/0
hBGkrpwjblzcMAxDQ55OkrhfX0X7hGuxZ2oSdI08B3oeBbEk5n6Qa+WPidPv
RfLfosAnLc9Xzt7dYRCr5/qo1y6G2Mj4FYhti82N3yEqt4y4g34fyd9nHynv
DTlv1Zj3ahhGZSEWgM9PenFUc2wAfSEfWNZR8o2McPx9R+LmCuAvxn+TNK8N
P7vucVJppI6d2Z1RkD8mr4F6bq5N+p4yu6wYek4OBza7zAoo1mPUMAwjiNWr
V+fXJXyf1Y7u5cURJ0eplvHbjUnywHlvmY0VlNe2ePHiQHv10ksv7ZY+qcSJ
5HqK6a+eY8/1SY9y+p/GzcEmj0+/j/jamUlqGIaRBvpJSV0YeaW1AHsUbd9J
70YjGPpoa93Bx5zEP0OuIPlnQXlt6KLWP/Iku6NPKrM45DrwYUeh/VL0GZe6
sLj9XID3i9dTLI/fMAyjGPjrZP0qVodabRBnlDW0WvPzygl9WHSuPn33ktZL
UrNB3pvURcnBvlHntek+qfRprQTMWpHnj4rF6xpwYvlic6PhSeb0kC/AOXQt
HAf5bIZhGEnAFpJ1CTukliDPXK+j9A8zoqEPsNZv8rPT9ABD84kBh+W1ab9I
pfqksoeQ54yqZ9Mz9TjE5k6SG673Cex5br755sg+OIZhGGGQ2yo+TGJ4tchT
Tz1V0AuU/lJGNPhq9J4nTm10FPjjdZ2zHLoXfSX6pJJ3JzZ/GOxL5DvCPkX6
n5JrRr+xOBADkPpL/pTeCfjbtX5bzwHDMOJATaqsk7Ucd9NrKDlV1ZxnXy7Q
UnKt5H3Df1xqrgQzUKi3lrw29FHOj4+93D2+JQ+e2EkY+GL8NjdH3L0uexrs
bHk89rfG3weHvqSGYRhRsGaxnrAuVmuf1zig1dhDcftPG1nIL0Ozdd1TOWa9
6Lw2rWv8m7y2119/vQxX7/K9ZPDRhyH6zqwU6X/Kn9RmFIPPFfVkotv0UA1i
6tSpBb6fnpiDahhG30DPVIhTn1rt0N9Tx3F7sq90X4KcAT5D8r7hUy5XvTI2
K7FufW7xO9Nvv5TnYa8qn/9f/OIXgffRM8aoBRObG82Pg+63ygyXqD5xumcQ
z0Edo2EYhh9sDelbmbTvdLWi65iJte7cubOnL6lPgC+bWi/93uH/Lte59Z4K
DdU+bPLF4sadNbq+grrrIOjbIza3xLn5kxy7YtCbUNeyv/nmm0Ufo+vaeQ9f
eOGFxK/LMIzq5ZVXXsnHFOlBaXRC3xFZP1lzjXhgxxLX1bZjnB6ocdB9UomH
B+W10aMUvYzbA515pvJY/h6ExKmlhxoHNn+x+BL7Aslv4/5x9zH42Ok7p/U7
SQ2aYRjVDfOMZN1irqnRCeuyjuHOnj27py+pz4BuFpsBngbmUvr7pFLPqPPa
dP0Vs8CL5bXpPM0g3zv7DvGVSz03fxab9UXthuSRxOn54gf9ps++jhNUIsfe
MIy+Bf3DpIcze3yjK1u3bi3Qn1qrey8V8rPK3TssrE8qPiRqpaUGSw7quZjZ
FdavlBi33DfIjpb6MfLvdC+WYrVw+PDlvMxHTQN7IN2bhtw4i2sZRm1z3333
5deWOHG7WoUZVjp/utz1SdUOsz20fmMLl0KxPqn0Jic+HdSvDW33+54l3yMo
74z9rfi8Rbc5wnLaBImPc+DXL2WGKfsJ9h/6M1gr/YoNw+jKxRdfnO8jbT28
o9E5zrXau6YU0Dqt38X8zcWI0ycVzWPOtvZb67w2iRHJ7UG9cJctW9bF5ubv
Ub5rHT9n/1COOja+n7p2EbufPYphGLWFxPCiak2NTvCP6v5haIKRDP8McHIt
0kLdXpI+qczoYs/l13DmqKCD/D1opqnM5tE2NzXYYTAfVOJQaG05+6/j79E1
eOS8G4ZRW5DbI3Vh1vszHk8//XSB9rBOG8nwzwC/4YYbUp8L7ZLzxP0Mo6XY
3JLXxjlEk6m71v4n6vy5j8wKk7qwsDmxaKv4sjiISZUb9pD6dRuGUTuQ6yJr
V5IZCobzco507+5S4pi1SikzwDXEzdOeg30XsW+t3fjCiSsTqyaeLPNJtM0d
ldPJbHLRbeagVQp85eTYm3YbRm1x++2359cYZhoaydD9Oa0mPh2lzgAH7q/j
GGlmoCxevDjf3xQ91Hlt/Ntvc4fNCJk/f35BfXml+wqzt2CvYRhGbSA5q8Xm
LhjhtLS0FPT3QoeM5BCD0O8jtcxJNY99qDyevudJoQew1G5TT8A16B4s0luG
g+9NEOx/xY9Fblp31XDxOTQMozagP4TYB8QejXQwA0r3vIrT59LoCvXypcwA
131S+T0kjWFQv8Z3QWrNsOXpySa+dO0b4NrYp2n/APnmshdGv8vVP84wDEOD
P0/WqnfeeaenL6dPQ66ArOtxZ1IYXSl1Brjuk4rtnATJPddxbOlZpK8JHZc9
L7Y5eWjMXuFxxXqhG4ZhlAI5tqX2eTI68fdMtVq79JQyAzyoT2pcxGam7kJ4
+OGHC+Zzc6DX/n5tXC8HNrrNijUMo1KIfzCsb7ORHOY7ab9qOet5a41SZoDr
PqmPPPJIrMfgdwrqccAMTsnjlvxz7ktchN6q6L3kt0lvc+aQbt++PdXrNgzD
CIN1UewG1iajfNx9990F/aatZ2p60s4AL9YnNewx/lpsqZ/UNveMGTMKHkeu
OXout2N3S7wb+932b4ZhlAt6WhWbc2ikR89rpN7JSE/aGeBx+qRq9Fztp556
yvsZ8XKx/aUuTM8wQdulTzpaPWvWLO/37e/XRg/z1atXJ657MwzDEFg/WNdk
LqKtJ+WHeY86Xms5/KWRZgZ40j6pCxcuzGstM8iAukndi4U5aPqatE5T0y3Q
G11mmuiDODn9cytd720YRvVB/E/WEtYrozKsW7euIPbtn1dlJCNoBjj6HEWS
Pqn0VRP7mf0stjp13rJXQMO1v55eafI90rltGn7n3C9oDuncuXPLMj+EHD7q
2rlWwzCqF/x30isqTe8pIz633nprwawI65laOuRnaP0mDzyMJH1SZc4I9j0Q
15a6MMktF/S8XGz6YjkN6Ct9XySPXfdro8YjaS98nm/RokUFs0CtJ6phVC86
H8efc2NUBr2+htlnRjLizgBP0icVzZbcTXzaxNh1nxfx0WOPix3NfZL4U6gV
p++q9GuTI05eG6/l0Ucf9eab6Ndu2m0Y1Y/286HjvQ3ixKyF9NciZsha9vzz
z3szj99///2evrxUUG+se3Ixf9IoHf8McB1v1sTpk4ouSh9T9rTElcgdF5sb
rQby1CRXhOPxxx9Pde08H88RNIeUueH6vMReiLP7+7rpPHpy6qyewTCqE2Jr
Yi8w37A3wVrW2Njo2TZhx8aNG92uXbsSn7sxswdo2NzY5eftzS95+4Og4yXC
kO1NrqE+93cfrY3r3LrGttjXsGLFioI8K52rbKQnzgzwOH1SyU3TOSD413Vd
2LJly7zHSbyJg/li5YDPtj+vjfgKNeVcb5BeczvxGPaFhmFUN+zNZW2gHqa3
gD29devWSN2WY/369QUzlYuy5Uo3oK7O1dUNcFf55HvB8fw8+Pi/M192O+Yf
7f39yJn+WGSTG8X9vvXLRK8Tn6juhW2UB+K+WtduvPHGLvcp1ieVmjD5bjzw
wAMFdWFoKHtLbHa5D1pbbtgzYtOH2dfoOK+D/j+GYdQGrD0Sz2N96E11YfTK
iqPb2v6O6z9fPmHfvB7vf27hfK97R/fP/Hwvd+ZN893iefO8+czeMWuee7Kx
w7UsGeU97ti5/v5YTW7MnnVut+PuSvQ6sdt03jN2k1EesIu1zvnz0or1SaVu
S/cH1jPD6J3G+XWdV7lyPPEJ0Pfcn3Pm12yuWfLapH7NMIzqh3lHsvagT70F
9Ax7I4l2c8Trbf2MG9E/o9sHjnDDBmb+3OMEpztyZbV7oLszpExHtPvEuX6/
ZDrtBmqM9LrMazfKQ7EZ4FF9UumBKt8P3dOFGv0NGzbkY03Elku1e/nM8/xR
OWfUlWP/06NP9tw6rw37m5wQwzCqG6l/YQ3qTfMp0eCkus0RZ/1sWzYmbzev
nbiP9/dznuzsiSHafVvGxnbt7Z4vXg4Q7f7yhatda3OjF4/naG55wo3qn067
Qft40Qby84zyEDQDXOLbxGXC+qQSzxBdlBgz52E2nNbOUmJNfG7JYQ/ziZOz
ftddd3XJOROtl5l/+iBvxfoiGkZ1gq0n3/Ubbrihpy+nAPplpNHuZ599tui5
ZwzHV36I81a2bT9ze9UV6u29oz8THO/ul7XPRbvDjk+m1G7AJpQ1W8+bNEon
aga4tqmpXxD4TKGP2N967ojOTaPfaVL47vGd0z32/Dln5NfFzTnjOokH+DVc
7HTDMKoH6RfFQay4N8GspTTaTc5aJG0L3ZC6rHZfk1lzZ80Y72l3Xd0wJ1ZK
1u4e4I4ee76bnLHDJnrHBHfeZfMdbnTR7oNOv9bNmzfLW7s55s2b6oYNSG93
A1qi13Ob9Vxe8MvoHG2ZAU4fNnLTd+7cGfrYd9991+s9jh7K9wZ7OW6OCDUE
fE6kJ5v/4PdOfXopvnf2BOTk+fu1GYZRHeCPRZP4XhPv620kzVPT+WpRPDft
sFB7+cRFO7z7iM/87pC09Xy8e9Hbvlt2unEfL027gTiqXtNtDmt58c8AR4vR
ZT/kPQbpMvWI5IbhMy/Wu7RYzhk2PHGr3/zmN2V7fUDfA/YJ+NtNuw2jemA9
kT35r371q56+nC68/fbbqbQ7uodkkztrUNbGftSr0yaG7VzHlus927vfodd6
9xLtntMcfJZy55kHwbqr/afWM7W8yAxwNFXneaDhaDt7QPlMsZcin0HnH6Dp
YTPD+V39eukCN27cODdq1Kj8cdxxo9yp3++cgcL3Tn6vW1bO6fTxTJ7mVpBr
oaGngK/XQH3DZlewc2h9Kdt3QO05pUeqYRjVgfReZE5hb5xdhM2j18+4R2QP
qVxN9ydO8tfx7sxp+mB3T2vv0G7gdyP6XYm64VqHGeB6r4e/vFhtA7GcsDpE
nXN2yvB9Q/w7n3GXr2hRj3rRXXTYJwPve+iZnZ9T6SnQ9Rjszl2U/Rzm8zAO
mOQKXUYJ+h4YhtFrWbNmTd7mpka1t0IcMolus65Gka3pHuAuWdd1r7J+2rC8
Hmdz1Ypr94kV1m5y7XVslp7VRmXA9o77OSOGIfpN7cH111/fJefslCMHZT4j
/dw/jfw3z7e+dOliN3/Ksdl+QB89xWUt9nZ3+WFZDf7YwWe4pZtbvPNtWXWD
G7pn9udfvWytd0/5zB163gJXv3KlW1m/MnO+f8/latS5H63I1pXPGN6vy75y
x/wTuvndNAyjEkg+KnUvO3bs6OnLiQTfZtzasN7UV6Zc0ONcx0Z7+++rL4Lf
KWkvAd27Vvdmk5yzKacfnNHQj3XpEXD5UNVPYP3FeTu5S9S843431NPlL7kH
W3WOReHvv2PNpOx+4KCLs9Z12wO5XMwRudzLbC8DwzD6NvgIZbYCa05fAPs7
zH/OmtvS0tJn55HEQWsDuUdGeaEfWdLYDLNw5DNH7xfJOaOOHLJau5e7cXNb
xrxuzdjTrW7LskvcYKXV0tvvgieDY1ZLxn7K8//c2hwVp2l3Fw3NavUzuZ9s
mTE81y9wuVs28UDv74Zh9G3otyn+8qL1VL0I1klyhZqbm721ljwh4pPvvfde
T19axSGfSdcVhc28MtJBT4A0eZGSu0aOhT+XMKoHwJG5fnzF+ve9taSzh1C4
dovG7+VpfJad7vwh6jkPsB75htGXYY35f+2dCXhV1bn+U/wbbCpPwWo1tdWC
1YL0UsOttNB7HaDeVrjFXrDXB4FbFRVCghRDCiHMYTTMEkSmyJQoiUQKBJAI
opyAAwGUJEwJaE0CDkkcSlJq/f7nXfvsnX3mISfZycn7e7qeknP23lme7LPe
/X3rG/ScEdb9aF2g/6nZLwvtII0Hz36h6DYG8rAAniu/+uorp+tqWtteHluw
TjY78v8XpA6Rzu2jHDX7RLKGXuVTu3X7GXa5L+3OHhSj6hUUmEPSzi2W2Cjt
dy11b5VHCGlFvPLKK049kUjrIi8vz9Du+Ph41kwNA8gJC1W7zTXPsA+FeijI
30DNtel/6mHXzRiJX5MtO3fuVPGhJ0+elNJlv9Y0eM0H8rrDn/2nHZ77l2hx
bJq2e9fuszK4ozn+TadaHr/B/nrME+I5k40Q0lpATil0GzmtQfXLJC0G6MKT
phxh0jhgMx85ciQk7dbrssCf5VqL9Mn/vtWutdEyINH59T/d+yOlwbf+Pl6m
j+4nV6i48ztlzgsvqGdr7J1jL/1k7ggtBs2xN+6tHtDRhf3U69f+IdPlv6xC
0243TSeEtCaw1ujrB2ozk9YJdCIhIcHQb/SoII0D9ctD0W59jxux//CJoxYp
8ruxHzX6gZ8qTf3Rz3pKr549pWfPXvLzn1zn2IO+RgaM0r6L//Xj9tpr0bHS
+74H5KGhD8nvenfRNN2u/b/+v6dVX7GUh7trtfL/7T9l8ODfyx//OFD69rjB
cb07nP3ligoZ5tBuVuUjpPVi7oeEulGk9YLYKvPet7l3Bgke2M/B6jbqrPnC
W6zat2PvlMdnLpP09HTVd2bixPHS/44b3Y+1a/lvho5xsePdr9fhhq4y8DHN
X488cvhl8F1fuXKe/Nd19mOu+738tbCwmT5JQkg4QWy2nheGNYO0fjIzMw3t
Rm3PllgbrzWB+gCB6jZqpIb7864uL5ItG7fI6tXLZd7i1bI+O1vlhCA/EP08
UXNd7z8QyiCEtD7WrVtnfIfD3fOAWIe5byXq7ZDQQbw5Ysn86TbyKq2MEUSc
Cmo0YB6vvfaaqlWO7zf89XPnzlX+etTS1Z/Vqd2EtE5gHyA2Te/lSyIH1PE0
10zds2eP1VNq1SBuDT4qbzXWzp49K/X19f4v1AJAjUHswxcXF8ubb77p/wRC
SIsC+Sn6szdyjEhk8cYbbzjVTEWNOdI4oHvoUwLtg5ajrjz3JAghzcm0adOU
bqMmi88eW6TVgl4Yun5jT5QQQkjrBXmius39/PPPWz0d0kQgV0nFIjv0OyMj
w+opEUIICZHFixcb2o2amiRyQY13c94YYxIJIU0F4jWhKchXRW0jxE4i1hP7
TJHYz7E5Qa1lPdYU8ack8kGdW3PNVPRfI4SQcAFdhmb767EXSi5GeVGRFJW4
102oqyxW8aMNw2Y/ziWup6ZMimxFUuGpXGhdhXqvzOgbUC37Nz8raampkpa2
QHJtpUHPtSnZsGGDYXMzzrTtkJaWZug38woIIeECeRiB1iCELR6UfpfO1WoA
R7WX+S7ynT3Icz++K7sOlgKHHn/uqIXU8dHdbpfWz38o94Lqb9+vo4dr/XSY
tITuTtj/RI4ndBu1lujDaDsg/9dcMzUrK8vqKRFCIgDksARTexD2d6Dao/ey
1/rOH3B6T+uV20c27dsn+9TIlfH9HXUGrxjg0Nw3pA9+7vCgSw3gd6VftHZc
sf2nzP7a88GQ9F1SY7fR62rflcn9f6iudeOj1udh7d2717C5t2zZYvV0SDOD
nF7z3jf2oQghJFSgwdjTDrZ2MPa//ePQ1679pE+su/7mDbW/9i33njq7Erop
zb0r/bj6Weupq/XM1anf/7hJl8/KsI5abz1n1/q7SvevesD63hCoaQzdRo3j
L774wv8JJOLAnomu3YmJicxPJoSETCg1/zFKS/3vJdfmDzP62x5K0mr7jzXp
rzftlqqV0gma6+ihV1+Y7GY/a73t28v0I7hetYzvrNnd9z42S3YUnXPScKtb
a5aUlBg2N3OF2jbYL9H1G/2tSNtl+fLlYrPZ+AxHQgI1ikLRbtjq/sjoCz3t
KSoq69wcTY9NNrBX7ZYTMiDafKyjl73DP67sefjRr2voYV9/dK50cdnrvqFb
Hxmdvkus7oqNusa6drO/VNsGz8rmmqn5+flWT4lYhL4moEYTckexb8haTSRQ
0HsyFO3G8EntS9ItStPuBWvXytqMeKXd2N/WI6y9anf9NnWuWedfT+qq9HjC
EfsPhYnq37+YecjlxGqx7VwjqQkPS+9u1xsafq3DfreC6upq5SfHdxS9hwiB
rWWumVpR4f70SiIfT73FsFY888wzqm4y1g5CvHHx4sWQdBvxar44ubC3xxhy
Iy5cfGh36RQVm+4UY3ZusdL+HzydJ1sTvme/TqxsrHS8V/+ujB80VJYddMmd
rSqQAdhn/3/9LIs1R0yx/r3EczUh4NlnnzX0Gzn/zDtoe3z88cfyyiuvyOzZ
s916jGHgNby3devWAOOLSFvi0qVLIWm37z73FZLYWbOxVa5XXZ3ac64vXaL0
t12vReooXbtrnM6tlvFxmsaP2vG58+vdtD1tlXPWY0qDL7xqpfba3SvcZpKt
4s+t0W7khWF/E99D9IbEz4QAaDXWZl2/oeWk7YKaPdg/gc2t++lcx4wZM5Qt
wHqMRAdxZ8Fqt88cb0dO9zVDsl3eqHZoehfJqdFzxLrIiCSth31SwsMSF6vp
9rfuWeR+2Yy+hu0+cM0HTtfVdD1Kbvuf2bIPdV5sO2TW0H/Tjr8t2eX5oHk4
cOCA8b3bvHmzBTMgLRnsV8Fnrut3YWGh1VMiLQDUA4CPDv1ssBfuScenTJki
69evV3GwpO2C+AjUXAmPza3ndOsx4M4cXdjHiD3PG/p9d596dKzcM3qFh/g1
UfVXujn2zAtcA9Bq35TH42Lcrnf9HcOMOi/NDfxd+h4W+joT4gr2NXXtRgwb
YtkI0YGvDs90K1asMGo7uY6JEyfKqlWrVPww917aHoiLCES/T5061aLvj5ry
I1qdF5tNiivrLZvHmTNnjO8W4swJ8QZyxXT9xh4LIZ7Auova0atXrzb24lwH
9B15qNB75p61Hb766iuv/nPcM8gnQ/1U4h88J+vfJ9TUIsQbWGNRq0XXb9Rw
IcQfqM0Hv/nkyZM96jhzz9oeiF9D/Dn246DX8ON9/fXXVk+r1YC4E+zf6/El
hPgDz8zmmql83iPB8MEHH0h2drZab7zlnqWnp6s9Gu7LEOKZnJwc4zuze7d7
DxVCPIF4RnPN1DqrCwKSVgnyyfLy8vzmnuEY5p4R0sCkSZOMvSfuOZFgQI9Q
Xb9Zy4c0FvgAYWvD5vaVewab/fz581ZPlxDLQM0s/TuBvShCgqG2tlbi4+MN
/d6+fbvVUyIRAva8sfeNPXBvuWfYO8e6xT53pK0xb948wy9FfxQJhcOHDzvV
TP3b3/5m9ZRIhKHnniEm3VvuGWLZEdOOOOWWnFtESGNBvIh+3y9a5F5bhpBA
wZqq6zfuJ66dEU5dhRQhr7XGPa8Vea9Hymub7FfrfaCRI+4r9wy5M9B71ock
kQbuff1ex7MqIaGC9RT7k7p+L1261OopkTATdfNgo27Uhaz7tXpS7R4U5wyD
ChkWbX/9ty8027xQqw1+c9Ru85Z7hppv8L8znpK0drCXpO8hTZ061erpkAgA
+ZnmmqkHDx60ekokjESZejBUbR1s1IK8ZdwB01F27e7o3FOxOUH8Gmqo+8o9
Qw121GJHXFxjwTNrfX29XL58mbVESLOwbds2437esWOH1dMhEQJyDHXtXrt2
LessRBBaDwatJ7JZu9EjcalRdtpa7TaD+B30NPOXe4beaMHE+kCjUTMa8XHm
emDw46PvCrQ8FMrR16LEd/1uT8eUl+C1KucD1Z5GkVS4uBkqS46IrehcSOeQ
loHuX0pOTqYfiYQV5Pe8/fbbTq9hvUP+IWohYm2jjdIKqauRyhptrdC0u4s8
uzVF9VpE/yTtnZaj3WZQ3wW5Z/76nr300ksqDsgb2Ds/ffq0zzrcqNWNfqlB
4eiHhb4a873Jt8djtM87Kup22W5axrW+Weiv9UrDi/V7tf4aHR6UwcGec7WH
3tek2XnnnXeM+xW2ESHhxBynBrsb9Q6PHz/uZqNgjQypnoAeJ+Wh/n9NebHY
bKUe+vDVSYndZilzvAFbAjEeTsNuz7CCV2Bo2t1JttjX/l0jvqfW/PtUr8SW
qd1mAsk9g22DWr/m3DPc18H0sPzkk08CnpPWD8vTHoT/Y15P+JF6bexB/btU
IY/f4PCJfL9Bc+sLk9VrNz66O6RziPXALtJ9RlhXCWkKYGO7arbrgIYjRzwY
Xk/6obbGxDzhYgvoNgjWmjznk6rWK5tF15fB0S79AI3RXh5Zw1xhrzjsNF27
N1bipzekn/rsesqb9qefx7/bsrXbDJ4dUeNi+fLlHnPPzDUvKioqguo7Dfs7
sGfTd6Uf7seu/aRPrGYXlwVxTP3+x9W9+7OUw9oLVSsl1rSfsdphox9L+7l6
bdSOz0M6h1gL4on0vR9oOCFNAfZhoMuBrnFffvllgFc+6/D3RSntmO8U5Gyy
HVzfq12v1ib08tU1vt0vk2WfbZ/ypcIO27p8nHRR53aRHBrgbmwdca1a16HX
ztqNn4erz/1HD0+WYZ1bj3ab0fueIf8GfUqxRuIeNr8XjHZjfPjhh35/b23+
MKPP9KGkG13s4QCOqd8rcbhvfzlb/Xhu3b3qbzNz6wy1n/Gfz55Sry/sbfKT
h3IOsRT4yPVnyrfeesvq6ZAIxTWOx9947733AsoJry9MVOvWHf37Kjva2Zdn
1m77uGlMg11u1+5OLtrtSV92jWin9GlVZTg+hcgizrTv6ardYGHfK4zP/poh
2ZbNM1wg90yPBYJvKFjd1u9rf2T01X0Wds7NUfep673p+5g6mRyH9/upfD3t
2AH2v5PDv3QncgNOaHa7EZcQyjnEKuC/QWwadBt1qAlpCmBDh7LOffrpp36v
ndlfswMK6ss1//gVA0z5xQ7tvukJyUjorjTkrvTj2lsetDvaHJOjqHasZ7FO
mkQ0zJ+nJ+2W2pe0uCb7+F4rtLt9gT6VodzTGD7jMo3PrKcssNtVazPitdg/
Rzx/oMccSr1N/T1Wl9hkgP29mN9mqtezB2mabCtdpc4x75OHcg6xBvgGdZsb
PXkIaQoQQxHKGldW5r7L54Qe8+rIMT6U9FOlEyNf0/fiHNod84TUSJkMiNZ0
Xvm/XbUbx0V3kbi4OGN0dvjifxLP74Yn4tccM/6tabf7M05pRt+IsbvNVFVV
hazdvvxJJxf29hJ3ESUP5V4I+Jj6o1pM2a+GDlL+qN9vuqjNW/2d2sugob9U
7080+eJDOYdYw7Rp04w6Q+xtT8LJpUuXjH9Dg0NZ4+Cj9MW5df3VWnLd/clq
72fhiJ+pn3V7wdBuh1+3Nv8JRz0R1Pja5rzfrbQ7Vjp36yadO3eWbvYR215b
D2N+t4g+QuIE8rlDuaePHTvm46oVkthZs59Vvbq6OvxP6kuXqOfMdr0WBXgM
eEPzb0eZnleByRcSdaXJlg/5HNLcIN5Xt7mff/55q6dDWhGwGxDjeOjQIcnN
zVW1y9PS0tT+C/p2o5aauR7+2bNnQ1rniouLfcyi2lEbxNPoKQVKbBu0W7fg
M/prx8SvXaDWI98+c0ccHHNZiQvI6w7lni4v91FrxZGv7e6jqHbodRfJfXu+
32N0zdXiyrQ4jxrTcfr3pl2P2W7PpKGcQ5oX5DLq2o3aP4TowAeDvNVXX31V
5bQuWLBA9VZEPoK5v6evAZ+ODvqIhbLOQfO9cm6xFp/zh0y1lugxRPtT44z4
W1e7W1G/TYuxcgx/sWpafQr9WYCQBrBuBntPI0/SG1q+dnuZfsTdJ310YR91
v/a5r4vfY7R7WuTkgn6OvK/XnY47lHqHc+yHiVDOIc0HagToeWFz5861ejqk
mUG9R+QUoD7kc889p+pATpgwQcaMGeNUfzyUAbsb9vesWbMMPUWd6FC021ct
Kj2n2zV3xshLVfaBwxfuYjdr+S/BaHesbGCOGHEBNcv91SswD1/12QgJBNhS
us395pvcvYgkoJenTp2SgoIC2bhxo/JdoyZUMDaztzFq1CgZO3asyklALYB1
69apHg4nTpzwGS+BuFr4v4PdF/Re+9xhT3dw7VkFdP8efIeVmh/Rzeetx4/r
sT0+csQctat+xtha4gHc94HoN3zlrPtLGgP2afR6QZMmTWJf5VYG8qZQwxZ5
AYhTmDNnTths5oSEBBW3OHPmTFVXasuWLar3F3zejQW+QtRcCVS7UW+akNYA
7G/Y1J7u7/fffz+gXEdC/IE9TN3mzsnJsXo6xATy7RGTjZpemzdvVj2GsW+M
XgmjR48Oi82M57X58+eruGzkCMJmCLyGWeNAPQt/taiw/gVT95mQlgLsIOwP
QasRh27OtSCkscCm0vvWfvHFF1ZPp01RXV2ttOuvf/2rqrOIWIOUlBR56qmn
wmIzJyUlyfTp02XZsmWSnZ0tBw4cUPE0Lcm3gp5h8B96slHOnDnDXEVCCHEB
+bK6zb1ixQqrpxNRYC8COgm9zMrKkqVLlyodhZ6Gw2aGvkPn582bJ2vWrJHt
27er2sp4zm+N4HkC9j6eZ/AMic+PEEKIO7DHdO2GjUMCB/uviJ/asWOH0k5o
qG4zQ1sbo83Qdmg8/OPwk0P79+/fr/zn1DRCCGm7wL7Re8yjjgZpAPqIWJM3
3nhDXnzxRfWMM2PGDBW3BV90Y3QZvnDoO/oQwUcOXzl85vAZMx6LEEKIL+Bf
Rc4ttBuxUG0J+JXRvwf5TMhrQqwWYrYQuxUOmxnPRFOnTlX1bjZt2qQ+X/g1
aDMTQghpLMgvhN83kjQF+6bIYUIuE3KakNuEeDzUBwmHzYzcK+RgIRdr5cqV
KjcLOVrM+yCEEBJukG+EWCDk1bZmrcZ/A2p/7N69WzIzM1VNENQGgf+gsTYz
apWgZglql6CGCWrW7N27V9U2wedHCCGENDWwq1FHElrnmn+D+tTIrw2F8qIi
KSrxUUNfKiR/7QxJSkq162qarNlR6vx2XYUU2UrF0+4ueloUFhaqXHNPPS0a
YzPjGqhDg5qfqP2JGqCHDx9WNUEJIYQQq4FtffLkSb/1qs6fPx9cbT5HbxvU
v5/vQb7rjy5p6A9nHjcPlh0Vl9Qzw4spvdRrf5y6UPW0gM3c2PqcOB/XwfXQ
K2P9+vWyZ88elQen19EmhBBCWirY8w1Et0Opia/Xc8a4xaWm88XTq+QH6r1o
uXNwokyZYbe9x46Qu27/ntYvLvY/lM4Ov6+zOubeYYHZ0brNDPsbdjjscdjl
sM8rKtiNkRBCSOunqqoq6B5N/mqqYb/31OmXJQ692GO7y4872P8/ups8Zupp
cX/3Dkqjf3jXwy76+5j0QN/jqOtloAftxj41bGa9pwX2sbGf7a+nBSGEEBIJ
6LHjwWq3uTYL6oB46mnx6O9+orT55r4Pyx96XK31U3pghEOfh0nXGLs+t7tZ
HnSxmxHfnTxujPxl0lQV9716/C/t53aQJUc+alH1OQkhhBArQBx5KL2RURtE
11GbzebRd/0fP4DtfK2ynZ8c0kui7dp9ZeffOHpajJE7YYtH/VzW5eer/Glv
PS2qtg62H9dJNlY25ydDCCGEtEzQryYU7cZAXwiA3spmmxn1xGak/FFuUHvZ
nSXBbo8/kzZcOqqf+4jW8btChqGHcrsHpczb5BwhY9RuQgghpIFwaDf2vl3z
x04u7O0eO+4YD+Uix6paxnfDzz2lwENY99YR19rfi1V6Te0mhBBCGgiHz9yd
CknsrNnYBUjKrqvD/6S+dIl0Qvx4r0XqqGNpP1da/pP4Xc6n174kcdD5q4cL
osKp3YQQQkgDocaqnT592vtFHTnd1wzJdnmj2qHpXSRHFVp5V/pFa7b4zfcn
S+4+m+zMSpFu7bXX7ko/rs6idhNCCCHOhDtHTMvpbi/Tj7jXBT26sI/S5YGb
zjt+eYEMi/uOi189VuLXHGuYn9LuWGo3IYQQ4gC+b9Qva4raLIFSU16s4tVt
RSUea58SQgghxJkmq4lKCCGEkCYDmnzx4kV5//333TQbdnlNDS1iQgghpKWC
/C/saaNeyuXLl62eDiGEEEIIIYQQQgghhBBCCCGEEEIIIYQQQgghhBBCCCGE
EEIIIYQQQgghhBBCCCGEEEIIIYQQQgghhBBCCCGEEEIIIYQ0OV9//bXqqU5I
S+Vf//qXfPLJJ3LmzBk5ceKE6h186tQpuXDhAu9dQkibAX1XP/jgAzl+/LjR
N72oqEitjZ9//nngF6qrUOeZh81WJF67r+N4m02KK+td35BynF9S5XZKTXmx
2IpK3K5Zum+jpKUmSWpqqsx8dqtU1JkvV+M2L4wytoVvdaA/sPk+dR1Hjx6V
Tz/91OppEkJIkwL75ciRI17XQozy8nJl6/jjQtb9EhUV5WF0kWcOuj8DvJ70
Q+39mCekwvxG1Xrp5Dh34sF/OJ2TPQivt5dVlforJySx97c9/M5YGZd73s+8
ouTuSbtC++BIs1NbW+v3XtUHbHBCCIlEoNuBrIMYsMG/+eYbn9er2jpY6WrK
y4V2e9tmH/skK22gtIdOXj3cWZ/lrAzuqGtoJ5lfbHqrdr100fX1+8OlzPRW
3tBopcsblXbXyaw47bib758iRyprpc5uYxdm/Vli1fk9pcCYV5T0ejpbbPv2
yT772Ll5hsR11J4D5pc4Px+Qlsfly5eVryTQ+xXjyy+/tHrahBASVuAnD9SG
0cfHH3/s85qaRnaSDS6+aKWvHR500uD6wkSlp3f076u0/cZHdze8addupb0d
26tj7kw5bLxl1u76o1PVue16zXaby8mFvdW5j+ReMLT7oVxnW+wf+YPU6/et
+SDgz41YA/Z0grlXMbAHTgghkcT58+eDXguxz+jL9ta1e1lJrdpjhg1cmj9d
s6FvS3bao87sD5v3dimoL5dhsH+vGCCG6V2r+cwfeTlfHr9B87lvdPjIzdpd
mtFXae/I1zztyddJTWWNaV7Q7i+cjtiV0E29/meP55OWAu65Y8eOBX2/YsBe
J4SQSCHUtfCrr75S58Nuf++995Se41qIEdq7sJ/XfeVe03YqP/rBgwfljdcW
yc2wl+94Wvbv3y8Z/3uTOua/07dLQUGBvJqXLFfbf+6dulX2ZAzUrvHTR2Tn
zp2Sek+0ej4Yt367JPW+Sv177MZXZOvWrWrk5uZKTk6ObNmyRY0XX3xRVj7d
S10j5ge3Sffu3eXWW2+VH1+n75HfJpPXr5cXXnhBMjMzZd26dbJ27VpZs2aN
GqtXr5ZVq1ap8fzzz8vKlSvlueeekxUrVkhGRoYay5cvV+PZZ5+VZcuWydKl
S2XJkiVqLF68WBYtWqTGwoULZcGCBZKenq7GM888I/Pnz1dj3rx5asydO1fm
zJmjxuzZs9WYNWuWpKWlqTFz5kyZMWOGGtOnT1dj2rRpakydOlWNKVOmyOTJ
k42B+D2MSZMmqZGSkqLGxIkTZcKECU7jL3/5iyQnJxtj/PjxaiQlJRnj6aef
VmPcuHHG+POf/2yMsWPHqvHUU085jTFjxhgjMTHRaSQkJBhj9OjRahQXa09z
//jHP0K6VzGwR04IIZEA8mhCXQv1GF5c48knn3Qaw+/rbNfCdnLbr+6Wvnff
LXfbx6/ibpEO7aCRMXLXkJHquIfv1rT62zf10I756TXq5yt/dI92rUfukWjs
Yfd9WP18T+do9f5tvxsuv+9+lbrWvcNGyv3dO2j/fmSk21y08ZhpXvZnhXbR
EhMTLdExMRIdHSPfvb6r/HaYt3M5rB6nT59W99qlS5dCvl8/++wzK79qhBAS
NuBHDHUt1Pe8EXfuWbuj3bR0+N03Ku388V3Q4kekR0fPtnlU1LUy4DF37X7y
yQFyPd6P/oF07/wdQ7t1Te7Sd7jbXEY+0EOLYbNfwzjuN49arkctcYwcOdLr
GDVqlNcRHx/vNHR72TzM9rSrrW22w11tdNjtyN1u7P2KnDJCCIkEsH8YbJya
qw/y73//u/Ijw6es+5cXj/53pavxKzOV/xl+6A0bNsj8/7tdaWfP+KWStXS4
xNj/Hf3vo2R9drZ6H77taYM0ff3FmOckd0OiOubOsc9LXl6ebNu2TTYk9TFp
/PXy9MZ82bXsUaXxUd/tJ6v27JFXX31V9u7dKwUF+TIi7kr1HPGnF16VvFl3
qfN+PTlH+ewx4L8vLCyUw4cPy1tvvSVvv/22vPPOO+q/EZ8NYpqxD4A9AewN
oP4HtAR+3JKSEiktLZWTJ08q2xAx+GVlZWqcO3dODcRWffjhh/LRRx9JRUWF
VFZWSlVVlcpdunjxonoGgg+jurpaampq1OeKXHrERmPg88WAvxijrYPPP9h7
FX9H1BoihJBIAZoT7rVQjwm7d8R4SVV7o6mSOKiHQ29vl5yahpzusS5521K1
Uost7zFb6hyxagM3nTcd0JAP1pAjJpI19CrttRv6SPrmfLHt2ySP947RXnPE
x+nzcr4eaU3g2SfY+xV1CQghJJKAnRfsWojYdF/oGuk6vtt1sOSUo3ZahRY3
3uFBKXY7u1rGd9NiynPP5ygdd9PaqvXSLco57hznrUv4hdvvvO1/Fhn55FVb
h2tx5tTuVgv2aIKxveEzQTwlIYREGmfPng14LYTvuEXn29Ro9VXhCy93q7FK
IgHErAWSH4H9jqBq+RJCSCsC/u9AfOfQbey9EmI12PtHfIG3exWxCLxXCSGR
DuLWED/lyZ7B/jbirlq0vU3aJLDBsQeO+xP72ogJZA1UQkhbAxqOfBrUOEcc
NGKfXePSGO9MrAJx+8g54D1ICCGBAXsmKytL1fQixApQBw656Kj7xjrlhBDi
G9jeqH+p1/HA3jchzQny8fX7D3VbCCGE+Af1TvS1E/WqCWkukBuGumv6/Yca
OoQQQgIDfSv09RN10AhpDjZu3Gjcd+izQgghJHBQ71NfQ1HLmnk4pKlBnAVq
quv3HWrLEkIICQ70tNTXUfSvJKQpQW9U/X5Dj1VCCCHBA1sbNre+nqJGBiFN
gaufp66uzuopEUJIqwU9vfQ1NTk52erpkAhlwoQJxn2GvG5CCCGNY9y4cca6
umfPHqunQyKM/fv3M6+BEELCDPo56Wvr6NGjWeuKhA3khCUmJhr3F/qKEEII
CQ9z585lHBEJO5mZmcZ9NX36dKunQwghEQXqnTN/h4QT13sKPXIIIYSEl82b
NxvrbGpqqtXTIa0csy/nueees3o6hBASkbjWq7TZbFZPibRSTp48adxH8fHx
jKEghJAm5NChQ8aaCx2HnhMSLMg31O+j7du3Wz0dQgiJeKZNm2asu+vWrbN6
OqSVYe51k5SUZPV0CCGkTVBVVWWsvYg1qq6utnpKpJXwz3/+UxISEoz75733
3mvy3/nZZ5+FdF55UZEUlZS7v1FXoXLZzMNmK5Iaj1epkPy1M+zPKKmSmpom
a3aUNuJahBDSOFatWmWsvzNnzrR6OqSVsHr1auO+SUtLa5bf+e6776qaq0Ht
75TOlfZRURIV1V7mu8j3haz77a9HeRhd5JmDnxvH1R9dIt08HXfzYCmoCe5a
hBASDmA/oU6Lvg4fP37c6imRFg7sX/1+wfj444+b5fdCuzHKyz3Y0F7YlXCT
oaO3jDvg9F7V1sFK01NeLlTxmjbbPslKG6hp/dXDRWVP1r4kXRzaPyR9l9TU
1UldTbFkjOiuXffuFYFfixBCwoh535K1LIk/YGfr9wvs7+ZC124M5JQHcIb0
i7ZrZ9d+0ifW/v8dHpQy07ua3naSDS6XmhXXcKyu/fet+cDl2nUyvhs0vY+8
GeC1CCEk3EycONFYj7ds2WL1dEgLpbi42KmuLvw2zYVZu5Gb5o/a/GFKdwdu
Oi+Hkm5U/x57sCGHTdfbZSW1dimukTr7KM2frtnZtyVLjd1afvwG+7+vGCDF
nn6B/fjKmroAr0Waiq+//lr1q0N+4jfffGP1dAhpVlx7N6JvKCGuIJ5cv092
797drL/brN0YWLN9kdEXdnFPZRfLuTnSya6jVz3wovG+pree9qjtdvamiyK6
dkcN8Gs3+78WCSfQ6E8//VRKSkqc7omjR4+qPZVQe896i2usKS8Wm63UwzNY
nZTYzylzvFFXWewSs2izX6/K/azKMrfYRmN4iqskxAdLliwx1uX09HSrp0Na
GPn5+Zb2kXXV7kuXLnk/uPYlR3xZT1mwdq2szYhX2q37uIG+R/3YgnWyGcfY
x4LUIdK5PY6LldXlVTIM2t3Oh8+7LtBrhfGDaOPA1wO/i+v94DouXgzymclr
XGOFDOuoPYfd+KhLX9uq9eocfU8le5Dn57cruzbENfo6Thv9uMdCggK2Nmxu
fX0+c+aM1VMiLQT4I80xjbB3mptgtPvkwt5e18aHcrV66972qC+su0fzta95
z7Gn3VMKPJhxW0dcq3R5Y2Ug13LdLyehgBwDV1vb1wgmjtJ7XKPuf4lSf+P5
5g2U2vUS69iXAXlDo9Xz4aZ9+2SfGrkyvv+t2rlXDJB3Hadpx90u6S+/rGpU
O42XCyU0rwFpy2zbts1S24q0TFCnXL8v5syZY8kcAveZV0hiZ83GVrYOYsPt
i2F96RJle7frtUgdpevtFpeFsjSjr7FPfizt5+rfP4nf5XyQ3a6PM8WQB3It
0ng++uijgHUb48iRIwHW6fUV12jWbvu4aUxD3oBduzs5abf9/W+55xXsSuim
zr0r/XjDcfZ7h3EQJJyMGzfOWKf37Nlj9XSIxcD32BJq+JjX5FOnTnk/0OH7
vGZItssb1Q5N7yI5NQ171PeOGC+pSUmq7krioB6ONfp2dYyxpttfu/n+ZMnd
Z5OdWSnSrX2U01oc2LVIY4DNjf3gYLQb48MPP/R7bd9xjQ7tvukJyUjo7vR3
D1S7pWqlFm/xh8yG49o9qGIg69SzpWmE48MibZL333/fKZaY/SXaNjNmzGgR
tXPN6/Hnn3uvd6L5PtvL9CPu9+3RhX2MNdpbfNl3uw6WnPL6hpOqCmRY3Hdc
jouV+DXHGg4J9FokZGpra4PWbYxAav75jmt0aHfME3Y7uUwGRJuexwLVbjmh
ztOvmTf0+95jG7m/QhqBua/j8uXLrZ4OsQjU6tHvA9RAbc6cMFf0tfj8eWv8
z1qssU1sRSX0dVoA+sKHot0YPnPH/MY1OrTbsT9Sm/+Eoy7PC/aftrnsd3vR
7vpt6nc0aHe0ev4bnZam+jAbIylVcpFnSEiIoPYF/KP6ul1RwcpQbRHz/slr
r71m6Vx03WYOb9sE/RdC1W5fdXT9xzU2aLe+B57RX3s/fu0Cpcl+tbt0itrH
0ePUud9NmhLEPOrrNp4JSdsiLy/P+PtPmDDB6ukonylpu6AWbyi6fezYMR9X
DSSu0dnuVtjt6DiTxrtqt7MmV8v4OO24UTs+93EcIeEBz6ro7a2v3/AXkrYB
Yhzi4+ONv/3p06etnhJp42C/JhTt9ln/PqC4xkotz9+lLv25dfd60O5odc6I
pFRVxygp4WGJi9WO+dY9i4xz9eMeTkiQESNGmMZQeezpTGo6aTSHDh0y1m/o
eFA9nEirBTEO+t99/vz5Vk+HEMW5c+eC1m5fNSIDi2t8R9Nxt54y1TI5zrlm
gMcYtOhYuWf0CqdzfcWqsf49CRdTp05tEXHGpHlw7etOXzVpKVy+fFnFT4Yz
P4yQSKWysrJF5PeS5sH8rLZx40arp0OIE6inh7wvf7rNuEZCRFatWmWs5zNn
zrR6OqSJwJqn/50TExO5R0JaJNj7hk3tqVbLiRMnaF8Q4gDfFXM9a/itSOSB
/u363/jAgQP+TyDEQvBs+cUXX6gYdOS1hto/jJBIZu/evca6jjWeRBY5OTnG
3zclJcXq6RBCCAkTyPPV1/ctW7ZYPR0SJlx7yCGelxBCSGRQVlZmrO9Y633l
X7QVsJ/gvadV68Dcu33BggVWT4cQQkiYWbx4sbHOp6enWz0dS8Ae29mzZ51i
ZVC/CbGt9fWh9Z4ot1+rqMRDHYm6CvV7zMNmK/Jav6Gusli9X1Hn+fUyl9c/
+uis/HHwA/LA4CEyYuRI+fLLL0OaPyGEkJaLq3/1zJkzVk+p2UDOCfTZV24K
egajb2ZQOOo7oU7EfBf5vpB1v5c6Dl3kmYOu/bQqZFhH7f1bxh12eseo22zu
P2znid/8UHv9e3fK+mzX+lKEEEIiBXOt6+TkZKun02xgzyDQuhDB6LdW30nX
XOf4bq2/ZHtJeblQ62Nl2ydZaQM1rXet9XR0iuMZwD6+P9ylPlOdzOqtvXdn
iqbrb+VPkBh1/PXyh/gxoX4szcL/BzqHCxg=
    "], {{0, 414}, {495, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{495, 414},
  PlotRange->{{0, 495}, {0, 414}}]], "Input"]], "Text",
 CellChangeTimes->{3.5930580430725594`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"price", " ", "=", " ", 
     RowBox[{"FinancialData", "[", 
      RowBox[{"\"\<ASH\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dwd", " ", "=", " ", 
     RowBox[{"DiscreteWaveletTransform", "[", 
      RowBox[{
       RowBox[{"price", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
       RowBox[{"BiorthogonalSplineWavelet", "[", 
        RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"trASH", " ", "=", " ", 
     RowBox[{"InverseWaveletTransform", "[", 
      RowBox[{"WaveletThreshold", "[", 
       RowBox[{"dwd", ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{"DateListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"price", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trASH"}],
        "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "False"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<ASH\>\""}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.593048129902651*^9, 3.5930481486825438`*^9}, {
  3.593058855150058*^9, 3.5930588579384613`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1gs4VHkfB/BR2krRlIqm27hU2pBsRbqY0z20zYZRIYqEVkaRfSSRSzRv
LrmFtqamdVci99uQS+8ra0i5a0pGndqIVNja/c3/93oej+fznDPH93zP//87
o3Hc8+CJKQwGoxN+5X/hR1oZQ1MfqgtVm/Zbc8DMt+DLZdl3KEtijuo1mmq2
sPZoPEQsiQHX+eSedT9KzCgHn82pej3oSGwgA3eOXhLvQDsyY2nq696JHwLs
iKNNwM3ZK4oTrInZJWCH5dParpoTc/vBacLrR5y2EQcqx4ENpOZq+sS5RmCH
5u60DBax9Bi42V9wmqVILFSKp6lx46FbbrQVybse3DV1+pbEJmKGA9int3W7
KIfYIALcUHfw4dUrxOLpCTTVWh4WzXMmHl4Hjqs53f7NhJhtB57TrhQRrELM
DQPL3CVWLJklyZsLXhRQZVJTTcxcm0hT6cwOk/O3iTmHwfGaLOtdocT8YHBv
fmgE24NYmAMOqmV1zD5MLGmX26qTo7SP2JF3Hc53qn6kvpU4OhCcMNLqaLyB
WJwJzmSoqLutIx5uA7Miz7zNRLP/Ab9JZjz7hudL05JoirmquOvYNszbCo43
TJp4boZ5/wafqxCtt7fFvCuTaSq/oT38kycx4w+5VymuXR5EbNAMPters6o3
EvOOgyfe7PLST8K8Wik0td3MVllViHn3gy0U3CaviIi5T8AsFc/NCejAz+AM
vkfTejw/l30Drqfj/MAFryc1A88xshxcE4X5fcADySaeIZhHOAq+aMXax+dj
n0t/p6lupxHvIbwfxl7w+OOaEYWdmP+M/HiwoCZNB/PfAAfEWbyWzsQ+WTfh
+hPTDuUMHiR97gK3lD/odmkk5nqCt3cd8FQuIA5MAhtbSufdvkuc+wict8qp
XiOZmLP9FtimIyIqnpj/K9io39SeTiAWJoCp/yVxDG8SS8Tgltmyn05mEUe7
CSFPprZRRCWxOBYccNfa7Ho78XAF+Pfx3zziPmPeN2AqM1J4YTH2Pe82TbkX
JvRb7sY+o8Hqy2I2qvlin2Vgi5cXkhpycD0MgBUZ9rNP0Lge5tyB9e3ov/Ka
FtkPwk1go6k9gz8fxv1VDM4bPM9NERA7vgIvUrFz9C0ljp4toqlT5/zV+gdw
/20Ep7N7ffqUyX4edhTJ7zfgvJshzoMXYJmJg04IzqfcmXfBmYH++l44D34C
t9i98nUV4Dw7Ck7nhrAM7+A8Cwe7h7k4Cwpwnv3wB+T5Hm7tXYfzbB04r+jd
X+9bcJ7Zgo3yI/XGunCehYLTh73mX5XiPLsP7h497RwzgPNMP5WmJOWhS6fQ
OM8OgcPNC01f/IX5L4EVhYxGnY+YPxtMlTpX9Y1i/udyJ79aovCZmG+dBudz
/PqjvuB8uwgOz1qjKviK+TPAkp7PWSNoRhu462l3Tj3a4Ds4NbpLfTpa7J9O
UxtVR9/n4/WHU8GXbVf82PQJ87eAU9y8JAdHMP8k+MzW9hc7hzD/igyamtXO
OyR6h33+CY6uqc3XHMS8X8EKDI2RmpeYVzOTpuyjTqmGdGNeC3Aq/66aSxv2
2QjuFDV+d32CfY6Bv+i8fPyfR5h3eRZNTWEM+LSUYN594HGd9mlG9zGvN7hL
VPRbhQj7HAGn8cP+dE7EPpdkw/siasd0vSu4HvZky9fvkOZCf8zvBY6tCddg
e2D+FLByO3OquT32ycqhKe+tlxsSLLDPneCGsXenp27G/KfBPVrtRq5rMP91
cF7DXs26pZi/Jke+fzj6rHnYJ3UP1g+/yvbkDOzzFLjepzYzm4H548FpwwcW
0xNkP0irwOYvj+Us/0LMpMF5eyYc94/hfnO9D+tPa9HGs2jJNXCDT6VuDJ7P
qAD7bKV3pk3i/pubC/PC70ZAgQL2GQVW13/WWTYT+ywFq9jE8UpVMe/rXPn9
dn7KXY55VR7A+lRKfXhLD/MagzXrri92wj44RWD3lXmrJ/diny8fyK8/0neS
h+thVh5N6fYc2pzhhOthQ578/S7bVsXHvh3B4WuS32ZcwD77wM1PvDe74fMT
z8inqQvzz63/loD5DcHXptxsO4HPn20PVk58v1iE64N7Gfyh5ZhSQRmuh2kP
Yf3nf7uV0oDrwQD82kTcw3uK+Y+Av7pmiGV9mD/kofz5l5ib434W3gPziocu
hIzhetAroKmIxh1qVf/gerABq/gWqE3O4JH8QeCB0p0XjecSi7PkxxM/7vdV
Jx5+Jv/8rPLgomXEgVaFNGWjfpc9rkWcG1Aof/9maG/RIZamg2UTT6IC1xAz
n4IzJMrH6/WIOd/Aldt+TVFeSyw5X0RT2rvebOahGangnv6gHUJ9YgMJWMba
lPdOl9hxArydVg43/hHzaxfT1PAvjLqwlcRsEfjjL0y35xrE3KZi+ftebNq3
FPN/AQd9mrvvJgvza5TQ1NzEqaEL8X6l5mDtuvjR3QuJhZ/AlQGP49YuwLzL
SuH7zaMUV8l8zLsPHBg3x3M1Hjc4C84Y1ko3wc+LP4JtOjpUFf/f5+Iymrpi
rp8Xiv+fvbtM/n1DO7gK83H54IttpWEPMH9gMpiiP5bb4v0xF5XD5wX/XVGJ
/XJ2lMufN1XdsY6Y71Euny9HorKMMX8i+INGj7jFFPNXg3Wf1Fub78E+ORUw
fzxZP6sfwD7dweGz2jOMbTB/HDhV+LdrtgPmrwSX6QsEZ10x/1twXcGluZFe
2OfJSpqq3dA/MemHfcaAS+9l76kIwfzl4FT2iy8tkZhfBg4X+M0yScL8zCrI
MxRwaUyE/UaBdS3e2ynex35LwB9u1yS7lGL+/ir5PFLYsqQe8yuLoQ/jTM6K
VsxvBHbnpe0N68Z+C8EDZuOWpq+wXym4YYHwOFeG+ZWqYf0XpXiXDGL+9eAK
/fcRfnic6QBu9Y+5E4ufF/aCLW4LKhV7sN/pNTSlf6Ortwn/P8MQfM4jgDGE
+QzswNoLfFe6FmP+MLBxbO2BTWnYr+Ij+fcRF//jsdjvWnDcvKPZ/f6Y/zC4
RzXzRbkT5g8GX3lntvADPs/cHPDNJA7XdzX2q1sL97+wzqp3NvbLAw8f69Bi
4/tTGAjW8/erMO3EeZcJ1jyRpbGlBufdM7BkySnughxrzr+uSXOx
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 74.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"ASH\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {74.3368858921738, 
    91.62069430548237}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.34567616826617154`, 
   0.34567616826617154`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.5930481498925323`*^9, 3.593049359291602*^9, 
  3.593058858648761*^9, 3.59306516172996*^9, 3.5930977933798943`*^9, 
  3.5931303726846037`*^9, 3.593130432204932*^9, 3.593136232025136*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<ALV\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trALV", " ", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trALV"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<ALV\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593048159877125*^9, 3.59304816391518*^9}, {
  3.5930482014460373`*^9, 3.593048202795373*^9}, {3.593058862135045*^9, 
  3.593058865790887*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1gtYTOkfB/DZLtptVYN1i2W6rUtRViW57JwipMugolINq78k2wghWRPd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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 63.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"ALV\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {62.82347394516229, 
    93.55981893891008}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.6147268998749559, 
   0.6147268998749559}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593048203497637*^9, 3.593049367316946*^9, 
  3.593058866980245*^9, 3.5930651637651167`*^9, 3.5930977955612087`*^9, 
  3.593130374445294*^9, 3.59313043362325*^9, 3.593136235165781*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"price", " ", "=", " ", 
     RowBox[{"FinancialData", "[", 
      RowBox[{"\"\<AXP\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dwd", " ", "=", " ", 
     RowBox[{"DiscreteWaveletTransform", "[", 
      RowBox[{
       RowBox[{"price", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
       RowBox[{"BiorthogonalSplineWavelet", "[", 
        RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"trAXP", " ", "=", " ", 
     RowBox[{"InverseWaveletTransform", "[", 
      RowBox[{"WaveletThreshold", "[", 
       RowBox[{"dwd", ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{"DateListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"price", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trAXP"}],
        "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "False"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<AXP\>\""}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5931303795500813`*^9, 3.593130389252986*^9}, {
  3.593130424927655*^9, 3.593130427205114*^9}, {3.593136242465528*^9, 
  3.593136244605857*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1gk4lPseB/AhpUU1XcVJFxM5dSRNi0jRvLdOjSWNtThiEGHcjHYnMYji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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 58.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"AXP\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {58.39369273538704, 
    81.56739163778492}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.46347397804795765`, 
   0.46347397804795765`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.593130390013014*^9, 3.5931304358552437`*^9, {3.593136237252192*^9, 
   3.593136247000474*^9}}]
}, Open  ]],

Cell["\<\

Compute pair-wise distance between the Trend price curves:\
\>", "Text",
 CellChangeTimes->{{3.593137730644918*^9, 3.593137763865587*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trALV", ",", "trASH"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trAXP", ",", "trASH"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trALV", ",", "trAXP"}], "]"}]}], "Input",
 CellChangeTimes->{{3.593048230582942*^9, 3.5930482368105497`*^9}, {
  3.5931303974997053`*^9, 3.593130415229088*^9}}],

Cell[BoxData["11.916924121421108`"], "Output",
 CellChangeTimes->{
  3.59304823733888*^9, 3.593049369806534*^9, 3.593051256358539*^9, 
   3.593051411649543*^9, 3.593065165583025*^9, 3.59309779739542*^9, {
   3.593130415830183*^9, 3.5931304372142677`*^9}, 3.593136256361779*^9}],

Cell[BoxData["20.32758320798495`"], "Output",
 CellChangeTimes->{
  3.59304823733888*^9, 3.593049369806534*^9, 3.593051256358539*^9, 
   3.593051411649543*^9, 3.593065165583025*^9, 3.59309779739542*^9, {
   3.593130415830183*^9, 3.5931304372142677`*^9}, 3.593136256363069*^9}],

Cell[BoxData["8.674161505350607`"], "Output",
 CellChangeTimes->{
  3.59304823733888*^9, 3.593049369806534*^9, 3.593051256358539*^9, 
   3.593051411649543*^9, 3.593065165583025*^9, 3.59309779739542*^9, {
   3.593130415830183*^9, 3.5931304372142677`*^9}, 3.5931362563640633`*^9}]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["OK!", "Title"]
}], "Text",
 CellChangeTimes->{{3.5931307681881113`*^9, 3.5931307693695593`*^9}}],

Cell["\<\
Compute the mean distance to the random-pick outliers:
\
\>", "Text",
 CellChangeTimes->{{3.5931376324777107`*^9, 3.5931376340630083`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trALV", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trASH", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trAXP", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}]}], "Input",
 CellChangeTimes->{{3.593048211300666*^9, 3.59304821717837*^9}, {
  3.5930493747600727`*^9, 3.5930493788725452`*^9}, {3.5930514140139103`*^9, 
  3.593051415600039*^9}, {3.593130457226242*^9, 3.593130491177911*^9}}],

Cell[BoxData["128.4878926758611`"], "Output",
 CellChangeTimes->{
  3.593048217842123*^9, {3.59304937107487*^9, 3.5930493794816504`*^9}, 
   3.593051257326078*^9, 3.593051416770608*^9, 3.5930651667498293`*^9, 
   3.593097798262945*^9, {3.593130486218788*^9, 3.5931304927093697`*^9}, 
   3.593136258197175*^9}],

Cell[BoxData["133.44782475115488`"], "Output",
 CellChangeTimes->{
  3.593048217842123*^9, {3.59304937107487*^9, 3.5930493794816504`*^9}, 
   3.593051257326078*^9, 3.593051416770608*^9, 3.5930651667498293`*^9, 
   3.593097798262945*^9, {3.593130486218788*^9, 3.5931304927093697`*^9}, 
   3.593136258198454*^9}],

Cell[BoxData["124.5212249908689`"], "Output",
 CellChangeTimes->{
  3.593048217842123*^9, {3.59304937107487*^9, 3.5930493794816504`*^9}, 
   3.593051257326078*^9, 3.593051416770608*^9, 3.5930651667498293`*^9, 
   3.593097798262945*^9, {3.593130486218788*^9, 3.5931304927093697`*^9}, 
   3.5931362581994543`*^9}]
}, Open  ]],

Cell[TextData[StyleBox["Similarity: APEI, APOL", "Title"]], "Text",
 CellChangeTimes->{{3.593058957341634*^9, 3.593058964969667*^9}, {
  3.593097203701207*^9, 3.593097204711274*^9}}],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvX3MFfWd/y16t/3ZpLHZh7DNJiWbTZqazWZ3G7Ld7DbL9s7+VZI2u/eu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    "], {{0, 438}, {495, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{495, 438},
  PlotRange->{{0, 495}, {0, 438}}]], "Input"]], "Text",
 CellChangeTimes->{3.593058941278407*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<APEI\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trAPEI", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trAPEI"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<APEI\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.59304831827835*^9, 3.593048332531191*^9}, {
  3.5930588791018753`*^9, 3.593058882812345*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1ws4lGkbB/BZFaqRQaXSwWGrrxJSJp+NZsiqdJhEahNWbcu2RTXqK7HT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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 33.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"APEI\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {32.9769156851154, 
    40.42049861946378}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.14887165868696756`, 
   0.14887165868696756`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{{3.593048322705562*^9, 3.593048333448039*^9}, 
   3.5930493844280453`*^9, 3.5930588841044073`*^9, 3.593065173139626*^9, 
   3.593097800947844*^9, 3.593127539620016*^9, 3.5931362617729387`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<APOL\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trAPOL", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trAPOL"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<APOL\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5930483448626003`*^9, 3.5930483539174843`*^9}, {
  3.5930588872007713`*^9, 3.593058890879098*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1gtYjGkbB/DZtJVE4/CVSAdyPjTosCttM1kqGzptkrYG6xNZZtE6M5tD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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 16.400000000000002`},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"APOL\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {16.528356002331726`, 
    24.345879442798914`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.15635046880934375`, 
   0.15635046880934375`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.59304835471644*^9, 3.593049386594249*^9, 
  3.59305889180093*^9, 3.5930651758101*^9, 3.5930978030045567`*^9, 
  3.593127542116364*^9, 3.593136265086132*^9}]
}, Open  ]],

Cell["\<\

Distance between the Trend curves:
\
\>", "Text",
 CellChangeTimes->{{3.5930589805631332`*^9, 3.593058989134845*^9}, 
   3.59306664627997*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trAPEI", ",", "trAPOL"}], "]"}]], "Input",
 CellChangeTimes->{{3.5930483634688377`*^9, 3.593048371506838*^9}}],

Cell[BoxData["68.07985399174858`"], "Output",
 CellChangeTimes->{3.5930483725639153`*^9, 3.593049389222809*^9, 
  3.5930512522555017`*^9, 3.5930589917999487`*^9, 3.593065177992145*^9, 
  3.5930978045507593`*^9, 3.5931275452268467`*^9, 3.593136269621917*^9}]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["OK!", "Title"],
 "\n\nDistance between the APEI and APOL Trend curves and random-pick:\n"
}], "Text",
 CellChangeTimes->{{3.5930589972357473`*^9, 3.5930590244824133`*^9}, {
  3.5931307820716763`*^9, 3.5931307840063057`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"data", " ", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"CanberraDistance", "[", 
     RowBox[{"trAPEI", ",", 
      RowBox[{"tr", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", " ", "1", ",", " ", 
      RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Sqrt", "[", 
   RowBox[{"Variance", "[", "data", "]"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.59304838026515*^9, 3.593048382790592*^9}, {
  3.593049394166279*^9, 3.59304940123062*^9}, {3.593051424116391*^9, 
  3.593051426039919*^9}, {3.593127562313733*^9, 3.5931275725889072`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "146.66599860615452`", ",", "17.74653886293874`", ",", 
   "26.981549261277692`", ",", "23.34236415559104`", ",", 
   "163.9796350652175`", ",", "20.30851537383815`", ",", "98.22739926974458`",
    ",", "168.97141539855824`", ",", "178.36982203157635`", ",", 
   "91.01249762857222`", ",", "115.22810535384738`"}], "}"}]], "Output",
 CellChangeTimes->{3.593048383289097*^9, 3.593049401831901*^9, 
  3.5930512535061197`*^9, 3.593051428212583*^9, 3.5930589931178827`*^9, 
  3.593065179010784*^9, 3.593097805818524*^9, 3.593127573249823*^9, 
  3.593136272524644*^9}],

Cell[BoxData["95.53034918248332`"], "Output",
 CellChangeTimes->{3.593048383289097*^9, 3.593049401831901*^9, 
  3.5930512535061197`*^9, 3.593051428212583*^9, 3.5930589931178827`*^9, 
  3.593065179010784*^9, 3.593097805818524*^9, 3.593127573249823*^9, 
  3.593136272526106*^9}],

Cell[BoxData["64.49069939996923`"], "Output",
 CellChangeTimes->{3.593048383289097*^9, 3.593049401831901*^9, 
  3.5930512535061197`*^9, 3.593051428212583*^9, 3.5930589931178827`*^9, 
  3.593065179010784*^9, 3.593097805818524*^9, 3.593127573249823*^9, 
  3.5931362725271473`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"data", " ", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"CanberraDistance", "[", 
     RowBox[{"trAPOL", ",", 
      RowBox[{"tr", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", " ", "1", ",", " ", 
      RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Sqrt", "[", 
  RowBox[{"Variance", "[", "data", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5931275857801867`*^9, 3.593127587158292*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "177.06144614595905`", ",", "51.6570507134254`", ",", "91.38968726386688`", 
   ",", "46.75015916877153`", ",", "125.73015297139132`", ",", 
   "85.20135093831865`", ",", "45.80166952328163`", ",", "133.4880864412424`",
    ",", "148.63007664145152`", ",", "26.444834031655688`", ",", 
   "56.45492649549353`"}], "}"}]], "Output",
 CellChangeTimes->{3.593127587661614*^9, 3.59312769958346*^9, 
  3.5931362736925373`*^9}],

Cell[BoxData["89.87358548498706`"], "Output",
 CellChangeTimes->{3.593127587661614*^9, 3.59312769958346*^9, 
  3.5931362736939383`*^9}],

Cell[BoxData["49.66746948336128`"], "Output",
 CellChangeTimes->{3.593127587661614*^9, 3.59312769958346*^9, 
  3.593136273694956*^9}]
}, Open  ]],

Cell[TextData[StyleBox["Similarity: CBSH, CFR", "Title"]], "Text",
 CellChangeTimes->{{3.593062704348578*^9, 3.593062713065301*^9}}],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztvQt4FFWa/5/BWeKyOgZndMnjLE7QdYx/1zHuLjPw+82oYWaU8Ky6hN/6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    "], {{0, 369}, {493, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{493, 369},
  PlotRange->{{0, 493}, {0, 369}}]], "Input"]], "Text",
 CellChangeTimes->{3.593059184566023*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<CBSH\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trCBSH", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trCBSH"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<CBSH\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593048438024251*^9, 3.593048449576929*^9}, {
  3.593059038639657*^9, 3.593059044284698*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1Qk4VfkbB/BLYxjZEtlaUNOTQleJtM091pKKSiaJy0xTf0xMZKYydWOM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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 36.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"CBSH\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {35.829950806316944`, 
    46.69079998050587}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.21721698348377858`, 
   0.21721698348377858`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.5930484529048243`*^9, 3.593049407255568*^9, 
  3.593059045636711*^9, 3.5930651820662203`*^9, 3.593097808548317*^9, 
  3.593127712716875*^9, 3.593136278084363*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<CFR\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trCFR", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trCFR"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<CFR\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593048463471631*^9, 3.593048473045395*^9}, {
  3.593059049291657*^9, 3.593059053813435*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1Qk8lPsawPHJUocKabOkRtJqmSTh1DGv6rgKSZaSMi06loQi1alM6tDe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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 56.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"CFR\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {55.72910872086653, 
    72.6575262942631}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.33856835146793157`, 
   0.33856835146793157`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.5930484742047863`*^9, 3.59304941455569*^9, 
  3.593059054313034*^9, 3.5930651844637814`*^9, 3.593097810687818*^9, 
  3.5931277148542423`*^9, 3.5931362833794622`*^9}]
}, Open  ]],

Cell["\<\

Distance between the CBSH Trend curve and CFR\[CloseCurlyQuote]s:\
\>", "Text",
 CellChangeTimes->{{3.593059195506976*^9, 3.593059213303893*^9}, 
   3.593066651994966*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trCBSH", ",", "trCFR"}], "]"}]], "Input",
 CellChangeTimes->{{3.593048483158276*^9, 3.593048490521409*^9}}],

Cell[BoxData["47.00285787414424`"], "Output",
 CellChangeTimes->{3.59304849154184*^9, 3.593049416611032*^9, 
  3.5930512472681437`*^9, 3.593059090528872*^9, 3.593065186649666*^9, 
  3.593097812840914*^9, 3.593127719265424*^9, 3.593136286186797*^9}]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["OK!", "Title"],
 "\n\nDistance between the CBSH and CFR Trend curves and random-pick:"
}], "Text",
 CellChangeTimes->{{3.5930592208872213`*^9, 3.593059249461258*^9}, {
  3.593130790981573*^9, 3.593130791835744*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"data", " ", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"CanberraDistance", "[", 
     RowBox[{"trCBSH", ",", 
      RowBox[{"tr", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", " ", "1", ",", " ", 
      RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Sqrt", "[", 
  RowBox[{"Variance", "[", "data", "]"}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.593048499167164*^9, 3.593048501130085*^9}, {
  3.59304942162805*^9, 3.593049425538011*^9}, {3.593051432396793*^9, 
  3.5930514338138027`*^9}, {3.593127724237144*^9, 3.59312773259892*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "140.046131837296`", ",", "29.251697261471854`", ",", "15.474648218695567`",
    ",", "34.21693481453139`", ",", "168.9844710539948`", ",", 
   "8.109785075961733`", ",", "107.82280354939877`", ",", 
   "173.37267384318477`", ",", "182.07651309133828`", ",", 
   "100.39483801198894`", ",", "123.35941245170643`"}], "}"}]], "Output",
 CellChangeTimes->{3.593048501616342*^9, 3.593049425901227*^9, 
  3.593051248519663*^9, 3.593051434850421*^9, 3.593059091878581*^9, 
  3.593059225668228*^9, 3.593065187551049*^9, 3.593097813992453*^9, 
  3.593127733277079*^9, 3.5931362877870073`*^9}],

Cell[BoxData["98.46453720086987`"], "Output",
 CellChangeTimes->{3.593048501616342*^9, 3.593049425901227*^9, 
  3.593051248519663*^9, 3.593051434850421*^9, 3.593059091878581*^9, 
  3.593059225668228*^9, 3.593065187551049*^9, 3.593097813992453*^9, 
  3.593127733277079*^9, 3.593136287788415*^9}],

Cell[BoxData["66.32104800469628`"], "Output",
 CellChangeTimes->{3.593048501616342*^9, 3.593049425901227*^9, 
  3.593051248519663*^9, 3.593051434850421*^9, 3.593059091878581*^9, 
  3.593059225668228*^9, 3.593065187551049*^9, 3.593097813992453*^9, 
  3.593127733277079*^9, 3.593136287789455*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"data", " ", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"CanberraDistance", "[", 
       RowBox[{"trCFR", ",", 
        RowBox[{"tr", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"i", ",", " ", "1", ",", " ", 
        RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"Variance", "[", "data", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.59312773696212*^9, 3.593127744197661*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "108.1904611534269`", ",", "74.06689522583156`", ",", "31.99011951368432`", 
   ",", "78.49652150049663`", ",", "184.80829219632483`", ",", 
   "39.26870269507627`", ",", "139.02247871378182`", ",", 
   "187.86321364534854`", ",", "193.85820258944398`", ",", 
   "133.97301263050468`", ",", "151.65572283813415`"}], "}"}]], "Output",
 CellChangeTimes->{3.593127744602372*^9, 3.5931362907227077`*^9}],

Cell[BoxData["120.29032933655031`"], "Output",
 CellChangeTimes->{3.593127744602372*^9, 3.59313629072403*^9}],

Cell[BoxData["58.35576872523277`"], "Output",
 CellChangeTimes->{3.593127744602372*^9, 3.59313629072504*^9}]
}, Open  ]],

Cell[TextData[StyleBox["Similarity: BDN, BXP, BMR, ARE", "Title"]], "Text",
 CellChangeTimes->{{3.5930601323911552`*^9, 3.5930601527410097`*^9}}],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvQt0VdW5/h2xJR5bK/TiR0ZbPcHWI/YcbTyntjDGqRb+thW+qgccfz8F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    "], {{0, 457}, {509, 0}}, {0, 
    255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{509, 457},
  PlotRange->{{0, 509}, {0, 457}}]], "Input"]], "Text",
 CellChangeTimes->{3.593060100938287*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<BDN\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trBDN", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trBDN"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<BDN\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5930485557671833`*^9, 3.59304857223631*^9}, {
  3.593059909856851*^9, 3.593059915613597*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1wtczOkaB/DpglS21smlOttOnFZIRje309kmx1KKkHu2CUWty4jWyqVx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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 12.3},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"BDN\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {12.34955678354018, 
    15.524351030017726`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.06349588492955092, 
   0.06349588492955092}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.593048580278764*^9, 3.593049432060287*^9, 3.593059254819627*^9, {
   3.593059910915515*^9, 3.593059916263495*^9}, 3.593065190055974*^9, 
   3.593097817223387*^9, 3.59312777941011*^9, 3.593136294765774*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<BMR\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trBMR", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trBMR"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<BMR\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5930485901471653`*^9, 3.593048596918708*^9}, {
  3.593059919157587*^9, 3.593059929575726*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1glYzHsXB/C5rVQq5Epp4SZSN6Od+2L+yjblKioimdz3pkIG0ytKDSlZ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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 18.3},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"BMR\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {18.345729041940075`, 
    22.332487773275947`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.07973517462671743, 
   0.07973517462671743}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.593048597562413*^9, 3.59304943307439*^9, 3.593059255956901*^9, {
   3.593059925170062*^9, 3.593059930055355*^9}, 3.5930651924149714`*^9, 
   3.593097818895954*^9, 3.593127781837237*^9, 3.59313629687374*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<ARE\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trARE", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trARE"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<ARE\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593048603174999*^9, 3.593048611511168*^9}, {
  3.593059934931542*^9, 3.59305994210742*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1gk41PkfB/BZKv5yltWlorb0j9xHqmWGXTnXuFoJMx1YVMhROiZH1G4W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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 61.5},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"ARE\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {61.396111737983325`, 
    74.98304591857367}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.2717386836118068, 
   0.2717386836118068}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.593048612514587*^9, 3.593049438460614*^9, 3.5930592594249563`*^9, 
   3.593059794560195*^9, {3.5930599381691732`*^9, 3.59305994259682*^9}, 
   3.593065194846854*^9, 3.593097821244404*^9, 3.593127783691432*^9, 
   3.5931362992082243`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<BXP\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trBXP", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trBXP"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<BXP\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593059360569676*^9, 3.593059381404613*^9}, {
  3.593059945877342*^9, 3.593059950376487*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1wlYTP0XB/D5IyWpIdrRQuWVacirUfTvlqRFllIv0mZPSMqSTJMi8apo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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 100.5},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"BXP\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {100.36143431465379`, 
    110.43211740912875`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.20141366188949916`, 
   0.20141366188949916`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{{3.5930593656899757`*^9, 3.5930593820866623`*^9}, 
   3.593059532325206*^9, 3.593059721064616*^9, 3.593059795754917*^9, 
   3.593059951007276*^9, 3.5930651967935057`*^9, 3.593097823868782*^9, 
   3.5931277860787163`*^9, 3.593136301629488*^9}]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["Fail:Partial", "Title"],
 "\n\nIn this case the pair-wise Canberra distances of the stock Trend curves \
are smaller than their individual distances to the random-pick:"
}], "Text",
 CellChangeTimes->{{3.593071538529724*^9, 3.593071588456582*^9}, 
   3.5930721758463783`*^9, {3.593072841310917*^9, 3.5930728489819527`*^9}, 
   3.5930968077441387`*^9, {3.593096915642942*^9, 3.593096920535285*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trBDN", ",", "trBMR"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trARE", ",", "trBMR"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trBMR", ",", "trARE"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trBDN", ",", "trBXP"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trARE", ",", "trBXP"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trBMR", ",", "trBXP"}], "]"}]}], "Input",
 CellChangeTimes->{{3.593048707642016*^9, 3.5930487443899307`*^9}, {
  3.593059393283927*^9, 3.593059427411722*^9}, {3.593059698690022*^9, 
  3.593059699854993*^9}}],

Cell[BoxData["42.32548711874151`"], "Output",
 CellChangeTimes->{
  3.59304873578622*^9, 3.59304944059643*^9, 3.5930512349250927`*^9, 
   3.593059260313645*^9, 3.593059441624609*^9, 3.593059534782674*^9, {
   3.59305970029677*^9, 3.593059732172534*^9}, 3.593059798824566*^9, 
   3.593059955785119*^9, 3.593065198392105*^9, 3.593097825601762*^9, 
   3.5931277891545486`*^9, 3.5931363038668327`*^9}],

Cell[BoxData["117.64448622820674`"], "Output",
 CellChangeTimes->{
  3.59304873578622*^9, 3.59304944059643*^9, 3.5930512349250927`*^9, 
   3.593059260313645*^9, 3.593059441624609*^9, 3.593059534782674*^9, {
   3.59305970029677*^9, 3.593059732172534*^9}, 3.593059798824566*^9, 
   3.593059955785119*^9, 3.593065198392105*^9, 3.593097825601762*^9, 
   3.5931277891545486`*^9, 3.593136303868144*^9}],

Cell[BoxData["117.64448622820674`"], "Output",
 CellChangeTimes->{
  3.59304873578622*^9, 3.59304944059643*^9, 3.5930512349250927`*^9, 
   3.593059260313645*^9, 3.593059441624609*^9, 3.593059534782674*^9, {
   3.59305970029677*^9, 3.593059732172534*^9}, 3.593059798824566*^9, 
   3.593059955785119*^9, 3.593065198392105*^9, 3.593097825601762*^9, 
   3.5931277891545486`*^9, 3.5931363038691673`*^9}],

Cell[BoxData["167.6322792313544`"], "Output",
 CellChangeTimes->{
  3.59304873578622*^9, 3.59304944059643*^9, 3.5930512349250927`*^9, 
   3.593059260313645*^9, 3.593059441624609*^9, 3.593059534782674*^9, {
   3.59305970029677*^9, 3.593059732172534*^9}, 3.593059798824566*^9, 
   3.593059955785119*^9, 3.593065198392105*^9, 3.593097825601762*^9, 
   3.5931277891545486`*^9, 3.59313630387018*^9}],

Cell[BoxData["47.38328402833798`"], "Output",
 CellChangeTimes->{
  3.59304873578622*^9, 3.59304944059643*^9, 3.5930512349250927`*^9, 
   3.593059260313645*^9, 3.593059441624609*^9, 3.593059534782674*^9, {
   3.59305970029677*^9, 3.593059732172534*^9}, 3.593059798824566*^9, 
   3.593059955785119*^9, 3.593065198392105*^9, 3.593097825601762*^9, 
   3.5931277891545486`*^9, 3.593136303871179*^9}],

Cell[BoxData["147.53438144998984`"], "Output",
 CellChangeTimes->{
  3.59304873578622*^9, 3.59304944059643*^9, 3.5930512349250927`*^9, 
   3.593059260313645*^9, 3.593059441624609*^9, 3.593059534782674*^9, {
   3.59305970029677*^9, 3.593059732172534*^9}, 3.593059798824566*^9, 
   3.593059955785119*^9, 3.593065198392105*^9, 3.593097825601762*^9, 
   3.5931277891545486`*^9, 3.593136303872162*^9}]
}, Open  ]],

Cell["\<\
Compute the mean distance to the random-pick outliers:\
\>", "Text",
 CellChangeTimes->{3.593137821838891*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trBDN", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trARE", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trBMR", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trBXP", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.5930487509894943`*^9, 3.593048764269154*^9}, {
  3.593051440159049*^9, 3.5930514434666157`*^9}, {3.593059465262048*^9, 
  3.593059476113267*^9}, {3.593127794447999*^9, 3.5931278394314632`*^9}}],

Cell[BoxData["91.87411181967758`"], "Output",
 CellChangeTimes->{3.5930487647915773`*^9, 3.5930494453665752`*^9, 
  3.5930512364094353`*^9, 3.593051444558523*^9, 3.5930592620641813`*^9, 
  3.593059476685624*^9, 3.59305980159647*^9, 3.59305995775194*^9, 
  3.593065199843437*^9, 3.593097826852974*^9, 3.5931278402627707`*^9, 
  3.593130634838415*^9, 3.593136304850281*^9}],

Cell[BoxData["122.32087271793485`"], "Output",
 CellChangeTimes->{3.5930487647915773`*^9, 3.5930494453665752`*^9, 
  3.5930512364094353`*^9, 3.593051444558523*^9, 3.5930592620641813`*^9, 
  3.593059476685624*^9, 3.59305980159647*^9, 3.59305995775194*^9, 
  3.593065199843437*^9, 3.593097826852974*^9, 3.5931278402627707`*^9, 
  3.593130634838415*^9, 3.593136304851429*^9}],

Cell[BoxData["90.38606700278413`"], "Output",
 CellChangeTimes->{3.5930487647915773`*^9, 3.5930494453665752`*^9, 
  3.5930512364094353`*^9, 3.593051444558523*^9, 3.5930592620641813`*^9, 
  3.593059476685624*^9, 3.59305980159647*^9, 3.59305995775194*^9, 
  3.593065199843437*^9, 3.593097826852974*^9, 3.5931278402627707`*^9, 
  3.593130634838415*^9, 3.593136304852318*^9}],

Cell[BoxData["142.44051306056127`"], "Output",
 CellChangeTimes->{3.5930487647915773`*^9, 3.5930494453665752`*^9, 
  3.5930512364094353`*^9, 3.593051444558523*^9, 3.5930592620641813`*^9, 
  3.593059476685624*^9, 3.59305980159647*^9, 3.59305995775194*^9, 
  3.593065199843437*^9, 3.593097826852974*^9, 3.5931278402627707`*^9, 
  3.593130634838415*^9, 3.593136304853207*^9}]
}, Open  ]],

Cell["\<\

BXP and ARE are causing the problem here, perhaps more investigation needed, \
or modification of algorithm. 

\
\>", "Text",
 CellChangeTimes->{
  3.593096929254476*^9, {3.593096962745322*^9, 3.593096991590376*^9}}],

Cell[TextData[StyleBox["Similarity: CMSB, CLX, ACXM", "Title"]], "Text",
 CellChangeTimes->{{3.593060698956514*^9, 3.5930607161667852`*^9}}],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvQl8VOW9/5+CJV6sLVjrJb+2csFeK7YXi+2lhd+/VcO1Cryqlvj69QLh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    "], {{0, 438}, {519, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{519, 438},
  PlotRange->{{0, 519}, {0, 438}}]], "Input"]], "Text",
 CellChangeTimes->{3.5930606858588257`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<CMSB\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trCMSB", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trCMSB"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<CMSB\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593049513361516*^9, 3.59304951719748*^9}, {
  3.593049678197443*^9, 3.59304968523948*^9}, {3.5930600099482107`*^9, 
  3.593060014119272*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwtlwlUk9cSgBHKKmBQSnFjE9wKsiqIcsyvddcnLuBShACCihbSKn0qoHFf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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 7.95},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"CMSB\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {7.9386484913760835`, 
    9.172607190450659}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.02467917398149151, 
   0.02467917398149151}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593049687071189*^9, 3.59306001602885*^9, 
  3.5930607260001173`*^9, 3.593065214461556*^9, 3.5930978302407637`*^9, 
  3.593127879752924*^9, 3.5931363101792927`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<ACXM\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trACXM", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trACXM"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<ACXM\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593049697694025*^9, 3.593049711091864*^9}, {
  3.593060019385869*^9, 3.593060024525598*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1gs4lNkfB/BZJXLfVekijUpbSY0kUWpe2yZSjZK0iVGbVlIjPJWKQTey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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 17.5},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"ACXM\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {17.42256283322583, 
    32.83287256686484}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.30820619467278026`, 
   0.30820619467278026`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593049712350296*^9, 3.593060025205076*^9, 
  3.5930607280164967`*^9, 3.593065216696813*^9, 3.593097831476335*^9, 
  3.593127882242091*^9, 3.593136312927824*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<CLX\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trCLX", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trCLX"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<CLX\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593049719665229*^9, 3.593049729991987*^9}, {
  3.593060029412529*^9, 3.593060032738372*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1gs4VPkbB/BJoSJGtkSIaCu5JZfSVjNabS5tqkHJZVI9JGlK/n8hTYUU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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 73.5},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"CLX\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {73.7200065833703, 
    87.76541858970192}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.28090824012663235`, 
   0.28090824012663235`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593049730566681*^9, 3.5930600332880087`*^9, 
  3.593060730259049*^9, 3.593065219132107*^9, 3.593097833357503*^9, 
  3.593127884406097*^9, 3.5931363147625847`*^9}]
}, Open  ]],

Cell["\<\

Let\[CloseCurlyQuote]s compute the Canberra distance between the stocks Trend \
curves:\
\>", "Text",
 CellChangeTimes->{{3.593071667500217*^9, 3.593071685186125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trCMSB", ",", "trACXM"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trCMSB", ",", "trCLX"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trCLX", ",", "trACXM"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5930497463718643`*^9, 3.593049774739752*^9}}],

Cell[BoxData["96.95794550166146`"], "Output",
 CellChangeTimes->{3.593049775129743*^9, 3.593051211640297*^9, 
  3.5930600366139708`*^9, 3.593060732185841*^9, 3.593065220909355*^9, 
  3.593097835692589*^9, 3.593127886381476*^9, 3.593136317393828*^9}],

Cell[BoxData["176.06305015098206`"], "Output",
 CellChangeTimes->{3.593049775129743*^9, 3.593051211640297*^9, 
  3.5930600366139708`*^9, 3.593060732185841*^9, 3.593065220909355*^9, 
  3.593097835692589*^9, 3.593127886381476*^9, 3.593136317395091*^9}],

Cell[BoxData["123.12434574192959`"], "Output",
 CellChangeTimes->{3.593049775129743*^9, 3.593051211640297*^9, 
  3.5930600366139708`*^9, 3.593060732185841*^9, 3.593065220909355*^9, 
  3.593097835692589*^9, 3.593127886381476*^9, 3.59313631739609*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["FAIL: Partial", "Title"],
 "\n\nOne of the distances i.e. 87.1352 is smaller than the distances above.\n"
}], "Text",
 CellChangeTimes->{{3.593060760751666*^9, 3.5930607622581587`*^9}, {
  3.5930609340711107`*^9, 3.5930609548484364`*^9}, {3.593097033678761*^9, 
  3.593097035161827*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trCMSB", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trCLX", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trACXM", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}]}], "Input",
 CellChangeTimes->{{3.5930497869173183`*^9, 3.593049799827135*^9}, {
  3.593051455819154*^9, 3.593051461365419*^9}, {3.5931278892293997`*^9, 
  3.593127910350566*^9}}],

Cell[BoxData["100.13025575669977`"], "Output",
 CellChangeTimes->{3.59304980045053*^9, 3.593051213141306*^9, 
  3.593051462123136*^9, 3.593060037765623*^9, 3.593060734320767*^9, 
  3.593065222611533*^9, 3.5930978375606527`*^9, 3.593127911100857*^9, 
  3.593136319011541*^9}],

Cell[BoxData["132.33922762594645`"], "Output",
 CellChangeTimes->{3.59304980045053*^9, 3.593051213141306*^9, 
  3.593051462123136*^9, 3.593060037765623*^9, 3.593060734320767*^9, 
  3.593065222611533*^9, 3.5930978375606527`*^9, 3.593127911100857*^9, 
  3.593136319012765*^9}],

Cell[BoxData["90.03006906920619`"], "Output",
 CellChangeTimes->{3.59304980045053*^9, 3.593051213141306*^9, 
  3.593051462123136*^9, 3.593060037765623*^9, 3.593060734320767*^9, 
  3.593065222611533*^9, 3.5930978375606527`*^9, 3.593127911100857*^9, 
  3.593136319013755*^9}]
}, Open  ]],

Cell["\<\


CLX is causing the problem, somehow it should be weeded out.
\
\>", "Text",
 CellChangeTimes->{{3.593097040506328*^9, 3.593097058494383*^9}}],

Cell[TextData[StyleBox["Similarity: CCV, CMCSK", "Title"]], "Text",
 CellChangeTimes->{{3.593060872016178*^9, 3.593060881554089*^9}}],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsnQt8FOW997fYEg/VGtRac3qqDbbW+PbY4tvSwuccL+FYFU61Bd/Tg8Cn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    "], {{0, 478}, {523, 0}}, {0,
     255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{523, 478},
  PlotRange->{{0, 523}, {0, 478}}]], "Input"]], "Text",
 CellChangeTimes->{{3.5930608425634604`*^9, 3.5930608547071323`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<CCV\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trCCV", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trCCV"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<CCV\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.59305035270746*^9, 3.593050361617365*^9}, {
  3.5930614708485937`*^9, 3.593061477922082*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1gs4lGkbB/BZHXw5TiUi2RnUp02lJGWzeRGFrhXSSQ5tB7FfTQ616TQp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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 21.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"CCV\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {21.076662099636174`, 
    25.2832895352645}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.08413254871256655, 
   0.08413254871256655}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593050363144475*^9, 3.5930609790859528`*^9, 
  3.593061478766594*^9, 3.59306522593909*^9, 3.593097840781715*^9, 
  3.593127934128389*^9, 3.593136322281156*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<CMCSK\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trCMCSK", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trCMCSK"}],
      "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<CMCSK\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593050375948983*^9, 3.593050385915992*^9}, {
  3.5930614821970043`*^9, 3.5930614922327003`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1gs4VOkfB/AJUZGmG4oi1F8XmUTpYncOiShLyT1GW6kppSRlS0MuaXdD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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 36.5},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"CMCSK\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {36.651359876412926`, 
    46.3709444740508}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.19439169195275752`, 
   0.19439169195275752`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.5930503871632357`*^9, 3.593060980144512*^9, {3.593061489443623*^9, 
   3.5930614927626553`*^9}, 3.593065227156782*^9, 3.593097842697341*^9, 
   3.593127936253902*^9, 3.593136325957704*^9}]
}, Open  ]],

Cell["\<\

Distance between the Trend curves for CMCSK and CCV:
\
\>", "Text",
 CellChangeTimes->{{3.593060996396175*^9, 3.5930610120549507`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trCMCSK", ",", "trCCV"}], "]"}]], "Input",
 CellChangeTimes->{{3.593050395670013*^9, 3.5930504150534143`*^9}}],

Cell[BoxData["56.01437770408236`"], "Output",
 CellChangeTimes->{{3.593050404150502*^9, 3.593050415822691*^9}, 
   3.59305120196517*^9, 3.5930609818670473`*^9, 3.593065229634137*^9, 
   3.593097844850541*^9, 3.5931279390910263`*^9, 3.593136327869472*^9}]
}, Open  ]],

Cell[TextData[{
 "\n\n",
 StyleBox["OK!", "Title"],
 "\nMuch smaller than the corresponding distance to the random-pick:"
}], "Text",
 CellChangeTimes->{{3.593061016071849*^9, 3.593061031922429*^9}, {
  3.593130809589471*^9, 3.593130812243472*^9}, {3.593136328763254*^9, 
  3.593136330247945*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trCMCSK", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trCCV", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}]}], "Input",
 CellChangeTimes->{{3.5930504237274103`*^9, 3.593050435231242*^9}, {
  3.593051469566791*^9, 3.593051472367755*^9}, {3.5931279414300823`*^9, 
  3.593127951863195*^9}}],

Cell[BoxData["97.48745542814324`"], "Output",
 CellChangeTimes->{{3.593050426181576*^9, 3.593050436088732*^9}, 
   3.593051203283559*^9, 3.59305147304806*^9, 3.59306098281758*^9, 
   3.593065230718586*^9, 3.593097845767139*^9, 3.593127952335313*^9, 
   3.59313633143911*^9}],

Cell[BoxData["90.38962986260555`"], "Output",
 CellChangeTimes->{{3.593050426181576*^9, 3.593050436088732*^9}, 
   3.593051203283559*^9, 3.59305147304806*^9, 3.59306098281758*^9, 
   3.593065230718586*^9, 3.593097845767139*^9, 3.593127952335313*^9, 
   3.5931363314403563`*^9}]
}, Open  ]],

Cell[TextData[StyleBox["Similarity: CUK, CHEV, CCL", "Title"]], "Text",
 CellChangeTimes->{{3.593061553084181*^9, 3.593061572445154*^9}}],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3Qt8VNX5L/wRlVDUv+Ct5LWvGmwtsdYaj6VN3rZqKEXheCOe40HgrRoQ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    "], {{0, 426}, {439, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{439, 426},
  PlotRange->{{0, 439}, {0, 426}}]], "Input"]], "Text",
 CellChangeTimes->{3.593061455314178*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<CHEV\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trCHEV", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trCHEV"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<CHEV\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5930515111486073`*^9, 3.593051522757678*^9}, {
  3.5930614999186783`*^9, 3.593061502818386*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwtlgtUjWkXx8+HUCM1yYyM6EJikm66MOm8yDUUSk2NLpaS0KkcZoU6pBQ+
ndLt6CIqJV0OdZSup3JX4/iEUWkaFF7D5BLRGN/ez2Yty/qt99jv7/0/z7P3
YxgQumbTMIFA8AD+4r/wp6chieeC+9q17vobC4G1nwNn6y2L5zwZC8cl89yV
AZWk2IWxKgm4N3LrRy0nxoI64Fk+7+fa2DC26APOlm13/t6MsZ/2MZ6zs747
4aIJY+lc4I+mMxV6UxkbXDyG9bZNdCB2fcyen1j6/XTGEs0UnrO1bnSqpHpy
uxSs3/ZFaw7jHv8UfP+N+JlCxrkaqVhP0TF8FfnapKL/0YHMDeTrC6xq9Xjw
Jox8E4CHCzTjRsczVo5K4znfxHNDXbmM+y2Bn0QumiuqI18f4OTmy1xzB/nG
AQcH7iwRDpKvnLFH5AvdqSzP2en4+01nmy0YC73SsV6+05UVjEUx6fg+Hbv3
mxjnlqajjzxpTTRj1f109N2zujOdsZ9HBn7PryJpOWOpJAO/N/9d2BXGyuIM
zONLZ3QX4/524BxZgknNa8YGXzJwPRa2G4ycxvIrlPHcJ1Oz3go9xtr/k2G9
RV4RZoyF/7DnRyx85zMWmRznOXvr4SG7VjMWFAB7VN/68sCXscUtxq9fxYUy
9vvIfh9sHxXFWGqcifVsuxqPMFauzMT19OxYcZyxayuwcazKyqiQseQ9cMKL
7N4FFYzlBlk8d7tV+aa0gfyXZ2E9h583Xid/MfAIwahJG+8wzn0L3O820760
i7FKP5vn6ibnlXG95L8UeEtgWLTBS/IPz8Z6qcXL3pF/Fns+1qL+E+P+iTn4
/x9q7RaYsDydgTuNk154j2TsGgp8RTyzxXcMY4kMOEr3TFqcDmN5Sw76aQaq
JjAWLjgBedl7WDpOYSzaCryj/sBg6zTGuWnAfokZtdFmjFVK4AllSZHu1oyl
wbl4XkVzVs1lrDwG/Pdt67+COcb99cBj73flFC0l32e5eL5CVmq4kq/OSZ47
d7X7w9H1jHukwLYVdjm2voy1a4HjX4iF/wki317gQpGs+9V28tU6hfVWXJi2
k3wdTuH3Hr5asIexRfUp3G9eOqH7Gfs9AjaKVaTtO0j+Y/J4jtPIXffwMPnb
Ah9rnuCyP5H8/fLwe6fsFSVTnn/k4XmofFqYQnmq5+N6/H7YNI38rYE78hKC
3xBrbwA287kuUUsn/3jg80vSb/vTc9XIAlzft96jUhkLLIHdqx9OeU/vs/AG
jnD00DeXkn8s8KUBn3XlR8i/HFh+Vc8tKIHyNT/NczYVR8Z5xFG+nsBrqxWZ
u2PIfz/wmPspz+9LyL8EeIPWzM9bosj/HvAyf/E9G8pP5F7Ic7+17hTPiaR8
o4H/cjPv2Por+Z8BLujPHNFJ+QvagT8UNb6LFpP/v8CPImXF3jso3z1FPLc5
cIbJ9gjK9zRwXEhoUFU4+d8Gnn8oZLsdsesQsLRZf96rMPKfdobn9ujGtXUS
C38DbhFHSl2IRYPAQX2fYoQi8jUqxveNKqqi/aJyKcb8TvxzbivleRN4b8ql
fbO3UJ4DwMkLxHYWtN+UU87y3DDBef3KjeS7DPhWa6RNLe1Pgx3Ag0W3djt7
U55vzmI9+ds1HpTnpBLIN1E/6zHtd+0lwFmy78QflpN/WAnu98yoo4vIPxPY
rKukusiR8pxYivt5ufFiW8pzUSnup4iGQHPy316K+2evYmg6+WeU4n7fPFrN
mPybS3E/W1ftp/PtypXxXLRuT9MOfcozpAz7zTbTzknkn1qG/aGTV9DznsYy
7N8z1NUMyJ8vw/7vGXON6uduLke/YC/BDMo3GfjqgNfhktnkX1+O//9HvTY7
8v1Wjnl2Dwv42h8SgQdNw5aGuFCeNXKs1/v8mSf5PpHj/HJ42hFIvmPP4TwO
FXK03+T2wPEhhd3X6XwLq4APhjxq2kHnQ/Qn8BxrAwiBfL85j/X81lvSeVTN
Ac7Sy1dfmEG+fsDr7HnBLjqf0m7gmsnWjm1JlOfoClz/qAbnQ+RvVYH7pe1A
TzT5/wI8TDJZmv11/x4ENowN79kTQHmqVfLcK7fr4qjVlKdFJd5/jFxPOZD/
z5VYLzr0GeUtOoDPA7vvuKqRfxnw327CvZ19NC9mKaBf2L/8veUGzYv1CuzH
vX3q52je7VPgek0vLJXRvDurwP6l0Cs/QPPkLnBdztH5Y8Np3q27gHmeH3/T
n+Zd1AXM2/BE71qad0UXsF5Hxy9Lad7dAbar+OOatRPN68/ACSGzg4Psad7t
rsL+eKN20Jrm3ekqzK9c+dSS/FXAl8U9u2ysyP9TFa6Hz5/dNuQ/tRrWo9ro
c58DY4O8aszP5qYLR/O6Dfhj0VQbT/KRfKjG+fXWTp3uB3LDi3i/OXnP1538
VwDXTjbX9vGm+fzuIn6v7MlnP/KdXAP9Qfx4rXMg+S4DDnccs8EqhHwjanD/
jBt+me4XytfAhmqfFnyOoDx/qOU5A7VG/c5d5Lu4FvtXwLENu8lXVIv1evMO
0n1EcrwW37d4tcc+ylOvDvthXOqNGMpzYR3uv4KdT2Lp/rOtDvvJqTd5B8k/
Hfi0aJ0Xd4j8m4CTmmuK6/5LeQrrwSf2bt/4ZMpzSz3mma+5Mp38U4B/9DGd
EpBN/g31WM/vB/d88n8OfHnAZZhJCeUZ1ADn68XLO+2VlGcS8Eu3hVJ/ug9p
1zXgeV5p13qN/PsasN4313XbyV+7EZ9HOc/roXwTG3E9C0qcvt5/LjZifcm/
hkPk/7gR368975E6nUdNJc5/9wCJHp1HOyXe3wQrf6L7iusF4CKRztD4WdQv
epTYjw5t1bSkfqHRhP1uy0kj4h4b4AUacpk7/V7btwn7lY/76a/3n4dNeH8J
bdedSP1iVDPPpTQ//+6kBvULK2BznxuTVnwgfx/grrxv+3To+/zimrFeY/jg
Jcp3RAvsT8f25qECynd2C96vVt+bROvt6sXYstTbh/ZHDPt95JJqOi/y0hac
HzMKrIZTvmaXsF+IFr2+R/d5j0vYv1ZNe1dC93kJ8OPIliXzYuk+XwzspKE6
e8WXseAu8Oa+CLe0n6YK/w/KkTJp
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 9.600000000000001},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"CHEV\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {9.57050863399171, 
    11.297386456758254`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.034537556455330895`, 
   0.034537556455330895`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.59305152594868*^9, 3.593061503975731*^9, 
  3.593065233262731*^9, 3.593072869752859*^9, 3.59309784862437*^9, 
  3.593122203109377*^9, 3.593136334654711*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<CUK\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trCUK", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trCUK"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<CUK\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593051536505932*^9, 3.5930515465743723`*^9}, {
  3.59306150707224*^9, 3.5930615117169647`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1wlYjWkbB/CjdbQ5I5SMcVoYV6JNi6Vx3opIRo2USA5fDCeTSF+NJSfa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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 33.2},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"CUK\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {33.31704251334073, 
    39.399920697791984`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.12165756368902507`, 
   0.12165756368902507`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593051547490426*^9, 3.593061512688154*^9, 
  3.5930652355317173`*^9, 3.5930728722081347`*^9, 3.593097852008419*^9, 
  3.593122205163186*^9, 3.5931363373217783`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<CCL\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trCCL", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trCCL"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<CCL\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593051552683733*^9, 3.593051560921509*^9}, {
  3.593061515959465*^9, 3.5930615206299543`*^9}, {3.5930728843208647`*^9, 
  3.593072886969364*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1glYzGkcB/DRRBQae5Els7miJDpUpPmn1JJMKjkqYy06rEYJmy5Xkmi6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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 32.4},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"CCL\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {32.43887005726343, 
    37.45210169636881}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.10026463278210755`, 
   0.10026463278210755`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593051561566359*^9, 3.5930615213327503`*^9, 
  3.593065236640006*^9, 3.593072890597617*^9, 3.5930978531577272`*^9, 
  3.593122207718973*^9, 3.593136340522709*^9}]
}, Open  ]],

Cell["\<\

Distances between the Trend curves are smaller than the distances to the \
random-pick:\
\>", "Text",
 CellChangeTimes->{{3.593071715796855*^9, 3.593071741884907*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trCHEV", ",", "trCCL"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trCUK", ",", "trCCL"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trCUK", ",", "trCHEV"}], "]"}]}], "Input",
 CellChangeTimes->{{3.593051573380684*^9, 3.593051617713539*^9}}],

Cell[BoxData["114.29508134032594`"], "Output",
 CellChangeTimes->{{3.593051581368347*^9, 3.593051618130884*^9}, 
   3.593061529221253*^9, 3.593065238740472*^9, 3.593072896969542*^9, 
   3.593097854841406*^9, 3.5931222119986362`*^9, 3.593136343247925*^9}],

Cell[BoxData["4.059218848918594`"], "Output",
 CellChangeTimes->{{3.593051581368347*^9, 3.593051618130884*^9}, 
   3.593061529221253*^9, 3.593065238740472*^9, 3.593072896969542*^9, 
   3.593097854841406*^9, 3.5931222119986362`*^9, 3.5931363432492123`*^9}],

Cell[BoxData["117.17101207185598`"], "Output",
 CellChangeTimes->{{3.593051581368347*^9, 3.593051618130884*^9}, 
   3.593061529221253*^9, 3.593065238740472*^9, 3.593072896969542*^9, 
   3.593097854841406*^9, 3.5931222119986362`*^9, 3.5931363432502193`*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["FAIL", "Title"],
 "\n"
}], "Text",
 CellChangeTimes->{{3.5931280542660723`*^9, 3.593128055063517*^9}}],

Cell["\<\
Compute the mean distance to the random-pick outliers:\
\>", "Text",
 CellChangeTimes->{3.593137848692631*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"data", " ", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"CanberraDistance", "[", 
        RowBox[{"trCHEV", ",", 
         RowBox[{"tr", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"data", " ", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"CanberraDistance", "[", 
        RowBox[{"trCCL", ",", 
         RowBox[{"tr", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"data", " ", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"CanberraDistance", "[", 
        RowBox[{"trCUK", ",", 
         RowBox[{"tr", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.593122215300213*^9, 3.5931222220700417`*^9}, {
   3.5931279664274673`*^9, 3.5931280022796583`*^9}, 3.593137905135428*^9}],

Cell[BoxData["94.50144798770393`"], "Output",
 CellChangeTimes->{
  3.593122225492725*^9, {3.5931279952690287`*^9, 3.593128002958282*^9}, 
   3.593130840938574*^9, 3.593136344149027*^9}],

Cell[BoxData["93.65758038770986`"], "Output",
 CellChangeTimes->{
  3.593122225492725*^9, {3.5931279952690287`*^9, 3.593128002958282*^9}, 
   3.593130840938574*^9, 3.593136344150214*^9}],

Cell[BoxData["94.73331151179228`"], "Output",
 CellChangeTimes->{
  3.593122225492725*^9, {3.5931279952690287`*^9, 3.593128002958282*^9}, 
   3.593130840938574*^9, 3.593136344151183*^9}],

Cell[BoxData["94.73331151179228`"], "Output",
 CellChangeTimes->{
  3.593122225492725*^9, {3.5931279952690287`*^9, 3.593128002958282*^9}, 
   3.593130840938574*^9, 3.593136344152153*^9}]
}, Open  ]],

Cell[TextData[StyleBox["Similarity: AN, ABG", "Title"]], "Text",
 CellChangeTimes->{{3.593062848506887*^9, 3.5930628578765917`*^9}}],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3Qt4VNW5N/Ap2sSDWoO1HvLZQoOtFWq1ePrRku85XkK9hadqic/DB4RT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    "], {{0, 369}, {479, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{479, 369},
  PlotRange->{{0, 479}, {0, 369}}]], "Input"]], "Text",
 CellChangeTimes->{3.593062795196703*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<ABG\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trABG", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trABG"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<ABG\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593051785323907*^9, 3.593051793153879*^9}, {
  3.593062805375688*^9, 3.593062814295124*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1Qs4VPkbB/BJ6xqZSlmXtRO6rmUQqf8fc9CFtqIL1R+NbEXZNUr3aErS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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 33.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"ABG\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {33.00166123882868, 
    53.61835383336064}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.41233385189063926`, 
   0.41233385189063926`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593051794567235*^9, 3.5930628255464153`*^9, 
  3.593065242562272*^9, 3.593097858567985*^9, 3.593128073401926*^9, 
  3.593136350579295*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<AN\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trAN", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trAN"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<AN\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5930518046964283`*^9, 3.593051812120801*^9}, {
  3.5930628174912558`*^9, 3.593062821348713*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1gk4VfkbB/CbrYjcmWma0NSV7Z9BKlFp6h7GvvwZS5RyRQktFPGYoYtu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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 42.5},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"AN\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {42.439473022883774`, 
    52.02808534536747}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.19177224644967397`, 
   0.19177224644967397`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593051812836308*^9, 3.593062827619329*^9, 
  3.593065243731842*^9, 3.593097860346045*^9, 3.593128075640163*^9, 
  3.593136353404456*^9}]
}, Open  ]],

Cell["\<\

Canberra distance for the two stocks\[CloseCurlyQuote] Trend curve:\
\>", "Text",
 CellChangeTimes->{{3.5930717636209993`*^9, 3.593071781136425*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trABG", ",", "trAN"}], "]"}]], "Input",
 CellChangeTimes->{{3.593051819725595*^9, 3.593051824737855*^9}}],

Cell[BoxData["12.915255608463685`"], "Output",
 CellChangeTimes->{3.59305182516164*^9, 3.593062832558482*^9, 
  3.59306524582908*^9, 3.5930978623307247`*^9, 3.593128077400527*^9, 
  3.5931363557083483`*^9}]
}, Open  ]],

Cell[TextData[{
 "\n\n",
 StyleBox["OK!", "Title"],
 "\nHow far they are from the random-pick:"
}], "Text",
 CellChangeTimes->{{3.593071784647196*^9, 3.593071791306679*^9}, {
  3.5931308645900497`*^9, 3.593130865512521*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trABG", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trAN", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}]}], "Input",
 CellChangeTimes->{{3.593051830818095*^9, 3.5930518388906183`*^9}, {
  3.593128079715536*^9, 3.593128094144086*^9}}],

Cell[BoxData["99.34628763860128`"], "Output",
 CellChangeTimes->{3.593051839257112*^9, 3.593062834409768*^9, 
  3.593065246880452*^9, 3.593097863214052*^9, 3.593128094965423*^9, 
  3.593136357542921*^9}],

Cell[BoxData["102.07081253614787`"], "Output",
 CellChangeTimes->{3.593051839257112*^9, 3.593062834409768*^9, 
  3.593065246880452*^9, 3.593097863214052*^9, 3.593128094965423*^9, 
  3.593136357544116*^9}]
}, Open  ]],

Cell[TextData[StyleBox["Similarity: ANR, ACI, CLD", "Title"]], "Text",
 CellChangeTimes->{{3.593063955119699*^9, 3.593063969585285*^9}}],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvQt8VdWZ95+hFiytFexNPnZUaMeKY53iv7WFmakWxqowVQvO6yDwVgXb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    "], {{0, 422}, {488, 0}}, {0,
     255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{488, 422},
  PlotRange->{{0, 488}, {0, 422}}]], "Input"]], "Text",
 CellChangeTimes->{3.593062939157997*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<ANR\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trANR", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trANR"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<ANR\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593051871499092*^9, 3.593051875930756*^9}, {
  3.5930629511092463`*^9, 3.593062953976782*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1gtYzFkbAPChFKkM+uRWJoWW2Kl0wVPm/7kkyk4tuSRNKEU0lXwruxlL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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 5.2},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"ANR\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {5.1190900210337755`, 
    9.610383187364794}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.08982586332662038, 
   0.08982586332662038}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593051877733832*^9, 3.593062954847671*^9, 
  3.593065249698024*^9, 3.593097865399969*^9, 3.5931281547587833`*^9, 
  3.593136361256493*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<ACI\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trACI", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trACI"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<ACI\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593051884144346*^9, 3.5930518924973717`*^9}, {
  3.593062957678327*^9, 3.5930629619970512`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1gtYTOkbAPBBLhU1iXLNqKz4RzexecScSqH4T0oq0UhbdCGhjWKnbFu5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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 3.6},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"ACI\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {3.6375226190732812`, 
    7.257457911334934}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.07239870584523306, 
   0.07239870584523306}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593051893401161*^9, 3.59306296314746*^9, 
  3.593065253162936*^9, 3.5930978663471212`*^9, 3.593128157200562*^9, 
  3.593136363989887*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<CLD\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trCLD", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trCLD"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<CLD\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593051901300918*^9, 3.593051909980115*^9}, {
  3.59306296737569*^9, 3.59306297267381*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1gs4lGkbB/C5SgkJnTYdrEOKlQxaZFc7Y5UKGR0cyjLt11aSbSrV13FH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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 14.600000000000001`},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"CLD\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {14.560110630940189`, 
    19.17526859429666}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.09230315926712944, 
   0.09230315926712944}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593051910602178*^9, 3.5930629732294607`*^9, 
  3.593065254361231*^9, 3.5930978692927*^9, 3.593128159452734*^9, 
  3.5931363675871887`*^9}]
}, Open  ]],

Cell["\<\

Pair-wise Canberra distances less than the distance to Trend curve of the \
random-pick:\
\>", "Text",
 CellChangeTimes->{{3.593071810061368*^9, 3.593071838061995*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trANR", ",", "trACI"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trCLD", ",", "trACI"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trANR", ",", "trCLD"}], "]"}]}], "Input",
 CellChangeTimes->{{3.593051922348765*^9, 3.593051948004794*^9}}],

Cell[BoxData["38.06259337842022`"], "Output",
 CellChangeTimes->{3.593051948609803*^9, 3.5930629787919693`*^9, 
  3.593065256271866*^9, 3.5930978710205383`*^9, 3.593128160967115*^9, 
  3.593136369952751*^9}],

Cell[BoxData["120.68176173916723`"], "Output",
 CellChangeTimes->{3.593051948609803*^9, 3.5930629787919693`*^9, 
  3.593065256271866*^9, 3.5930978710205383`*^9, 3.593128160967115*^9, 
  3.593136369953969*^9}],

Cell[BoxData["91.5921473109215`"], "Output",
 CellChangeTimes->{3.593051948609803*^9, 3.5930629787919693`*^9, 
  3.593065256271866*^9, 3.5930978710205383`*^9, 3.593128160967115*^9, 
  3.5931363699549437`*^9}]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["Fail: Partial ", "Title"]
}], "Text",
 CellChangeTimes->{{3.593128208155541*^9, 3.593128227268285*^9}}],

Cell["\<\

Random-pick Canberra distances:\
\>", "Text",
 CellChangeTimes->{{3.593071843552903*^9, 3.593071854621909*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trACI", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trCLD", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trANR", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.5930519593840857`*^9, 3.593051973834382*^9}, {
  3.593128163461255*^9, 3.593128189419971*^9}}],

Cell[BoxData["113.24373261008732`"], "Output",
 CellChangeTimes->{3.5930519745475082`*^9, 3.5930629817457647`*^9, 
  3.593065257305584*^9, 3.59309787255516*^9, 3.593128190574737*^9, 
  3.5931363720368843`*^9}],

Cell[BoxData["91.01359069624897`"], "Output",
 CellChangeTimes->{3.5930519745475082`*^9, 3.5930629817457647`*^9, 
  3.593065257305584*^9, 3.59309787255516*^9, 3.593128190574737*^9, 
  3.593136372038114*^9}],

Cell[BoxData["104.74453215073473`"], "Output",
 CellChangeTimes->{3.5930519745475082`*^9, 3.5930629817457647`*^9, 
  3.593065257305584*^9, 3.59309787255516*^9, 3.593128190574737*^9, 
  3.593136372039091*^9}]
}, Open  ]],

Cell[TextData[StyleBox["Similarity: BLKB, BSFT, AZPN, CA", "Title"]], "Text",
 CellChangeTimes->{{3.593064600901905*^9, 3.59306461677947*^9}, {
  3.5930646582476997`*^9, 3.593064662442956*^9}}],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvQl4VGWa912NNnFwC92tH/naxg72OOL0aOP02A3XN7bCOLYwrT3ANb4I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    "], {{0, 449}, {538, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{538, 449},
  PlotRange->{{0, 538}, {0, 449}}]], "Input"]], "Text",
 CellChangeTimes->{
  3.593064591055642*^9, {3.593064634569643*^9, 3.59306465471983*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<BLKB\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trBLKB", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trBLKB"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<BLKB\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593052502704707*^9, 3.5930525174320917`*^9}, {
  3.593064676612075*^9, 3.593064682897341*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1gs4VOsaB/BJRLpNpY0ummh3IZoijWI3a6QtYuOghFInhchUii5qulLt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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 23.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"BLKB\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {23.307969657673986`, 
    41.90240426559469}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.3718886921584141, 
   0.3718886921584141}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593052519172222*^9, 3.5930646840812893`*^9, 
  3.593065259992113*^9, 3.5930978746295757`*^9, 3.593128246684184*^9, 
  3.59313638029403*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<BSFT\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trBSFT", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trBSFT"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<BSFT\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.593052526804631*^9, 3.593052536804961*^9}, {
  3.593064687095847*^9, 3.593064694034597*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1wtYjGkbB/D5UCli8rEkMh2WrpWaNh1QmjeSDsghoTBaSyiG4osW47ii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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 24.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"BSFT\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {24.21651628096822, 
    37.83593062272298}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.2723882868350951, 
   0.2723882868350951}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593052537835834*^9, 3.5930646946313972`*^9, 
  3.59306526201198*^9, 3.593097876709199*^9, 3.593128249101994*^9, 
  3.5931363824137363`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<AZPN\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trAZPN", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trAZPN"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<AZPN\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5930525436454353`*^9, 3.593052555469137*^9}, {
  3.593064697725889*^9, 3.5930647016964197`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwt1QtYTPkbB/CRIiWmxSbaVIqwanQlYk6hpVAkXVy6kJI0pUh/m1EhbauL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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 27.8},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"AZPN\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {27.80779176863611, 
    35.65800687175479}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.15700430206237365`, 
   0.15700430206237365`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593052556124342*^9, 3.593064702470969*^9, 
  3.5930652635937643`*^9, 3.5930978777502327`*^9, 3.593128251223131*^9, 
  3.593136384582219*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"price", " ", "=", " ", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<CA\>\"", ",", "\"\<Jan. 1, 2013\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dwd", " ", "=", " ", 
   RowBox[{"DiscreteWaveletTransform", "[", 
    RowBox[{
     RowBox[{"price", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"BiorthogonalSplineWavelet", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trCA", "=", " ", 
   RowBox[{"InverseWaveletTransform", "[", 
    RowBox[{"WaveletThreshold", "[", 
     RowBox[{"dwd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Hard\>\"", ",", "100"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"price", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", "trCA"}], 
     "}"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<CA\>\""}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5930525608805647`*^9, 3.5930525681541567`*^9}, {
  3.5930647053309317`*^9, 3.5930647102123327`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJwl1glYjGsbB/ApxOlLTbK0qSxfOLa0WFLHvMVB8plwCoW0IEqdk/DFxxAi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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3566073600, 23.},
  FrameTicks->None,
  GridLines->{{{3565987200, 
      GrayLevel[0.8]}, {3571084800, 
      GrayLevel[0.8]}, {3576355200, 
      GrayLevel[0.8]}, {3581625600, 
      GrayLevel[0.8]}, {3586982400, 
      GrayLevel[0.8]}, {3592252800, 
      GrayLevel[0.8]}}, None},
  Method->{},
  PlotLabel->FormBox["\"CA\"", TraditionalForm],
  PlotRange->{{3566073600, 3.5928576*^9}, {23.060743451674945`, 
    31.134488278816008`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{535680., 535680.}, {0.16147489654282127`, 
   0.16147489654282127`}},
  Ticks->{{{3565987200, 
      FormBox["\"Jan\"", TraditionalForm]}, {3571084800, 
      FormBox["\"Mar\"", TraditionalForm]}, {3576355200, 
      FormBox["\"May\"", TraditionalForm]}, {3581625600, 
      FormBox["\"Jul\"", TraditionalForm]}, {3586982400, 
      FormBox["\"Sep\"", TraditionalForm]}, {3592252800, 
      FormBox["\"Nov\"", TraditionalForm]}, {3568665600, 
      FormBox["\"\"", TraditionalForm]}, {3573763200, 
      FormBox["\"\"", TraditionalForm]}, {3579033600, 
      FormBox["\"\"", TraditionalForm]}, {3584304000, 
      FormBox["\"\"", TraditionalForm]}, {3589574400, 
      FormBox["\"\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.593052569359083*^9, 3.5930647108177*^9, 
  3.5930652657552834`*^9, 3.593097880655513*^9, 3.593128253184959*^9, 
  3.593136387867909*^9}]
}, Open  ]],

Cell["\<\

Pair-wise Canberra distances less than the distance to Trend curve of the \
random-pick:\
\>", "Text",
 CellChangeTimes->{{3.593071872214293*^9, 3.593071874760367*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trBLKB", ",", "trBSFT"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trBSFT", ",", "trAZPN"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"CanberraDistance", "[", 
  RowBox[{"trAZPN", ",", "trCA"}], "]"}]}], "Input",
 CellChangeTimes->{{3.593052581827488*^9, 3.5930526154381247`*^9}}],

Cell[BoxData["15.677464127022677`"], "Output",
 CellChangeTimes->{3.5930526176095467`*^9, 3.5930647271346807`*^9, 
  3.593065267563748*^9, 3.593097882546953*^9, 3.593128255175996*^9, 
  3.5931363902512093`*^9}],

Cell[BoxData["10.923331146135691`"], "Output",
 CellChangeTimes->{3.5930526176095467`*^9, 3.5930647271346807`*^9, 
  3.593065267563748*^9, 3.593097882546953*^9, 3.593128255175996*^9, 
  3.593136390252387*^9}],

Cell[BoxData["16.466980101739914`"], "Output",
 CellChangeTimes->{3.5930526176095467`*^9, 3.5930647271346807`*^9, 
  3.593065267563748*^9, 3.593097882546953*^9, 3.593128255175996*^9, 
  3.593136390253358*^9}]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["OK!", "Title"],
 "\n\nRandom-pick Canberra distances:"
}], "Text",
 CellChangeTimes->{{3.593071884897153*^9, 3.59307188706918*^9}, {
  3.593130874557461*^9, 3.593130875356433*^9}, {3.593131180392104*^9, 
  3.5931311918163652`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trBLKB", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trBSFT", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trAZPN", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"CanberraDistance", "[", 
      RowBox[{"trCA", ",", 
       RowBox[{"tr", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "tr", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", "data", "]"}]}], "Input",
 CellChangeTimes->{{3.5930526262427397`*^9, 3.593052653501045*^9}, {
  3.593128257938994*^9, 3.593128311995764*^9}}],

Cell[BoxData["91.40957650067712`"], "Output",
 CellChangeTimes->{
  3.593052654138199*^9, 3.5930647289346333`*^9, 3.593065269082563*^9, 
   3.593097883580195*^9, {3.5931282745579453`*^9, 3.5931283122908792`*^9}, 
   3.593136392253126*^9}],

Cell[BoxData["91.2411227673292`"], "Output",
 CellChangeTimes->{
  3.593052654138199*^9, 3.5930647289346333`*^9, 3.593065269082563*^9, 
   3.593097883580195*^9, {3.5931282745579453`*^9, 3.5931283122908792`*^9}, 
   3.5931363922540617`*^9}],

Cell[BoxData["91.32390784481062`"], "Output",
 CellChangeTimes->{
  3.593052654138199*^9, 3.5930647289346333`*^9, 3.593065269082563*^9, 
   3.593097883580195*^9, {3.5931282745579453`*^9, 3.5931283122908792`*^9}, 
   3.593136392254774*^9}],

Cell[BoxData["90.24522287051018`"], "Output",
 CellChangeTimes->{
  3.593052654138199*^9, 3.5930647289346333`*^9, 3.593065269082563*^9, 
   3.593097883580195*^9, {3.5931282745579453`*^9, 3.5931283122908792`*^9}, 
   3.5931363922554817`*^9}]
}, Open  ]]
},
WindowSize->{841, 1352},
WindowMargins->{{540, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 450, 9, 295, "Text"],
Cell[1010, 31, 6482, 156, 967, "Text"],
Cell[7495, 189, 4120, 108, 622, "Text"],
Cell[11618, 299, 189, 5, 49, "Text"],
Cell[11810, 306, 639, 12, 28, "Input"],
Cell[CellGroupData[{
Cell[12474, 322, 300, 6, 28, "Input"],
Cell[12777, 330, 4152, 78, 253, "Output"]
}, Open  ]],
Cell[16944, 411, 155, 4, 49, "Text"],
Cell[17102, 417, 393, 9, 28, "Input"],
Cell[CellGroupData[{
Cell[17520, 430, 261, 5, 28, "Input"],
Cell[17784, 437, 38185, 854, 186, "Output"]
}, Open  ]],
Cell[55984, 1294, 342, 10, 69, "Text"],
Cell[CellGroupData[{
Cell[56351, 1308, 196, 4, 28, "Input"],
Cell[56550, 1314, 17372, 346, 222, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73959, 1665, 232, 5, 46, "Input"],
Cell[74194, 1672, 10687, 277, 148, "Output"]
}, Open  ]],
Cell[84896, 1952, 184, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[85105, 1961, 77, 1, 28, "Input"],
Cell[85185, 1964, 931, 24, 46, "Output"]
}, Open  ]],
Cell[86131, 1991, 425, 12, 88, "Text"],
Cell[86559, 2005, 316, 7, 68, "Text"],
Cell[86878, 2014, 471, 12, 28, "Input"],
Cell[CellGroupData[{
Cell[87374, 2030, 632, 15, 46, "Input"],
Cell[88009, 2047, 5128, 94, 255, "Output"]
}, Open  ]],
Cell[93152, 2144, 192, 5, 86, "Text"],
Cell[93347, 2151, 304, 7, 68, "Text"],
Cell[CellGroupData[{
Cell[93676, 2162, 1366, 35, 97, "Input"],
Cell[95045, 2199, 4815, 90, 256, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[99897, 2294, 1368, 35, 97, "Input"],
Cell[101268, 2331, 4800, 90, 266, "Output"]
}, Open  ]],
Cell[106083, 2424, 121, 5, 68, "Text"],
Cell[CellGroupData[{
Cell[106229, 2433, 168, 3, 28, "Input"],
Cell[106400, 2438, 159, 2, 28, "Output"]
}, Open  ]],
Cell[106574, 2443, 146, 4, 86, "Text"],
Cell[106723, 2449, 411, 10, 106, "Text"],
Cell[CellGroupData[{
Cell[107159, 2463, 15646, 407, 1151, "Input"],
Cell[122808, 2872, 5205, 95, 255, "Output"],
Cell[128016, 2969, 5193, 95, 260, "Output"],
Cell[133212, 3066, 5233, 96, 261, "Output"],
Cell[138448, 3164, 5216, 96, 256, "Output"],
Cell[143667, 3262, 5165, 95, 254, "Output"],
Cell[148835, 3359, 5229, 96, 258, "Output"],
Cell[154067, 3457, 5257, 96, 254, "Output"],
Cell[159327, 3555, 5105, 94, 259, "Output"],
Cell[164435, 3651, 5217, 96, 258, "Output"],
Cell[169655, 3749, 5207, 95, 257, "Output"],
Cell[174865, 3846, 5176, 95, 247, "Output"]
}, Open  ]],
Cell[180056, 3944, 318, 7, 68, "Text"],
Cell[CellGroupData[{
Cell[180399, 3955, 762, 18, 80, "Input"],
Cell[181164, 3975, 941, 15, 28, "Output"],
Cell[182108, 3992, 615, 8, 28, "Output"],
Cell[182726, 4002, 617, 8, 28, "Output"]
}, Open  ]],
Cell[183358, 4013, 147, 5, 68, "Text"],
Cell[CellGroupData[{
Cell[183530, 4022, 592, 15, 63, "Input"],
Cell[184125, 4039, 687, 13, 46, "Output"],
Cell[184815, 4054, 352, 5, 28, "Output"],
Cell[185170, 4061, 354, 5, 28, "Output"]
}, Open  ]],
Cell[185539, 4069, 374979, 6155, 973, "Text"],
Cell[560521, 10226, 288, 9, 106, "Text"],
Cell[560812, 10237, 142, 4, 86, "Text"],
Cell[560957, 10243, 48767, 804, 466, "Text"],
Cell[609727, 11049, 122, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[609874, 11057, 1521, 38, 114, "Input"],
Cell[611398, 11097, 4945, 92, 251, "Output"]
}, Open  ]],
Cell[616358, 11192, 119, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[616502, 11200, 1605, 38, 97, "Input"],
Cell[618110, 11240, 4841, 90, 260, "Output"]
}, Open  ]],
Cell[622966, 11333, 269, 6, 68, "Text"],
Cell[CellGroupData[{
Cell[623260, 11343, 331, 7, 46, "Input"],
Cell[623594, 11352, 426, 6, 28, "Output"]
}, Open  ]],
Cell[624035, 11361, 488, 9, 143, "Text"],
Cell[CellGroupData[{
Cell[624548, 11374, 790, 20, 97, "Input"],
Cell[625341, 11396, 694, 12, 46, "Output"],
Cell[626038, 11410, 367, 5, 28, "Output"],
Cell[626408, 11417, 369, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[626814, 11427, 691, 18, 97, "Input"],
Cell[627508, 11447, 531, 10, 46, "Output"],
Cell[628042, 11459, 205, 3, 28, "Output"],
Cell[628250, 11464, 203, 3, 28, "Output"]
}, Open  ]],
Cell[628468, 11470, 525, 13, 144, "Text"],
Cell[628996, 11485, 132, 1, 66, "Text"],
Cell[629131, 11488, 46443, 766, 380, "Text"],
Cell[CellGroupData[{
Cell[675599, 12258, 1370, 35, 97, "Input"],
Cell[676972, 12295, 4757, 89, 258, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[681766, 12389, 1370, 35, 97, "Input"],
Cell[683139, 12426, 4734, 89, 255, "Output"]
}, Open  ]],
Cell[687888, 12518, 135, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[688048, 12526, 168, 3, 28, "Input"],
Cell[688219, 12531, 111, 1, 28, "Output"]
}, Open  ]],
Cell[688345, 12535, 126, 4, 86, "Text"],
Cell[688474, 12541, 120, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[688619, 12548, 618, 16, 80, "Input"],
Cell[689240, 12566, 109, 1, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[689386, 12572, 616, 16, 80, "Input"],
Cell[690005, 12590, 110, 1, 28, "Output"]
}, Open  ]],
Cell[690130, 12594, 140, 1, 66, "Text"],
Cell[690273, 12597, 53952, 889, 422, "Text"],
Cell[CellGroupData[{
Cell[744250, 13490, 1415, 36, 97, "Input"],
Cell[745668, 13528, 4771, 89, 259, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[750476, 13622, 1419, 36, 97, "Input"],
Cell[751898, 13660, 4775, 89, 261, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[756710, 13754, 1421, 36, 97, "Input"],
Cell[758134, 13792, 4781, 89, 259, "Output"]
}, Open  ]],
Cell[762930, 13884, 155, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[763110, 13892, 536, 11, 80, "Input"],
Cell[763649, 13905, 160, 2, 28, "Output"],
Cell[763812, 13909, 160, 2, 28, "Output"],
Cell[763975, 13913, 161, 2, 28, "Output"]
}, Open  ]],
Cell[764151, 13918, 135, 5, 105, "Text"],
Cell[764289, 13925, 120, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[764434, 13932, 1555, 42, 131, "Input"],
Cell[765992, 13976, 133, 2, 28, "Output"],
Cell[766128, 13980, 135, 2, 28, "Output"],
Cell[766266, 13984, 136, 2, 28, "Output"]
}, Open  ]],
Cell[766417, 13989, 184, 2, 66, "Text"],
Cell[766604, 13993, 54997, 906, 428, "Text"],
Cell[CellGroupData[{
Cell[821626, 14903, 1477, 37, 114, "Input"],
Cell[823106, 14942, 4834, 89, 261, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[827977, 15036, 1414, 36, 97, "Input"],
Cell[829394, 15074, 4842, 90, 256, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[834273, 15169, 1524, 38, 114, "Input"],
Cell[835800, 15209, 4764, 90, 260, "Output"]
}, Open  ]],
Cell[840579, 15302, 149, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[840753, 15310, 423, 8, 63, "Input"],
Cell[841179, 15320, 277, 4, 28, "Output"],
Cell[841459, 15326, 276, 4, 28, "Output"],
Cell[841738, 15332, 278, 4, 28, "Output"]
}, Open  ]],
Cell[842031, 15339, 130, 4, 86, "Text"],
Cell[842164, 15345, 149, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[842338, 15353, 1581, 42, 114, "Input"],
Cell[843922, 15397, 309, 5, 28, "Output"],
Cell[844234, 15404, 310, 5, 28, "Output"],
Cell[844547, 15411, 311, 5, 28, "Output"]
}, Open  ]],
Cell[844873, 15419, 182, 2, 66, "Text"],
Cell[845058, 15423, 42547, 702, 452, "Text"],
Cell[CellGroupData[{
Cell[887630, 16129, 1364, 35, 97, "Input"],
Cell[888997, 16166, 4849, 90, 256, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[893883, 16261, 1369, 35, 97, "Input"],
Cell[895255, 16298, 4864, 90, 260, "Output"]
}, Open  ]],
Cell[900134, 16391, 153, 6, 68, "Text"],
Cell[CellGroupData[{
Cell[900312, 16401, 170, 3, 28, "Input"],
Cell[900485, 16406, 257, 3, 28, "Output"]
}, Open  ]],
Cell[900757, 16412, 258, 6, 143, "Text"],
Cell[CellGroupData[{
Cell[901040, 16422, 800, 19, 97, "Input"],
Cell[901843, 16443, 605, 11, 46, "Output"],
Cell[902451, 16456, 276, 4, 28, "Output"],
Cell[902730, 16462, 278, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[903045, 16471, 595, 15, 63, "Input"],
Cell[903643, 16488, 462, 9, 46, "Output"],
Cell[904108, 16499, 135, 2, 28, "Output"],
Cell[904246, 16503, 133, 2, 28, "Output"]
}, Open  ]],
Cell[904394, 16508, 132, 1, 66, "Text"],
Cell[904529, 16511, 32336, 535, 383, "Text"],
Cell[CellGroupData[{
Cell[936890, 17050, 1363, 35, 97, "Input"],
Cell[938256, 17087, 4815, 89, 254, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[943108, 17181, 1359, 35, 97, "Input"],
Cell[944470, 17218, 4802, 89, 254, "Output"]
}, Open  ]],
Cell[949287, 17310, 182, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[949494, 17319, 167, 3, 28, "Input"],
Cell[949664, 17324, 248, 3, 28, "Output"]
}, Open  ]],
Cell[949927, 17330, 249, 6, 124, "Text"],
Cell[CellGroupData[{
Cell[950201, 17340, 763, 18, 80, "Input"],
Cell[950967, 17360, 626, 11, 46, "Output"],
Cell[951596, 17373, 294, 4, 28, "Output"],
Cell[951893, 17379, 294, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[952224, 17388, 663, 17, 80, "Input"],
Cell[952890, 17407, 441, 8, 46, "Output"],
Cell[953334, 17417, 109, 1, 28, "Output"],
Cell[953446, 17420, 108, 1, 28, "Output"]
}, Open  ]],
Cell[953569, 17424, 145, 1, 66, "Text"],
Cell[953717, 17427, 46952, 775, 471, "Text"],
Cell[CellGroupData[{
Cell[1000694, 18206, 1360, 35, 97, "Input"],
Cell[1002057, 18243, 4872, 91, 255, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1006966, 18339, 1361, 35, 97, "Input"],
Cell[1008330, 18376, 4875, 91, 259, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1013242, 18472, 1358, 35, 97, "Input"],
Cell[1014603, 18509, 4889, 91, 255, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1019529, 18605, 1359, 35, 97, "Input"],
Cell[1020891, 18642, 4905, 91, 251, "Output"]
}, Open  ]],
Cell[1025811, 18736, 431, 8, 143, "Text"],
Cell[CellGroupData[{
Cell[1026267, 18748, 773, 15, 114, "Input"],
Cell[1027043, 18765, 397, 6, 28, "Output"],
Cell[1027443, 18773, 396, 6, 28, "Output"],
Cell[1027842, 18781, 398, 6, 28, "Output"],
Cell[1028243, 18789, 394, 6, 28, "Output"],
Cell[1028640, 18797, 395, 6, 28, "Output"],
Cell[1029038, 18805, 396, 6, 28, "Output"]
}, Open  ]],
Cell[1029449, 18814, 120, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[1029594, 18821, 2060, 55, 165, "Input"],
Cell[1031657, 18878, 371, 5, 28, "Output"],
Cell[1032031, 18885, 372, 5, 28, "Output"],
Cell[1032406, 18892, 371, 5, 28, "Output"],
Cell[1032780, 18899, 372, 5, 28, "Output"]
}, Open  ]],
Cell[1033167, 18907, 227, 8, 87, "Text"],
Cell[1033397, 18917, 140, 1, 66, "Text"],
Cell[1033540, 18920, 39918, 659, 452, "Text"],
Cell[CellGroupData[{
Cell[1073483, 19583, 1412, 36, 97, "Input"],
Cell[1074898, 19621, 4771, 89, 253, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1079706, 19715, 1363, 35, 97, "Input"],
Cell[1081072, 19752, 4833, 90, 256, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1085942, 19847, 1359, 35, 97, "Input"],
Cell[1087304, 19884, 4821, 90, 264, "Output"]
}, Open  ]],
Cell[1092140, 19977, 178, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[1092343, 19986, 376, 7, 63, "Input"],
Cell[1092722, 19995, 249, 3, 28, "Output"],
Cell[1092974, 20000, 250, 3, 28, "Output"],
Cell[1093227, 20005, 249, 3, 28, "Output"]
}, Open  ]],
Cell[1093491, 20011, 314, 6, 123, "Text"],
Cell[CellGroupData[{
Cell[1093830, 20021, 1536, 42, 114, "Input"],
Cell[1095369, 20065, 274, 4, 28, "Output"],
Cell[1095646, 20071, 274, 4, 28, "Output"],
Cell[1095923, 20077, 273, 4, 28, "Output"]
}, Open  ]],
Cell[1096211, 20084, 153, 6, 87, "Text"],
Cell[1096367, 20092, 133, 1, 66, "Text"],
Cell[1096503, 20095, 65589, 1080, 492, "Text"],
Cell[CellGroupData[{
Cell[1162117, 21179, 1360, 35, 97, "Input"],
Cell[1163480, 21216, 4780, 89, 261, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1168297, 21310, 1371, 35, 97, "Input"],
Cell[1169671, 21347, 4849, 90, 260, "Output"]
}, Open  ]],
Cell[1174535, 21440, 146, 5, 68, "Text"],
Cell[CellGroupData[{
Cell[1174706, 21449, 170, 3, 28, "Input"],
Cell[1174879, 21454, 254, 3, 28, "Output"]
}, Open  ]],
Cell[1175148, 21460, 297, 7, 124, "Text"],
Cell[CellGroupData[{
Cell[1175470, 21471, 1081, 29, 80, "Input"],
Cell[1176554, 21502, 274, 4, 28, "Output"],
Cell[1176831, 21508, 277, 4, 28, "Output"]
}, Open  ]],
Cell[1177123, 21515, 137, 1, 66, "Text"],
Cell[1177263, 21518, 30884, 511, 440, "Text"],
Cell[CellGroupData[{
Cell[1208172, 22033, 1367, 35, 97, "Input"],
Cell[1209542, 22070, 4800, 89, 248, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1214379, 22164, 1362, 35, 97, "Input"],
Cell[1215744, 22201, 4834, 90, 261, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1220615, 22296, 1412, 36, 97, "Input"],
Cell[1222030, 22334, 4813, 89, 259, "Output"]
}, Open  ]],
Cell[1226858, 22426, 178, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[1227061, 22435, 372, 7, 63, "Input"],
Cell[1227436, 22444, 254, 3, 28, "Output"],
Cell[1227693, 22449, 255, 3, 28, "Output"],
Cell[1227951, 22454, 256, 3, 28, "Output"]
}, Open  ]],
Cell[1228222, 22460, 129, 4, 85, "Text"],
Cell[1228354, 22466, 120, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[1228499, 22473, 1682, 44, 165, "Input"],
Cell[1230184, 22519, 186, 3, 28, "Output"],
Cell[1230373, 22524, 186, 3, 28, "Output"],
Cell[1230562, 22529, 186, 3, 28, "Output"],
Cell[1230751, 22534, 186, 3, 28, "Output"]
}, Open  ]],
Cell[1230952, 22540, 132, 1, 66, "Text"],
Cell[1231087, 22543, 25752, 427, 383, "Text"],
Cell[CellGroupData[{
Cell[1256864, 22974, 1359, 35, 97, "Input"],
Cell[1258226, 23011, 4801, 90, 257, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1263064, 23106, 1359, 35, 97, "Input"],
Cell[1264426, 23143, 4805, 90, 256, "Output"]
}, Open  ]],
Cell[1269246, 23236, 160, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[1269431, 23244, 165, 3, 28, "Input"],
Cell[1269599, 23249, 206, 3, 28, "Output"]
}, Open  ]],
Cell[1269820, 23255, 224, 6, 124, "Text"],
Cell[CellGroupData[{
Cell[1270069, 23265, 1027, 28, 80, "Input"],
Cell[1271099, 23295, 203, 3, 28, "Output"],
Cell[1271305, 23300, 204, 3, 28, "Output"]
}, Open  ]],
Cell[1271524, 23306, 136, 1, 66, "Text"],
Cell[1271663, 23309, 43296, 715, 436, "Text"],
Cell[CellGroupData[{
Cell[1314984, 24028, 1361, 35, 97, "Input"],
Cell[1316348, 24065, 4792, 89, 256, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1321177, 24159, 1363, 35, 97, "Input"],
Cell[1322543, 24196, 4828, 90, 257, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1327408, 24291, 1357, 35, 97, "Input"],
Cell[1328768, 24328, 4808, 89, 255, "Output"]
}, Open  ]],
Cell[1333591, 24420, 179, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[1333795, 24429, 370, 7, 63, "Input"],
Cell[1334168, 24438, 207, 3, 28, "Output"],
Cell[1334378, 24443, 208, 3, 28, "Output"],
Cell[1334589, 24448, 208, 3, 28, "Output"]
}, Open  ]],
Cell[1334812, 24454, 137, 4, 86, "Text"],
Cell[1334952, 24460, 122, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[1335099, 24468, 1506, 41, 131, "Input"],
Cell[1336608, 24511, 209, 3, 28, "Output"],
Cell[1336820, 24516, 206, 3, 28, "Output"],
Cell[1337029, 24521, 207, 3, 28, "Output"]
}, Open  ]],
Cell[1337251, 24527, 193, 2, 66, "Text"],
Cell[1337447, 24531, 40635, 671, 463, "Text"],
Cell[CellGroupData[{
Cell[1378107, 25206, 1365, 35, 97, "Input"],
Cell[1379475, 25243, 4805, 90, 260, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1384317, 25338, 1363, 35, 97, "Input"],
Cell[1385683, 25375, 4831, 90, 263, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1390551, 25470, 1367, 35, 97, "Input"],
Cell[1391921, 25507, 4809, 90, 257, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1396767, 25602, 1363, 35, 97, "Input"],
Cell[1398133, 25639, 4769, 89, 258, "Output"]
}, Open  ]],
Cell[1402917, 25731, 179, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[1403121, 25740, 376, 7, 63, "Input"],
Cell[1403500, 25749, 210, 3, 28, "Output"],
Cell[1403713, 25754, 208, 3, 28, "Output"],
Cell[1403924, 25759, 208, 3, 28, "Output"]
}, Open  ]],
Cell[1404147, 25765, 265, 7, 124, "Text"],
Cell[CellGroupData[{
Cell[1404437, 25776, 1940, 54, 148, "Input"],
Cell[1406380, 25832, 238, 4, 28, "Output"],
Cell[1406621, 25838, 239, 4, 28, "Output"],
Cell[1406863, 25844, 238, 4, 28, "Output"],
Cell[1407104, 25850, 240, 4, 28, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
